@@ -1,44 +1,39 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
+
 #-------------------------------------------------------------------------------
-#   This file is part of the Code_Saturne Solver.
+
+# This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-#   Copyright (C) 2009-2011  EDF
+# Copyright (C) 1998-2011 EDF S.A.
 #
-#   Code_Saturne is free software; you can redistribute it and/or modify it
-#   under the terms of the GNU General Public License as published by the
-#   Free Software Foundation; either version 2 of the License,
-#   or (at your option) any later version.
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of the GNU General Public License as published by the Free Software
+# Foundation; either version 2 of the License, or (at your option) any later
+# version.
 #
-#   Code_Saturne is distributed in the hope that it will be useful,
-#   but WITHOUT ANY WARRANTY; without even the implied warranty
-#   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#   GNU General Public License for more details.
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+# details.
 #
-#   You should have received a copy of the GNU General Public Licence
-#   along with the Code_Saturne Preprocessor; if not, write to the
-#   Free Software Foundation, Inc.,
-#   51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+# You should have received a copy of the GNU General Public License along with
+# this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
+# Street, Fifth Floor, Boston, MA 02110-1301, USA.
+
 #-------------------------------------------------------------------------------
 
 import datetime
 import fnmatch
 import os.path
+import subprocess
 import sys
 import tempfile
 
 python_version = sys.version[:3]
 
-try:
-    import subprocess        # Python 2.4+
-    have_subprocess = True
-except ImportError:
-    import popen2            # Python 2.3-
-    have_subprocess = False
-
 from optparse import OptionParser
 
-from cs_config import mpi_lib, env_modules
-
 #===============================================================================
 # Utility functions
 #===============================================================================
@@ -73,35 +68,21 @@ def run_command(cmd, echo = False, stdout = sys.stdout, stderr = sys.stderr):
     if echo == True:
         stdout.write(cmd + '\n')
 
-    if have_subprocess == True:
+    # As a workaround for a bug in which the standard output an error
+    # are "lost" (observed in an apparently random manner, with Python 2.4),
+    # we only add the stdout and stderr keywords if they are non-default.
 
-        # As a workaround for a bug in which the standard output an error
-        # are "lost" (observed in an apparently random manner, with Python 2.4),
-        # we only add the stdout and stderr keywords if they are non-default.
+    kwargs = {}
+    if (stdout != sys.stdout):
+        kwargs['stdout'] = stdout
+    if (stderr != sys.stderr):
+        kwargs['stderr'] = stderr
 
-        kwargs = {}
-        if (stdout != sys.stdout):
-            kwargs['stdout'] = stdout
-        if (stderr != sys.stderr):
-            kwargs['stderr'] = stderr
+    p = subprocess.Popen(cmd, shell=True, **kwargs)
 
-        p = subprocess.Popen(cmd, shell=True, **kwargs)
-        p.communicate()
-        returncode = p.returncode
+    p.communicate()
 
-    else:
-
-        p = popen2.Popen3(cmd, capturestderr=True)
-        returncode = p.wait()
-        output = (p.fromchild.read(), p.childerr.read())
-        if len(output[0]) > 0:
-            stdout.write(output[0])
-        if len(output[1]) > 0:
-            stderr.write(output[1])
-        p.fromchild.close()
-        p.childerr.close()
-
-    return returncode
+    return p.returncode
 
 #-------------------------------------------------------------------------------
 
@@ -109,55 +90,48 @@ def get_command_output(cmd):
     """
     Run a command and return it's standard output.
     """
-    if have_subprocess == True:
-        p = subprocess.Popen(cmd,
-                             shell=True,
-                             stdout=subprocess.PIPE,
-                             stderr=subprocess.PIPE)
-        output = p.communicate()
-        if p.returncode != 0:
-            sys.stderr.write(output[1] + '\n')
-            return ''
-        else:
-            return output[0]
-
+    p = subprocess.Popen(cmd,
+                         shell=True,
+                         stdout=subprocess.PIPE,
+                         stderr=subprocess.PIPE)
+    output = p.communicate()
+    if p.returncode != 0:
+        sys.stderr.write(output[1] + '\n')
+        return ''
     else:
-        p = popen2.Popen3(cmd, capturestderr=True)
-        returncode = p.wait()
-        if returncode != 0:
-            sys.stderr.write(p.childerr.read())
-            return ''
-        else:
-            return p.fromchild.read()
+        return output[0]
 
 #-------------------------------------------------------------------------------
 
-def set_modules():
+def get_command_outputs(cmd):
+    """
+    Run a command and return it's standard and error outputs.
+    """
+    p = subprocess.Popen(cmd,
+                         shell=True,
+                         stdout=subprocess.PIPE,
+                         stderr=subprocess.STDOUT)
+    return p.communicate()[0]
+
+#-------------------------------------------------------------------------------
+
+def set_modules(pkg):
     """
     Set environment modules if present.
     """
-    if env_modules.modules == "no" or not os.environ.has_key('MODULESHOME'):
+
+    if pkg.env_modules == "no":
         return
 
-    cmd_prefix = os.path.join(os.environ['MODULESHOME'], 'bin', 'modulecmd')
+    cmd_prefix = pkg.env_modulecmd
 
-    if have_subprocess == True:
-        cmds = ['purge']
-        for m in env_modules.modules.strip().split():
-            cmds.append('load ' + m)
-        for cmd in cmds:
-            (output, error) \
-                = subprocess.Popen([cmd_prefix, 'python'] + cmd.split(),
-                                   stdout=subprocess.PIPE).communicate()
-            exec output
-
-    else:
-        cmds = ['purge']
-        for m in env_modules.modules.strip().split():
-            cmds.append('load ' + m)
-        for cmd in cmds:
-            p = os.popen(cmd_prefix + ' python ' + cmd).read()
-            exec p
+    cmds = ['purge']
+    for m in pkg.env_modules.strip().split():
+        cmds.append('load ' + m)
+    for cmd in cmds:
+        (output, error) = subprocess.Popen([cmd_prefix, 'python'] + cmd.split(),
+                                           stdout=subprocess.PIPE).communicate()
+        exec output
 
 #-------------------------------------------------------------------------------
 
@@ -202,6 +176,7 @@ class batch_info:
             s = os.getenv('LOADL_JOB_NAME') # LoadLeveler
             if s != None:
                 self.batch_type = 'LOADL'
+                self.job_file = os.getenv('LOADL_STEP_COMMAND')
                 self.submit_dir = os.getenv('LOADL_STEP_INITDIR')
                 self.job_name = os.getenv('LOADL_JOB_NAME')
                 self.job_id = os.getenv('LOADL_STEP_ID')
@@ -248,7 +223,7 @@ class resource_info(batch_info):
 
     #---------------------------------------------------------------------------
 
-    def __init__(self, n_procs = None, hosts_list = None):
+    def __init__(self, n_procs = None, n_procs_default = None):
 
         """
         Get execution resources information.
@@ -270,6 +245,8 @@ class resource_info(batch_info):
         # Check for resource manager
 
         # Test for SLURM (Simple Linux Utility for Resource Management).
+        # Note that we could also use SLURM_CPUS_PER_TASK to
+        # determine Open MP behavior when that is ready.
 
         s = os.getenv('SLURM_NPROCS')
         if s != None:
@@ -364,17 +341,11 @@ class resource_info(batch_info):
                 if s != None:
                     self.hosts_file = '$PE_HOSTFILE'
 
-        # Set an optional list of hosts if we are not running under
-        # a resource manager.
+        # Check hosts file presence
 
-        if hosts_list != None:
-            if self.manager != None:
-                sys.stderr.write('Warning:\n'
-                                 + '   Host list will be ignored because a'
-                                 + ' resource manager (' + self.manager
-                                 + ') is in use.\n\n')
-            else:
-                self.hosts_list = hosts_list
+        if self.hosts_file != None:
+            if not os.path.isfile(os.getenv(self.hosts_file[1:])):
+                self.hosts_file = None
 
         # Determine number of processors from hosts file or list
 
@@ -396,6 +367,9 @@ class resource_info(batch_info):
                                      + str(n_procs) + '.\n\n')
             self.n_procs = n_procs
 
+        if self.n_procs == None:
+            self.n_procs = n_procs_default
+
     #---------------------------------------------------------------------------
 
     def n_procs_from_hosts_file(self, hosts_file):
@@ -591,7 +565,7 @@ MPI_MPMD_execve     = (1<<3)
 
 class mpi_environment:
 
-    def __init__(self, resource_info=None, wdir = None):
+    def __init__(self, pkg, resource_info=None, wdir = None):
         """
         Returns MPI environment info.
         """
@@ -601,14 +575,15 @@ class mpi_environment:
         # but in the case of srun, which uses a -n<n_procs> instead
         # of -n <n_procs> syntax, setting it to ' -n' will be enough.
 
-        self.type = mpi_lib.type
-        self.bindir = mpi_lib.bindir
+        self.type = pkg.mpi_type
+        self.bindir = pkg.mpi_bindir
 
         self.gen_hostsfile = None
         self.del_hostsfile = None
         self.mpiboot = None
         self.mpihalt = None
         self.mpiexec = None
+        self.mpiexec_opts = None
         self.mpiexec_n = None
         self.mpiexec_exe = None
         self.mpiexec_args = None
@@ -1178,7 +1153,7 @@ class exec_environment:
 
     #---------------------------------------------------------------------------
 
-    def __init__(self, wdir=None, n_procs=None, hosts_list=None):
+    def __init__(self, pkg, wdir=None, n_procs=None, n_procs_default = None):
         """
         Returns Execution environment.
         """
@@ -1192,27 +1167,30 @@ class exec_environment:
         if self.wdir == None:
             self.wdir = os.getcwd()
 
-        self.resources = resource_info(n_procs, hosts_list)
+        self.resources = resource_info(n_procs, n_procs_default)
 
         self.mpi_env = None
 
         # Associate default launcher and associated options based on
         # known MPI types, use default otherwise
 
-        self.mpi_env = mpi_environment(self.resources, wdir)
+        self.mpi_env = mpi_environment(pkg, self.resources, wdir)
 
 #-------------------------------------------------------------------------------
 
 if __name__ == '__main__':
 
-    e = exec_environment()
+    import cs_package
+    pkg = cs_package.package()
+    e = exec_environment(pkg)
 
-    mpi_env = mpi_environment()
+    mpi_env = mpi_environment(pkg)
 
     print('mpi_env.bindir =        ', mpi_env.bindir)
     print('mpi_env.mpiexec =       ', mpi_env.mpiexec)
     print('mpi_env.mpiexec_args =  ', mpi_env.mpiexec_args)
     print('mpi_env.mpiexec_exe =   ', mpi_env.mpiexec_exe)
+    print('mpi_env.mpiexec_opts =  ', mpi_env.mpiexec_opts)
     print('mpi_env.mpiexec_n =     ', mpi_env.mpiexec_n)
     print('mpi_env.gen_hostsfile = ', mpi_env.gen_hostsfile)
     print('mpi_env.del_hostsfile = ', mpi_env.del_hostsfile)
