@@ -6,7 +6,7 @@
 
 import sys
 
-if sys.version_info[:2] < (2,3):
+if sys.version_info[:2] < (2,4):
     sys.stderr.write("This script needs Python 2.4 at least\n")
 
 import platform
@@ -245,16 +245,11 @@ class Setup:
 
     def __init__(self):
 
-        # Code_Saturne libraries
-        self.satlibs = ['bft', 'fvm', 'mei', 'ecs', 'ncs']
-
         # Optional libraries
-        self.optlibs = ['cgns', 'hdf5', 'med', 'mpi', 'libxml2', 'swig']
+        self.optlibs = ['cgns', 'hdf5', 'med', 'mpi', 'libxml2']
 
-        self.libs = self.optlibs + self.satlibs
-
-        # Code_Saturne version 
-        self.version = '2.0'
+        # Code_Saturne version
+        self.version = '2.1'
 
         # Logging file
         self.log_file = sys.stdout
@@ -276,6 +271,9 @@ class Setup:
         # Disable GUI
         self.disable_gui = 'no'
 
+        # Disable frontend
+        self.disable_frontend = 'no'
+
         # Python interpreter path
         self.python = None
 
@@ -294,74 +292,29 @@ class Setup:
         # Architecture name
         self.arch = None
 
-        # Global installation prefix
-        # (if None, standard directory "/usr" will be used)
+        # Installation prefix (if None, standard directory "/usr" will be used)
         self.prefix = None
 
-        # Code_Saturne installation prefix
-        self.cs_prefix = None
-
 
         # Packages definition
         self.packages = {}
 
+        # Code_Saturne
+
         url_cs = "http://innovation.edf.com/fichiers/fckeditor/Commun/Innovation/logiciels/code_saturne/Releases/%s"
 
-        # BFT library
-
-        self.packages['bft'] = \
-            Package(name="BFT",
-                    description="Basic Functions and Tools",
-                    package="bft",
-                    version="1.1.5",
-                    archive="bft-115.zip",
+        self.packages['code_saturne'] = \
+            Package(name="Code_Saturne",
+                    description="Code_Saturne CFD tool",
+                    package="code_saturne",
+                    version="2.1.0",
+                    archive="code_saturne-210.zip",
                     url=url_cs)
 
-        # FVM library
-
-        self.packages['fvm'] = \
-            Package(name="FVM",
-                    description="Finite Volume Mesh",
-                    package="fvm",
-                    version="0.15.3",
-                    archive="fvm-0153.zip",
-                    url=url_cs)
-
-        p = self.packages['fvm']
-        p.use_lib_mpi_wrapper = True
-
-        # MEI library
-
-        self.packages['mei'] = \
-            Package(name="MEI",
-                    description="Mathematical Expressions Interpreter",
-                    package="mei",
-                    version="1.0.2",
-                    archive="mei-102.zip",
-                    url=url_cs)
-
-        # Code_Saturne Preprocessor
-
-        self.packages['ecs'] = \
-            Package(name="ECS",
-                    description="Code_Saturne Preprocessor",
-                    package="ecs",
-                    version="2.0.2",
-                    archive="ecs-202.zip",
-                    url=url_cs)
-
-        # Code_Saturne Kernel
-
-        self.packages['ncs'] = \
-            Package(name="NCS",
-                    description="Code_Saturne Kernel",
-                    package="ncs",
-                    version="2.0.2",
-                    archive="ncs-202.zip",
-                    url=url_cs)
-
-        p = self.packages['ncs']
-        p.use_lib_mpi_wrapper = True
+        p = self.packages['code_saturne']
+        p.use = 'yes'
+        p.installation = 'yes'
+        p.installation_pdf = 'yes'
 
         # CGNS library
 
@@ -428,22 +381,9 @@ class Setup:
         p = self.packages['libxml2']
         p.config_opts = "--with-ftp=no --with-http=no"
 
-        # Swig library
-
-        self.packages['swig'] = \
-            Package(name="Swig",
-                    description="Wrapper Python",
-                    package="swig",
-                    version="1.3.40",
-                    archive="swig-1.3.40.tar.gz",
-                    url="http://sourceforge.net/projects/swig/files/swig/swig-1.3.40/%s/download")
-
-        p = self.packages['swig']
-        p.config_opts = "--without-alllang"
-
 
     def read_setup(self):
-        
+
         #
         # setup file reading
         #
@@ -469,7 +409,7 @@ class Setup:
             if len(list) == 0: continue
 
             key = list[0]
-            
+
             if len(list) > 1:
                 if key == 'download': self.download = list[1]
                 elif key == 'prefix': self.prefix = list[1]
@@ -481,6 +421,7 @@ class Setup:
                 elif key == 'compF': self.fc = list[1]
                 elif key == 'mpiCompC': self.mpicc = list[1]
                 elif key == 'disable_gui': self.disable_gui = list[1]
+                elif key == 'disable_frontend': self.disable_frontend = list[1]
                 elif key == 'python': self.python = list[1]
                 elif key == 'blas': self.blas = list[1]
                 elif key == 'metis': self.metis = list[1]
@@ -530,14 +471,6 @@ class Setup:
             self.syrthes = os.path.expandvars(self.syrthes)
             self.syrthes = os.path.abspath(self.syrthes)
 
-        # Compute Code_Saturne installation prefix
-        if self.prefix is not None:
-            subdir = os.path.join('cs-' + self.version)
-            if self.arch is not None:
-                subdir = os.path.join(subdir, 'arch', self.arch)
-                if self.debug == 'yes': subdir = subdir + '_dbg'
-            self.cs_prefix= os.path.join(self.prefix, subdir)
-
 
     def check_setup(self):
 
@@ -565,7 +498,7 @@ Check the setup file and some utilities presence.
                              "Please check your setup file.\n\n")
             sys.exit(1)
 
-        # Testing debug option
+        # Testing GUI option
         if self.disable_gui not in ['yes', 'no']:
             sys.stderr.write("\n*** Aborting installation:\n"
                              "\'disable_gui\' option in the setup file "
@@ -573,6 +506,14 @@ Check the setup file and some utilities presence.
                              "Please check your setup file.\n\n")
             sys.exit(1)
 
+        # Testing frontend option
+        if self.disable_frontend not in ['yes', 'no']:
+            sys.stderr.write("\n*** Aborting installation:\n"
+                             "\'disable_frontend\' option in the setup file "
+                             "should be \'yes\' or \'no\'.\n"
+                             "Please check your setup file.\n\n")
+            sys.exit(1)
+
         # Testing language option
         if self.language not in ['en', 'fr']:
             sys.stderr.write("\n*** Aborting installation:\n"
@@ -580,7 +521,7 @@ Check the setup file and some utilities presence.
                              "should be \'en\' or \'fr'.\n"
                              "Please check your setup file.\n\n")
             sys.exit(1)
-            
+
         # Testing prefix directory
         if self.prefix is not None and not os.path.isdir(self.prefix):
             sys.stderr.write("\n*** Aborting installation:\n"
@@ -611,22 +552,23 @@ Check the setup file and some utilities presence.
                     sys.exit(1)
         
         # Looking for Python executable provided by the user
-        if self.python is not None:
-            python_exe = os.path.join(self.python, 'python')
-        else:
-            python_exe = "python"
-
-        ret = run_test(python_exe)
+        python = 'python'
+        if self.python is not None: python = self.python
+        ret = run_test(python)
         if ret != 0:
             if self.python is not None:
                 sys.stderr.write("\n*** Aborting installation:\n"
-                                 "\'%s\' Python path is provided in the setup "
-                                 "file but no executable can be found.\n"
+                                 "\'%s\' Python exec is provided in the setup "
+                                 "file doesn't not seem to be executable.\n"
                                  "Please check your setup file.\n\n"
                                  % self.python)
+            else:
+                sys.stderr.write("\n*** Aborting installation:\n"
+                                 "Cannot find Python executable.\n"
+                                 "Please check your setup file.\n\n")
             sys.exit(1)
         else:
-            cmd = python_exe + " -c \'import sys; print sys.version[:3]\'"
+            cmd = python + " -c \'import sys; print sys.version[:3]\'"
             if verbose == 'yes':
                 sys.stdout.write("     Python version is ")
             p = subprocess.Popen(cmd,
@@ -640,7 +582,7 @@ Check the setup file and some utilities presence.
                     sys.stdout.write(output[0])
 
         # Checking libraries options
-        for lib in self.libs:
+        for lib in self.optlibs:
             p = self.packages[lib]
             if p.use not in ['yes', 'no', 'auto']:
                 sys.stderr.write("\n*** Aborting installation:\n"
@@ -674,7 +616,7 @@ Check the setup file and some utilities presence.
                              "Please check your setup file.\n\n"
                              % self.blas)
             sys.exit(1)
-            
+
         # Looking for Metis path probided by the user
         if self.metis is not None and not os.path.isdir(self.metis):
             sys.stderr.write("\n*** Aborting installation:\n"
@@ -683,7 +625,7 @@ Check the setup file and some utilities presence.
                              "Please check your setup file.\n\n"
                              % self.metis)
             sys.exit(1)
-            
+
         # Looking for Scotch path probided by the user
         if self.scotch is not None and not os.path.isdir(self.scotch):
             sys.stderr.write("\n*** Aborting installation:\n"
@@ -692,7 +634,7 @@ Check the setup file and some utilities presence.
                              "Please check your setup file.\n\n"
                              % self.scotch)
             sys.exit(1)
-            
+
         # Looking for SYRTHES path probided by the user
         if self.syrthes is not None and not os.path.isdir(self.syrthes):
             sys.stderr.write("\n*** Aborting installation:\n"
@@ -714,24 +656,24 @@ Check the setup file and some utilities presence.
         # Looking for pdflatex for potential documentation compilation
         ret = run_test("pdflatex")
         if ret != 0:
-            self.packages['ncs'].installation_pdf = 'no'
+            self.packages['code_saturne'].installation_pdf = 'no'
             sys.stderr.write("\n*** Warning: "
                              "pdflatex utility cannot be found\n"
                              "Code_Saturne documentation will not be "
                              "installed\n")
         else:
-            self.packages['ncs'].installation_pdf = 'yes'
+            self.packages['code_saturne'].installation_pdf = 'yes'
 
         # Looking for fig2dev for potential documentation compilation
         ret = run_test("fig2dev")
         if ret != 0:
-            self.packages['ncs'].installation_pdf = 'no'
+            self.packages['code_saturne'].installation_pdf = 'no'
             sys.stderr.write("\n*** Warning: "
                              "fig2dev utility cannot be found\n"
                              "Code_Saturne documentation will not be "
                              "installed\n")
         else:
-            self.packages['ncs'].installation_pdf = 'yes'
+            self.packages['code_saturne'].installation_pdf = 'yes'
 
         if verbose == 'yes':
             sys.stdout.write("\n")
@@ -740,177 +682,131 @@ Check the setup file and some utilities presence.
     def update_package_opts(self):
 
         # Update log file, installation directory and compilers
-        for lib in self.libs:
+        for lib in self.optlibs + ['code_saturne']:
             p = self.packages[lib]
             # Update logging file
             p.log_file = self.log_file
             # Installation directory
             if p.installation == 'yes':
-                if lib in self.satlibs:
-                    p.install_dir = self.cs_prefix
-                else:
-                    subdir = os.path.join(p.package + '-' + p.version)
-                    if self.arch is not None:
-                        subdir = os.path.join(subdir, 'arch', self.arch)
-                    p.install_dir = os.path.join(self.prefix, subdir)
+                subdir = os.path.join(p.package + '-' + p.version)
+                if self.arch is not None:
+                    subdir = os.path.join(subdir, 'arch', self.arch)
+                if lib in ['code_saturne'] and self.debug == 'yes':
+                    subdir = subdir + '_dbg'
+                p.install_dir = os.path.join(self.prefix, subdir)
             # Compilers
-            if lib in ['fvm', 'ncs'] and self.mpicc is not None:
+            if lib in ['code_saturne'] and self.mpicc is not None:
                 p.cc = self.mpicc
             else:
                 p.cc = self.cc
-            if lib in ['med', 'ncs']:
+            if lib in ['med', 'code_saturne']:
                 p.fc = self.fc
 
         # Update configuration options
 
+        config_opts = ''
         if self.debug == 'yes':
-            for lib in self.satlibs:
-                p = self.packages[lib]
-                p.config_opts = p.config_opts + " --enable-debug"
-
-        bft = self.packages['bft']
-        fvm = self.packages['fvm']
-        mei = self.packages['mei']
-        ecs = self.packages['ecs']
-        ncs = self.packages['ncs']
+            config_opts = config_opts + " --enable-debug"
 
         cgns = self.packages['cgns']
         hdf5 = self.packages['hdf5']
         med= self.packages['med']
         mpi = self.packages['mpi']
         libxml2 = self.packages['libxml2']
-        swig = self.packages['swig']
 
-        # Disable GUI (and MEI Python bindings too)
+        # Disable GUI
 
         if self.disable_gui == 'yes':
-            swig.use = 'no'
-            ncs.config_opts = ncs.config_opts + " --disable-gui"
+            config_opts = config_opts + " --disable-gui"
 
-        # BFT
+        # Disable frontend
 
-        for p in [fvm, mei, ecs, ncs]:
-            p.config_opts = p.config_opts + " --with-bft=" + bft.install_dir
-
-        # FVM
-
-        ncs.config_opts = ncs.config_opts + " --with-fvm=" + fvm.install_dir
-
-        # MEI
-
-        if mei.use == 'yes':
-            ncs.config_opts = ncs.config_opts + " --with-mei=" + mei.install_dir
-
-        # Preprocessor
-
-        ncs.config_opts = ncs.config_opts + " --with-prepro=" + ecs.install_dir
+        if self.disable_frontend == 'yes':
+            config_opts = config_opts + " --disable-frontend"
 
         # CGNS
 
-        for p in [fvm, ecs]:
-            if cgns.use == 'no':
-                p.config_opts = p.config_opts + " --without-cgns"
-            else:
-                if cgns.install_dir is not None:
-                    p.config_opts = p.config_opts + \
-                        " --with-cgns=" + cgns.install_dir
+        if cgns.use == 'no':
+            config_opts = config_opts + " --without-cgns"
+        else:
+            if cgns.install_dir is not None:
+                config_opts = config_opts + " --with-cgns=" + cgns.install_dir
 
         # HDF5
 
-        if med.use == 'yes':
-            med.config_opts = med.config_opts + " --with-hdf5=" + hdf5.install_dir
-
-        for p in [fvm, ecs]:
-            if hdf5.use == 'no':
-                p.config_opts = p.config_opts + " --without-hdf5"
-            else:
-                if hdf5.install_dir is not None:
-                    p.config_opts = p.config_opts + \
-                        " --with-hdf5=" + hdf5.install_dir
+        if hdf5.use == 'no':
+            config_opts = config_opts + " --without-hdf5"
+        else:
+            if hdf5.install_dir is not None:
+                config_opts = config_opts + " --with-hdf5=" + hdf5.install_dir
+                # HDF5 is also needed for MED build
+                med.config_opts = med.config_opts + \
+                    " --with-hdf5=" + hdf5.install_dir
 
         # MED
 
-        for p in [fvm, ecs]:
-            if med.use == 'no':
-                p.config_opts = p.config_opts + " --without-med"
-            else:
-                if med.install_dir is not None:
-                    p.config_opts = p.config_opts + \
-                        " --with-med=" + med.install_dir
+        if med.use == 'no':
+            config_opts = config_opts + " --without-med"
+        else:
+            if med.install_dir is not None:
+                config_opts = config_opts + " --with-med=" + med.install_dir
 
         # MPI
 
-        for p in [fvm, ncs]:
-            if mpi.use == 'no' and self.mpicc is None:
-                p.config_opts = p.config_opts + " --without-mpi"
-            else:
-                if mpi.install_dir is not None:
-                    p.config_opts = p.config_opts + \
-                        " --with-mpi=" + mpi.install_dir
+        if mpi.use == 'no' and self.mpicc is None:
+            config_opts = config_opts + " --without-mpi"
+        else:
+            if mpi.install_dir is not None:
+                config_opts = config_opts +  " --with-mpi=" + mpi.install_dir
 
         if mpi.use == 'yes' or self.mpicc is not None:
-            fvm.config_opts = fvm.config_opts + " --disable-mpi-io"
+            config_opts = config_opts + " --disable-mpi-io"
 
         # Metis
 
         if self.metis is not None:
-            ecs.config_opts = ecs.config_opts + " --with-metis=" + self.metis
+            config_opts = config_opts + " --with-metis=" + self.metis
 
         # Scotch
 
         if self.scotch is not None:
-            ecs.config_opts = ecs.config_opts + " --with-scotch=" + self.scotch
+            config_opts = config_opts + " --with-scotch=" + self.scotch
 
         # Libxml2
 
         if libxml2.use == 'no':
-            ncs.config_opts = ncs.config_opts + " --without-libxml2"
+            config_opts = config_opts + " --without-libxml2"
         else:
             if libxml2.install_dir is not None:
-                ncs.config_opts = ncs.config_opts + \
+                config_opts = config_opts + \
                     " --with-libxml2=" + libxml2.install_dir
-            
-        # Swig
-
-        if swig.use == 'no':
-            mei.config_opts = mei.config_opts + " --disable-python-bindings"
-        else:
-            if swig.install_dir is not None:
-                mei.config_opts = mei.config_opts + \
-                    " --with-swig-exec=" + os.path.join(swig.install_dir, 'bin')
 
         # Python
 
-        for p in [mei, ncs]:
-            if self.python is not None:
-                p.config_opts = p.config_opts + \
-                    " --with-python-exec=" + self.python
-
         if self.python is not None:
-            swig.config_opts = swig.config_opts + \
-                " --with-python=" + os.path.dirname(self.python)
-        else:
-            swig.config_opts = swig.config_opts + " --with-python"
+            config_opts = config_opts + " --with-python=" + self.python
 
         # BLAS
 
         if self.blas is not None:
-            ncs.config_opts = ncs.config_opts + " --with-blas=" + self.blas
+            config_opts = config_opts + " --with-blas=" + self.blas
 
         # SYRTHES
 
         if self.syrthes is not None:
-            ncs.config_opts = ncs.config_opts + " --with-syrthes=" + self.syrthes
+            config_opts = config_opts + " --with-syrthes=" + self.syrthes
 
         # Language
 
         if self.language == 'fr':
-            ncs.config_opts = ncs.config_opts + " --enable-french"
+            config_opts = config_opts + " --enable-french"
+
+        self.packages['code_saturne'].config_opts = config_opts
 
 
     def install(self):
 
-        for lib in self.libs:
+        for lib in self.optlibs + ['code_saturne']:
             p = self.packages[lib]
             if p.installation == 'yes':
                 sys.stdout.write("Installation of %s\n" % p.name)
@@ -986,6 +882,11 @@ mpiCompC  %(mpicc)s
 disable_gui  %(disable_gui)s
 #
 #--------------------------------------------------------
+# Disable frontend (also disables GUI)
+#--------------------------------------------------------
+disable_frontend  %(disable_frontend)s
+#
+#--------------------------------------------------------
 # Python is mandatory to launch the Graphical User
 # Interface and to use Code_Saturne scripts.
 # It has to be compiled with PyQt 4 support.
@@ -995,7 +896,7 @@ disable_gui  %(disable_gui)s
 # the package manager if needed.
 #
 # If you need to provide your own Python, just set
-# the following variable to the bin directory of Python
+# the following variable to the Python interpreter.
 #--------------------------------------------------------
 python    %(python)s
 #
@@ -1044,19 +945,6 @@ scotch    %(scotch)s
 #--------------------------------------------------------
 syrthes   %(syrthes)s
 #
-#========================================================
-#  Name     Path                      Use         Install
-#========================================================
-"""
-        setupLibSat = \
-"""#
-#--------------------------------------------------------
-# Code_Saturne kernel and module libraries
-#--------------------------------------------------------
-#
-"""
-        setupLibOpt = \
-"""#
 #--------------------------------------------------------
 # Optional packages:
 # ------------------
@@ -1078,12 +966,11 @@ syrthes   %(syrthes)s
 # recommended to use the system's default MPI library.
 #
 #   Libxml2 is needed to read xml files output by the
-# Graphical User Interface, and swig is needed by the
-# Graphical User Interface to handle mathematical
-# expressions. Both should be installed by you package
-# manager.
+# Graphical User Interface.
 #--------------------------------------------------------
 #
+#  Name    Path    Use   Install
+#
 """
         setupLib= \
 """%(lib)s    %(dir)s    %(use)s  %(install)s
@@ -1111,17 +998,11 @@ syrthes   %(syrthes)s
                      'use_arch':self.use_arch, 'arch':self.arch,
                      'cc':self.cc, 'fc':self.fc, 'mpicc':self.mpicc,
                      'disable_gui':self.disable_gui,
+                     'disable_frontend':self.disable_frontend,
                      'python':self.python, 'blas':self.blas,
                      'metis':self.metis, 'scotch': self.scotch,
                      'syrthes':self.syrthes })
 
-        sf.write(setupLibSat)
-        for lib in self.satlibs:
-            p = self.packages[lib]
-            sf.write(setupLib % { 'lib':lib, 'dir':p.install_dir,
-                                  'use':p.use, 'install':p.installation })
-
-        sf.write(setupLibOpt)
         for lib in self.optlibs:
             p = self.packages[lib]
             sf.write(setupLib % { 'lib':lib, 'dir':p.install_dir,
@@ -1142,7 +1023,7 @@ if __name__ == "__main__":
         """
         Installation of Code_Saturne
         ____________________________
-        
+
 The process will take several minutes.
 You can have a look at the log file meanwhile.
 """
@@ -1178,8 +1059,9 @@ Thank you for choosing Code_Saturne!
     setup.check_setup()
     setup.update_package_opts()
     setup.install()
-    
+
     setup.log_file.close()
 
-    sys.stdout.write(finalize % {'cspath':os.path.join(setup.cs_prefix, 'bin')})
+    cspath = os.path.join(setup.packages['code_saturne'].install_dir, 'bin')
+    sys.stdout.write(finalize % {'cspath':cspath})
     sys.stdout.write(thanks)
