@@ -1,30 +1,25 @@
 # -*- coding: utf-8 -*-
-#
+
 #-------------------------------------------------------------------------------
+
+# This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-#     This file is part of the Code_Saturne User Interface, element of the
-#     Code_Saturne CFD tool.
+# Copyright (C) 1998-2011 EDF S.A.
 #
-#     Copyright (C) 1998-2009 EDF S.A., France
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of the GNU General Public License as published by the Free Software
+# Foundation; either version 2 of the License, or (at your option) any later
+# version.
 #
-#     contact: saturne-support@edf.fr
-#
-#     The Code_Saturne User Interface is free software; you can redistribute it
-#     and/or modify it under the terms of the GNU General Public License
-#     as published by the Free Software Foundation; either version 2 of
-#     the License, or (at your option) any later version.
-#
-#     The Code_Saturne User Interface is distributed in the hope that it will be
-#     useful, but WITHOUT ANY WARRANTY; without even the implied warranty
-#     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#     GNU General Public License for more details.
-#
-#     You should have received a copy of the GNU General Public License
-#     along with the Code_Saturne Kernel; if not, write to the
-#     Free Software Foundation, Inc.,
-#     51 Franklin St, Fifth Floor,
-#     Boston, MA  02110-1301  USA
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+# details.
 #
+# You should have received a copy of the GNU General Public License along with
+# this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
+# Street, Fifth Floor, Boston, MA 02110-1301, USA.
+
 #-------------------------------------------------------------------------------
 
 """
@@ -44,8 +39,7 @@ This module defines the following classes:
 # String for the root node of the xml document from the case
 #-------------------------------------------------------------------------------
 
-rootNode = '<Code_Saturne_GUI study="" case="" version="2.0"/>'
-#rootNode = '<NeptuneCFD study="" case=""/>'
+rootNode = None
 
 #-------------------------------------------------------------------------------
 # Library modules import
@@ -59,7 +53,7 @@ from xml.dom.minidom import Document, parse, parseString, Node
 # Application modules import
 #-------------------------------------------------------------------------------
 
-from Toolbox import GuiParam
+from Base.Toolbox import GuiParam
 
 #-------------------------------------------------------------------------------
 # log config
@@ -87,33 +81,33 @@ class Dico:
         """
         self.data = {}
 
-        self.data['new']                    = ""
-        self.data['saved']                  = "yes"
-        self.data['xmlfile']                = ""
-        self.data['mesh_path']              = ""
-        self.data['user_src_path']          = ""
-        self.data['data_path']              = ""
-        self.data['resu_path']              = ""
-        self.data['scripts_path']           = ""
-        self.data['relevant_subdir']        = "no"
-        self.data['case_path']              = ""
-        self.data['batchScript']            = {}
-        self.data['backupBatchScript']      = {}
-        self.data['computer']               = ""
+        self.data['new']              = ""
+        self.data['saved']            = "yes"
+        self.data['xmlfile']          = ""
+        self.data['mesh_path']        = ""
+        self.data['user_src_path']    = ""
+        self.data['data_path']        = ""
+        self.data['resu_path']        = ""
+        self.data['scripts_path']     = ""
+        self.data['relevant_subdir']  = "no"
+        self.data['case_path']        = ""
+        self.data['batch']            = ""
+        self.data['batch_type']       = ""
         self.data['no_boundary_conditions'] = False
-        self.data['salome']                 = False
+        self.data['salome']           = False
+        self.data['package']          = None
 
 
     def _errorExit(self, msg):
         """
         """
-        print 'CASE DICO ERROR'
-        raise ValueError, msg
+        print('CASE DICO ERROR')
+        raise ValueError(msg)
 
 
     def __setitem__(self, key, name):
         """
-        Store values in the data dictionary when the key existe
+        Store values in the data dictionary when the key exists
         in the  dictionary.
         """
         if hasattr(self, 'data'):
@@ -123,9 +117,9 @@ class Dico:
                 msg = "There is an error in the use of the dictionary "+ \
                       "with the key named: " + key + ". \n" + \
                       "The application will finish.\n" \
-                      "Please contact the devlopment team."
+                      "Please contact the development team."
 
-                print self._errorExit(msg)
+                print(self._errorExit(msg))
 
 
     def __getitem__(self, key):
@@ -145,7 +139,7 @@ class Dico:
         """
         if hasattr(self, 'data'):
             for i in self.data.keys():
-                print "%s -> %s" % (i, self.data[i])
+                print("%s -> %s" % (i, self.data[i]))
 
 
 #-------------------------------------------------------------------------------
@@ -181,8 +175,8 @@ class XMLElement:
     def _errorExit(self, msg):
         """
         """
-        print 'XML ERROR'
-        raise ValueError, msg
+        print('XML ERROR')
+        raise ValueError(msg)
 
 
     def toString(self):
@@ -1093,13 +1087,16 @@ class XMLDocument(XMLElement):
 #-------------------------------------------------------------------------------
 
 class Case(Dico, XMLDocument):
-    def __init__(self, file_name=""):
+    def __init__(self, package=None, file_name=""):
         """
         Instantiate a new dico and a new xml doc
         """
         Dico.__init__(self)
         XMLDocument.__init__(self, case=self)
 
+        self['package'] = package
+        rootNode = '<' + self['package'].code_name +'_GUI study="" case="" version="2.0"/>'
+
         if file_name:
             self.parse(file_name)
             self['new'] = "no"
@@ -1154,7 +1151,7 @@ class Case(Dico, XMLDocument):
 
     def xmlSaveDocument(self):
         """
-        This method write the associated xml file.
+        This method writes the associated xml file.
         See saveCase and saveCaseAs methods in the Main module.
         """
         try:
@@ -1169,23 +1166,8 @@ class Case(Dico, XMLDocument):
         except IOError:
             msg = "Error: unable to save the XML document file." ,
             "(XMLengine module, Case class, xmlSaveDocument method)"
-            print msg
+            print(msg)
 
-##  def xmlSaveDocument(self):
-##      """
-##      This method write the associated xml file.
-##      See saveCase and saveCaseAs methods in the Main module.
-##      """
-##      try:
-##          file = open(self['xmlfile'], 'w')
-##          file.write(self.toPrettyString())
-##          file.close()
-##          self['new'] = "no"
-##          self['saved'] = "yes"
-##      except IOError:
-##          msg = "Error: unable to save the XML document file." ,
-##          "(XMLengine module, Case class, xmlSaveDocument method)"
-##          print msg
 
 #-------------------------------------------------------------------------------
 # XMLengine test case
@@ -1474,7 +1456,7 @@ class XMLengineTestCase(unittest.TestCase):
 
     def checkXmlNodeFromString(self):
         """"Check whether two XML nodes could be compared."""
-        print '\n'
+        print('\n')
         n1 = self.xmlNodeFromString(u'<fruits taste="ok" color="red"><a>toto</a><c a="2é"/></fruits>')
         n2 = XMLDocument().parseString(u'<fruits color="red" taste="ok"><c a="2é"/><a>toto</a></fruits>').root()
         assert n1 == n2, 'This two node are not identical'
@@ -1569,7 +1551,7 @@ def suite():
 
 def runTest():
     """unittest function"""
-    print "XMLengineTestCase to be completed..."
+    print("XMLengineTestCase to be completed...")
     runner = unittest.TextTestRunner()
     runner.run(suite())
 
@@ -1606,9 +1588,9 @@ class XMLchek:
     def __call__(self, filename):
         try:
             self.parsefile(filename)
-            print "%s is well-formed" % filename
+            print("%s is well-formed" % filename)
         except Exception, e:
-            print "%s is NOT well-formed! %s" % (filename, e)
+            print("%s is NOT well-formed! %s" % (filename, e))
             sys.exit(0)
 
     def parsefile(self, file):
@@ -1731,7 +1713,7 @@ class XMLchek:
 ##    table.add("field", name="counter", type="int")
 ##    table.add("field", name="name", type="varchar")
 ##    table.add("field", name="info", type="text")
-##    print doc
+##    print(doc)
 ##
 ##    # Simulate reading a XML file
 ##    ndoc = XMLDocument()
@@ -1739,14 +1721,14 @@ class XMLchek:
 ##    root = ndoc.getAll("database")
 ##    if root:
 ##        db = root[0]
-##        print "Database:", db["name"]
+##        print("Database:", db["name"])
 ##        for table in db.getAll("table"):
-##            print "  Table:", table["name"]
+##            print("  Table:", table["name"])
 ##            for field in db.getAll("field"):
-##                print "    Field:", field["name"], "- Type:", field["type"]
+##                print("    Field:", field["name"], "- Type:", field["type"])
 ##
 ##    # It's object oriented
-##    print XMLDocument("notice").add("text",format="plain").addText("Some text")
+##    print(XMLDocument("notice").add("text",format="plain").addText("Some text"))
 #
 #-------------------------------------------------------------------------------
 # Testing part
@@ -1758,42 +1740,42 @@ if __name__ == "__main__":
     sys.exit(0)
 
 
-    print "------------------------------------------------------"
-    print "    Lightweight XML constructor and reader testing"
-    print "------------------------------------------------------\n"
+    print("------------------------------------------------------")
+    print("    Lightweight XML constructor and reader testing")
+    print("------------------------------------------------------\n")
 
     # Example of dumping a database structure
     #
     xmldoc = XMLDocument("", "", "database", name="testdb")
-    print "XMLDocument:\n", xmldoc
+    print("XMLDocument:\n", xmldoc)
 
     table = xmldoc.xmlAddChild("table", name="test")
     table.xmlAddChild("field", name="counter", type="int")
     table.xmlAddChild("field", name="name", type="varchar")
     table.xmlAddChild("field", name="info", type="text")
-    print "table:\n", table
+    print("table:\n", table)
 
-    print "name:", table.xmlGetAttribute("name")
+    print("name:", table.xmlGetAttribute("name"))
     table.xmlDelAttribute("name")
     table.xmlCreateAttribute(truc="super", toto="méga")
     table.xmlCreateAttribute(name="atchoum")
     for field in table.xmlGetNodeList("field", "name", "type", type="text"):
-        print "field:", field.toString()
-    print "truc:", table.xmlGetAttribute("truc")
+        print("field:", field.toString())
+    print("truc:", table.xmlGetAttribute("truc"))
     #table.xmlGetAttribute("tru") # Uncomment this line for testing
     l = table.xmlGetNodeList("camion", "jacky", moquette="moche")
     if not l:
         l = table.xmlAddChild("camion", jacky="", moquette="moche")
-        print "child:", l.toString()
+        print("child:", l.toString())
     l = table.xmlInitNodeList("camion", "jacky", moquette="bêlle")[0]
-    print "child:", l.toString()
+    print("child:", l.toString())
 
     l.xmlSetData("camion", "rétro")
     l.xmlSetData("camion", "chèvre")
     for i in table.xmlGetNodeList("camion"):
-        print "List camion :", i.toString(), "\n"
+        print("List camion :", i.toString(), "\n")
     for i in table.xmlGetChildNodeList("camion"):
-        print "Child camion:", i.toString(), "\n"
+        print("Child camion:", i.toString(), "\n")
 
     table.xmlAddComment("Ceci est un commentaire")
     table.xmlInitNodeList('scalar', 'roue', 'box', auto='yes', type='model')
@@ -1810,66 +1792,66 @@ if __name__ == "__main__":
 
     chaise = xmldoc.xmlAddChild("chaise", name="test")
     p = chaise.xmlSetData("pieds", 4)
-    print p[0].toString()
-    print chaise.xmlGetStringList("pieds")
-    print chaise.xmlGetIntList("pieds")
-    print chaise.xmlGetString("pieds")
-    print chaise.xmlGetInt("pieds")
-    print chaise.xmlGetDouble("pieds")
-    print p[0].xmlGetTextNode()
+    print(p[0].toString())
+    print(chaise.xmlGetStringList("pieds"))
+    print(chaise.xmlGetIntList("pieds"))
+    print(chaise.xmlGetString("pieds"))
+    print(chaise.xmlGetInt("pieds"))
+    print(chaise.xmlGetDouble("pieds"))
+    print(p[0].xmlGetTextNode())
 
-    print xmldoc
+    print(xmldoc)
 
     # Direct acces to node's methods
-    #print dir(xmldoc.doc.documentElement)
-    #print _encode(xmldoc.doc.documentElement.toxml())
-    #print _encode(xmldoc.doc.documentElement.childNodes[0].childNodes[2].attributes.get("name").value)
-    #print _encode(xmldoc.doc.firstChild.firstChild.childNodes[1].attributes.items())
-    #print dir(xmldoc.doc.firstChild.firstChild.childNodes[1].attributes)
+    #print(dir(xmldoc.doc.documentElement))
+    #print(_encode(xmldoc.doc.documentElement.toxml()))
+    #print(_encode(xmldoc.doc.documentElement.childNodes[0].childNodes[2].attributes.get("name").value))
+    #print(_encode(xmldoc.doc.firstChild.firstChild.childNodes[1].attributes.items()))
+    #print(dir(xmldoc.doc.firstChild.firstChild.childNodes[1].attributes))
 
     # Simulate reading a XML file
     ndoc = XMLDocument("", "")
-    print "XML DOC:", ndoc.toString()
+    print("XML DOC:", ndoc.toString())
     ndoc.parseString(str(xmldoc))
-    print "XML DOC:", ndoc.toString()
+    print("XML DOC:", ndoc.toString())
     root = ndoc.xmlGetNodeList("database")
     if root:
         db = root[0]
-        print "Database:", db.xmlGetAttribute("name")
+        print("Database:", db.xmlGetAttribute("name"))
         for table in db.xmlGetNodeList("table"):
-            print "  Table:", table.xmlGetAttribute("name")
+            print("  Table:", table.xmlGetAttribute("name"))
             for field in table.xmlGetNodeList("field"):
-                print "    Field:", field.xmlGetAttribute("name"), \
-                      "- Type:", field.xmlGetAttribute("type")
+                print("    Field:", field.xmlGetAttribute("name"), \
+                      "- Type:", field.xmlGetAttribute("type"))
 
 
     ndoc.parseString('<?xml version="2.0" encoding="utf-8" ?><foo><baré/></foo>')
-    print "1 XML DOC:\n", ndoc
+    print("1 XML DOC:\n", ndoc)
 
     ndoc.parse("../misc/foo.txt")
-    print "2 XML DOC:\n", ndoc
+    print("2 XML DOC:\n", ndoc)
 
 
-    print "------------------------------------------------------"
-    print "        Case class testing"
-    print "------------------------------------------------------\n"
+    print("------------------------------------------------------")
+    print("        Case class testing")
+    print("------------------------------------------------------\n")
 
     case = Case()
     case['new'] = 'toto'
-    print "case:", case['new']
+    print("case:", case['new'])
     models = case.xmlGetNodeList('thermophysical_models')[0]
     models = case.xmlInitNodeList('thermophysical_models')[0]
-    #print "models :", dir(models)
+    #print("models :", dir(models))
     variables = models.xmlGetNodeList('variable')
     for var in variables:
         name = var['name']
-        print var.toString(), name
+        print(var.toString(), name)
         var['label'] = name
         #var.xmlSetAttribute(label='truc')
 
-    #print case
+    #print(case)
     #case.xmlRemoveChild('variable')
-    #print case
+    #print(case)
 
 
 #-------------------------------------------------------------------------------
