@@ -1,30 +1,25 @@
-# -*- coding: iso-8859-1 -*-
-#
+# -*- coding: utf-8 -*-
+
 #-------------------------------------------------------------------------------
+
+# This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-#     This file is part of the Code_Saturne User Interface, element of the
-#     Code_Saturne CFD tool.
+# Copyright (C) 1998-2011 EDF S.A.
 #
-#     Copyright (C) 1998-2009 EDF S.A., France
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of the GNU General Public License as published by the Free Software
+# Foundation; either version 2 of the License, or (at your option) any later
+# version.
 #
-#     contact: saturne-support@edf.fr
-#
-#     The Code_Saturne User Interface is free software; you can redistribute it
-#     and/or modify it under the terms of the GNU General Public License
-#     as published by the Free Software Foundation; either version 2 of
-#     the License, or (at your option) any later version.
-#
-#     The Code_Saturne User Interface is distributed in the hope that it will be
-#     useful, but WITHOUT ANY WARRANTY; without even the implied warranty
-#     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#     GNU General Public License for more details.
-#
-#     You should have received a copy of the GNU General Public License
-#     along with the Code_Saturne Kernel; if not, write to the
-#     Free Software Foundation, Inc.,
-#     51 Franklin St, Fifth Floor,
-#     Boston, MA  02110-1301  USA
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+# details.
 #
+# You should have received a copy of the GNU General Public License along with
+# this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
+# Street, Fifth Floor, Boston, MA 02110-1301, USA.
+
 #-------------------------------------------------------------------------------
 
 """
@@ -46,8 +41,6 @@ import string, shutil, cStringIO
 from PyQt4.QtCore import *
 from PyQt4.QtGui  import *
 
-import cs_config
-
 #-------------------------------------------------------------------------------
 # Application modules import
 #-------------------------------------------------------------------------------
@@ -56,11 +49,10 @@ from Base.Toolbox import GuiParam
 from Base.QtPage import ComboModel
 from Base.XMLengine import Case
 from Base.XMLinitialize import XMLinit
-from SolutionVerifForm import Ui_SolutionVerifForm
-from MeshQualityCriteriaLogDialogForm import Ui_MeshQualityCriteriaLogDialogForm
+from Pages.SolutionVerifForm import Ui_SolutionVerifForm
+from Pages.MeshQualityCriteriaLogDialogForm import Ui_MeshQualityCriteriaLogDialogForm
 from Pages.SolutionDomainModel import SolutionDomainModel
-from OutputControlModel import OutputControlModel
-from FacesSelectionView import StandardItemModelFaces
+from Pages.OutputControlModel import OutputControlModel
 
 #-------------------------------------------------------------------------------
 # log config
@@ -89,11 +81,10 @@ class MeshQualityCriteriaLogDialogView(QDialog, Ui_MeshQualityCriteriaLogDialogF
         self.setWindowTitle(self.tr("Run mesh quality criteria"))
         self.pushButton.setEnabled(False)
 
-        self.cs = os.path.join(cs_config.dirs.bindir, "cs_solver")
-        self.ecs = os.path.join(cs_config.dirs.ecs_bindir, "cs_preprocess")
 
         self.case = case
         self.case2 = case2
+        self.cs = self.case['package'].get_solver()
         self.mdl = SolutionDomainModel(self.case)
         self.out2 = OutputControlModel(self.case2)
 
@@ -103,60 +94,104 @@ class MeshQualityCriteriaLogDialogView(QDialog, Ui_MeshQualityCriteriaLogDialogF
         self.procErrorFlag = False
 
         self.cwd = os.getcwd()
-        os.chdir(self.case['resu_path'])
-        self.fmt = string.join(string.split(self.__getPostCommand()))
 
-        self.__ecsProcess()
+        self.exec_dir = os.path.join(self.case['resu_path'], 'check_mesh')
+        if os.path.isdir(self.exec_dir):
+            shutil.rmtree(self.exec_dir)
+
+        os.mkdir(self.exec_dir)
+        os.chdir(self.exec_dir)
+
+        self.fmt = self.out2.getWriterFormat("-1").lower()
+
+        # Prepare preprocessing
+
+        mesh_input = None
+        node = self.mdl.node_meshes.xmlGetNode('mesh_input', 'path')
+        if node:
+            mesh_input = node['path']
+            if mesh_input:
+                if not os.path.isabs(mesh_input):
+                    mesh_input = os.path.join(self.case['case_path'], mesh_input)
+
+        if mesh_input:
+            try:
+                os.symlink(mesh_input, 'mesh_input')
+            except AttributeError:
+                shutil.copy2(mesh_input, 'mesh_input')
+
+        else:
+
+            self.preprocess_cmd = []
+            nodeList = self.mdl.node_meshes.xmlGetNodeList('mesh', 'name')
+
+            if len(nodeList) > 1:
+                os.mkdir('mesh_input')
+
+            for meshNode in nodeList:
+
+                cmd = self.case['package'].get_preprocessor()
+
+                name   = meshNode['name']
+                format = meshNode['format']
+                mesh = self.case['mesh_path'] + '/' + name
+                if meshNode['num']:
+                    cmd += ' --num ' + meshNode['num']
+                if meshNode['reorient'] == 'on':
+                    cmd += ' --reorient'
+                if meshNode['grp_fac']:
+                    cmd += ' --grp-fac ' + meshNode['grp_fac']
+                if meshNode['grp_cel']:
+                    cmd += ' --grp-cel ' + meshNode['grp_cel']
+
+                # Define postprocessing output for errors and warnings.
+
+                cmd += ' --post-error ' + self.fmt
+
+                cmd += ' --case preprocess'
+                if len(nodeList) > 1:
+                    str_add = '_%02d' % (len(self.preprocess_cmd) + 1)
+                    cmd += str_add
+                    cmd += ' --out ' + os.path.join('mesh_input', 'mesh' + str_add)
+                cmd += ' ' + mesh
+
+                log.debug("ecs_cmd = %s" % cmd)
+
+                self.preprocess_cmd.append(cmd)
+
+            self.__preProcess()
 
 
-    def __ecsProcess(self):
+    def __preProcess(self):
+
+        cmd = self.preprocess_cmd.pop(0)
+        nodelist = self.mdl.node_meshes.xmlGetNodeList('mesh', 'name')
+
+        if len(self.preprocess_cmd) < len(nodelist):
+            self.disconnect(self.proc,
+                            SIGNAL('finished(int, QProcess::ExitStatus)'),
+                            self.__preProcess)
+
         # Run Preprocessor
 
-        lines = []
-        lines.append(self.mdl.getMeshCommand())
-        lines.append(self.mdl.getJoinCommand())
-        lines.append(self.mdl.getPerioCommand())
-        lines.append(self.mdl.getSelectCommand())
-        lines.append(self.__getPostCommand())
-        lines.append(" --case check_mesh ")
-        log.debug("ecs_cmd = %s" % lines)
+        self.proc.start(cmd)
 
-        f1 = 'ecs_cmd'
-        f = open(f1, 'w')
-        f.writelines(lines)
-        f.close()
+        next_task = None
 
-        args = ' --in ' + f1
-        self.proc.start(self.ecs + args)
-
-        self.connect(self.proc, SIGNAL('finished(int, QProcess::ExitStatus)'), self.__ecsPostTreatment)
+        if len(self.preprocess_cmd) > 0:
+            self.connect(self.proc,
+                         SIGNAL('finished(int, QProcess::ExitStatus)'),
+                         self.__preProcess)
+        else:
+            self.connect(self.proc,
+                         SIGNAL('finished(int, QProcess::ExitStatus)'),
+                         self.__ecsPostTreatment)
 
 
     def __ecsPostTreatment(self):
         if self.proc.exitStatus() == QProcess.NormalExit and not self.procErrorFlag:
-            if self.fmt == "--ensight":
-                os.chdir(os.path.join(self.case['resu_path'], 'check_mesh.ensight'))
-                os.rename('CHR.case', 'PREPROCESSOR.case')
-                os.rename('chr.geo', 'preprocessor.geo')
-
-                out = cStringIO.StringIO()
-                f = open('PREPROCESSOR.case')
-                for line in f:
-                    print >> out, line.replace('chr', 'preprocessor'),
-                f.close()
-                out2 = open('PREPROCESSOR.case', 'w')
-                out2.write(out.getvalue())
-                out2.close()
-
-                os.chdir(self.case['resu_path'])
-
-            elif self.fmt == "--med":
-                os.rename('check_mesh.med', 'PREPROCESSOR.med')
-
-            #elif self.fmt == "--cgns":
-            #    os.rename('check_mesh.cgns', 'PREPROCESSOR.cgns')
-
-            if os.path.isfile(os.path.join(self.case['resu_path'], 'preprocessor_output')):
+            mesh_input = os.path.join(self.exec_dir, 'mesh_input')
+            if os.path.isfile(mesh_input) or os.path.isdir(mesh_input):
                 self.__csProcess()
             else:
                 self.__finished()
@@ -165,73 +200,74 @@ class MeshQualityCriteriaLogDialogView(QDialog, Ui_MeshQualityCriteriaLogDialogF
             self.__finished()
 
 
-
     def __csProcess(self):
         # Run Kernel
-        self.disconnect(self.proc, SIGNAL('finished(int, QProcess::ExitStatus)'), self.__ecsPostTreatment)
+        self.disconnect(self.proc,
+                        SIGNAL('finished(int, QProcess::ExitStatus)'),
+                        self.__ecsPostTreatment)
 
         self.case2.xmlSaveDocument()
         args = ' --quality --log 0 --param ' + self.case2['xmlfile']
         self.proc.start(self.cs + args)
 
-        self.connect(self.proc, SIGNAL('finished(int, QProcess::ExitStatus)'), self.__csPostTreatment)
+        self.connect(self.proc,
+                     SIGNAL('finished(int, QProcess::ExitStatus)'),
+                     self.__csPostTreatment)
 
 
     def __csPostTreatment(self):
         if self.proc.exitStatus() == QProcess.NormalExit and not self.procErrorFlag:
-            if self.fmt == "--ensight":
-                for src in os.listdir(os.path.join(self.case['resu_path'], 'chr.ensight')):
-                    shutil.copy(os.path.join(self.case['resu_path'], 'chr.ensight', src),
-                                os.path.join(self.case['resu_path'], 'check_mesh.ensight'))
-                os.chdir(os.path.join(self.case['resu_path'], 'check_mesh.ensight'))
-                os.rename('CHR.case', 'QUALITY.case')
 
-                for src in os.listdir(os.path.join(self.case['resu_path'], 'check_mesh.ensight')):
-                    if src[:4] == "chr.":
-                        dst = src.replace("chr.", "quality.")
-                        os.rename(src, dst)
+            try:
 
-                out = cStringIO.StringIO()
-                f = open('QUALITY.case')
-                for line in f:
-                    print >> out, line.replace('chr', 'quality'),
-                f.close()
-                out2 = open('QUALITY.case', 'w')
-                out2.write(out.getvalue())
-                out2.close()
+                if self.fmt == "ensight":
 
-                shutil.rmtree(os.path.join(self.case['resu_path'], 'chr.ensight'))
-                os.chdir(self.case['resu_path'])
+                    os.rename(os.path.join(self.exec_dir, 'chr.ensight'),
+                              os.path.join(self.exec_dir, 'quality.ensight'))
 
-            elif self.fmt == "--med":
-                os.rename('chr.med', 'QUALITY.med')
+                    os.chdir(os.path.join(self.exec_dir, 'quality.ensight'))
 
-            elif self.fmt == "--cgns":
-                os.rename('chr.cgns', 'QUALITY.cgns')
+                    for src in os.listdir(os.getcwd()):
+                        if src[:4] == "chr.":
+                            dst = src.replace("chr.", "quality.")
+                            os.rename(src, dst)
+
+                    os.rename('CHR.case', 'QUALITY.case')
+
+                    out = cStringIO.StringIO()
+                    f = open('QUALITY.case')
+                    for line in f:
+                        out.write(line.replace('chr', 'quality'))
+                    f.close()
+                    out2 = open('QUALITY.case', 'w')
+                    out2.write(out.getvalue())
+                    out2.close()
+
+                    os.chdir(self.exec_dir)
+
+                elif self.fmt == "med":
+                    os.rename('chr.med', 'QUALITY.med')
+
+                elif self.fmt == "cgns":
+                    os.rename('chr.cgns', 'QUALITY.cgns')
+
+            except OSError: # file to rename might not exist
+                pass
 
         # Cleanup
-        os.remove('preprocessor_output')
+        mesh_input = os.path.join(self.exec_dir, 'mesh_input')
+        if os.path.isdir(mesh_input) and not os.path.islink(mesh_input):
+            shutil.rmtree(mesh_input)
+        else:
+            os.remove(mesh_input)
+        if os.path.isfile('mesh_output'):
+            os.remove('mesh_output')
         os.remove('cs_cmd')
-        os.remove('ecs_cmd')
 
         self.__saveLog()
         self.__finished()
 
 
-    def __getPostCommand(self):
-        """
-        Return the preprocessor argument for postprocessing.
-        """
-        format = self.out2.getPostProFormat()
-        if format == "EnSight":
-            l = " --ensight "
-        elif format == "MED_fichier":
-            l = " --med "
-        elif format == "CGNS":
-            l = " --cgns "
-        return l
-
-
     def __readFromStdout(self):
         """
         Private slot to handle the readyReadStandardOutput signal of the process.
@@ -266,16 +302,7 @@ class MeshQualityCriteriaLogDialogView(QDialog, Ui_MeshQualityCriteriaLogDialogF
 
 
     def __saveLog(self):
-        fileName = QFileDialog.getSaveFileName(self,
-                                               self.tr("Save File As"),
-                                               self.case['resu_path'],
-                                               self.tr("Mesh quality criteria listing (listpre.*);;All files (*)"))
-        if fileName.isEmpty(): return
-        try:
-            logFile = open(str(fileName), 'w')
-        except:
-            QMessageBox.warning(self, 'Error', 'Could not open file for writing')
-            return
+        logFile = open(os.path.join(self.exec_dir, 'check_mesh.log'), 'w')
         logFile.write(str(self.logText.toPlainText().toAscii()))
         logFile.close()
 
@@ -312,10 +339,25 @@ class SolutionVerifView(QWidget, Ui_SolutionVerifForm):
         self.mdl = SolutionDomainModel(self.case)
         self.out = OutputControlModel(self.case)
 
-        self.case2 = Case(None)
+        self.case2 = Case(package = self.case['package'], file_name = None)
         XMLinit(self.case2)
         self.case2['xmlfile'] = 'cs_cmd'
         self.case2['salome'] = self.case['salome']
+
+        faces_cutting = self.case.xmlGetNode('faces_cutting')
+        joining = self.case.xmlGetNode('joining')
+        periodicity = self.case.xmlGetNode('periodicity')
+
+        sd_node = self.case2.xmlGetNode('solution_domain')
+        if faces_cutting != None:
+            if (faces_cutting)['status'] == 'on':
+                sd_node.xmlInitNode('faces_cutting',
+                                    status='on').xmlChildsCopy(faces_cutting)
+        if joining != None:
+            sd_node.xmlInitNode('joining').xmlChildsCopy(joining)
+        if periodicity != None:
+            sd_node.xmlInitNode('solution_domain').xmlChildsCopy(periodicity)
+
         self.out2 = OutputControlModel(self.case2)
 
         # combo models
@@ -324,9 +366,9 @@ class SolutionVerifView(QWidget, Ui_SolutionVerifForm):
         self.modelPolygon        = ComboModel(self.comboBoxPolygon, 3, 1)
         self.modelPolyhedra      = ComboModel(self.comboBoxPolyhedra, 3, 1)
 
-        self.modelFMTCHR.addItem(self.tr("EnSight Gold"), 'EnSight')
-        self.modelFMTCHR.addItem(self.tr("MED"), 'MED_fichier')
-        self.modelFMTCHR.addItem(self.tr("CGNS"), 'CGNS')
+        self.modelFMTCHR.addItem(self.tr("EnSight Gold"), 'ensight')
+        self.modelFMTCHR.addItem(self.tr("MED"), 'med')
+        self.modelFMTCHR.addItem(self.tr("CGNS"), 'cgns')
 
         self.modelFormat.addItem(self.tr("binary"), 'binary')
         self.modelFormat.addItem(self.tr("text"), 'text')
@@ -341,7 +383,6 @@ class SolutionVerifView(QWidget, Ui_SolutionVerifForm):
 
         # connections
 
-        self.connect(self.groupBoxFaces, SIGNAL("clicked(bool)"), self.slotInterneFacesPostPro)
         self.connect(self.comboBoxFMTCHR, SIGNAL("activated(const QString&)"), self.slotOutputFormat)
         self.connect(self.comboBoxFormat, SIGNAL("activated(const QString&)"), self.slotOutputOptions)
         self.connect(self.comboBoxPolygon, SIGNAL("activated(const QString&)"), self.slotOutputOptions)
@@ -349,52 +390,19 @@ class SolutionVerifView(QWidget, Ui_SolutionVerifForm):
         self.connect(self.checkBoxBigEndian, SIGNAL("clicked()"), self.slotOutputOptions)
         self.connect(self.toolButtonBatch, SIGNAL("clicked()"), self.slotMeshChecking)
 
-        # Faces for selection (Custom Widgets)
-
-        model = StandardItemModelFaces(self, self.mdl, 'faces_select')
-        self.widgetFacesSelect.modelFaces = model
-        self.widgetFacesSelect.tableView.setModel(model)
-
         # INITIALISATIONS
-        # 1 - Visualization faces parameters
 
-        if self.mdl.getSelectStatus() == 'on':
-            self.groupBoxFaces.setChecked(True)
-            self.slotInterneFacesPostPro(True)
-        else:
-            self.groupBoxFaces.setChecked(False)
-            self.slotInterneFacesPostPro(False)
+        # 1 - Values of post processing's format
 
-        # 2 - Values of post processing's format
-
-        fmt = self.out.getPostProFormat()
+        fmt = self.out.getWriterFormat("-1")
         self.modelFMTCHR.setItem(str_model=fmt)
-        line = self.out.getPostProOptionsFormat()
+        line = self.out.getWriterOptions("-1")
         self.__updateOptionsFormat(line)
 
         if not self.mdl.getMeshList():
             self.toolButtonBatch.setEnabled(False)
 
 
-    @pyqtSignature("bool")
-    def slotInterneFacesPostPro(self, checked):
-        """
-        Private slot.
-
-        Do we join any meshes ?
-
-        @type checked: C{True} or C{False}
-        @param checked: if C{True}, shows the QGroupBox join parameters
-        """
-        self.groupBoxFaces.setFlat(not checked)
-        if checked:
-            self.mdl.setSelectStatus("on")
-            self.frameFaces.show()
-        else:
-            self.mdl.setSelectStatus("off")
-            self.frameFaces.hide()
-
-
     @pyqtSignature("const QString &")
     def slotOutputFormat(self, text):
         """
@@ -402,22 +410,22 @@ class SolutionVerifView(QWidget, Ui_SolutionVerifForm):
         """
         format = self.modelFMTCHR.dicoV2M[str(text)]
 
-        if self.out.getPostProFormat() != format:
-            self.out.setPostProFormat(format)
-            l = self.out.defaultInitialValues()['postprocessing_options']
-            self.out.setPostProOptionsFormat(l)
+        if self.out.getWriterFormat("-1") != format:
+            self.out.setWriterFormat("-1",format)
+            l = self.out.defaultWriterValues()['options']
+            self.out.setWriterOptions("-1",l)
 
-        if self.out2.getPostProFormat() != format:
-            self.out2.setPostProFormat(format)
-            l = self.out2.defaultInitialValues()['postprocessing_options']
-            self.out2.setPostProOptionsFormat(l)
+        if self.out2.getWriterFormat("-1") != format:
+            self.out2.setWriterFormat("-1",format)
+            l = self.out2.defaultWriterValues()['options']
+            self.out2.setWriterOptions("-1",l)
             self.__updateOptionsFormat(l)
 
 
     @pyqtSignature("")
     def slotOutputOptions(self):
         """
-        Create characters ligne for command of format's options
+        Create format's command line options
         """
         line = []
         opt_format = self.modelFormat.dicoV2M[str(self.comboBoxFormat.currentText())]
@@ -433,13 +441,13 @@ class SolutionVerifView(QWidget, Ui_SolutionVerifForm):
 
         l = string.join(line, ',')
         log.debug("slotOutputOptions-> OPTCHR = %s" % l)
-        self.out.setPostProOptionsFormat(l)
-        self.out2.setPostProOptionsFormat(l)
+        self.out.setWriterOptions("-1",l)
+        self.out2.setWriterOptions("-1",l)
 
 
     def __updateOptionsFormat(self, line):
         """
-        Update ligne for command of format's options at each modification of
+        Update command-line options at each modification of
         post processing format
         """
         list = string.split(line, ',')
@@ -460,11 +468,9 @@ class SolutionVerifView(QWidget, Ui_SolutionVerifForm):
             if opt == 'discard_polyhedra' or opt == 'divide_polyhedra':
                 self.modelPolyhedra.setItem(str_model=opt)
 
-            if format == 'EnSight':
+            if format == 'ensight':
                 if opt == 'big_endian':
                     self.checkBoxBigEndian.setChecked(True)
-##                if opt == 'split_tensors':
-##                    self.opt_splittens.set('on')
 
         if 'discard_polygons' not in list and 'divide_polygons' not in list:
             self.modelPolygon.setItem(str_model="display")
@@ -472,14 +478,12 @@ class SolutionVerifView(QWidget, Ui_SolutionVerifForm):
             self.modelPolyhedra.setItem(str_model="display")
         if 'big_endian' not in list:
             self.checkBoxBigEndian.setChecked(False)
-##        if 'split_tensors' not in list:
-##            self.opt_splittens.set('off')
 
         # enable and disable options related to the format
 
-        if format != "EnSight":
+        if format != "ensight":
 
-            if format == "CGNS":
+            if format == "cgns":
                 self.modelPolyhedra.setItem(str_model='divide_polyhedra')
                 self.modelPolyhedra.disableItem(str_model='display')
 
@@ -496,20 +500,6 @@ class SolutionVerifView(QWidget, Ui_SolutionVerifForm):
             self.comboBoxPolyhedra.setEnabled(True)
 
 
-    def __getPostCommand(self):
-        """
-        Return the preprocessor argument for postprocessing.
-        """
-        format = self.out2.getPostProFormat()
-        if format == "EnSight":
-            l = " --ensight "
-        elif format == "MED_fichier":
-            l = " --med "
-        elif format == "CGNS":
-            l = " --cgns "
-        return l
-
-
     def __setButtonEnabled(self):
         """
         Block the QButton during the display of the dialog.
