@@ -1,30 +1,25 @@
-# -*- coding: iso-8859-1 -*-
-#
+# -*- coding: utf-8 -*-
+
 #-------------------------------------------------------------------------------
+
+# This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-#     This file is part of the Code_Saturne User Interface, element of the
-#     Code_Saturne CFD tool.
+# Copyright (C) 1998-2011 EDF S.A.
 #
-#     Copyright (C) 1998-2009 EDF S.A., France
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of the GNU General Public License as published by the Free Software
+# Foundation; either version 2 of the License, or (at your option) any later
+# version.
 #
-#     contact: saturne-support@edf.fr
-#
-#     The Code_Saturne User Interface is free software; you can redistribute it
-#     and/or modify it under the terms of the GNU General Public License
-#     as published by the Free Software Foundation; either version 2 of
-#     the License, or (at your option) any later version.
-#
-#     The Code_Saturne User Interface is distributed in the hope that it will be
-#     useful, but WITHOUT ANY WARRANTY; without even the implied warranty
-#     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#     GNU General Public License for more details.
-#
-#     You should have received a copy of the GNU General Public License
-#     along with the Code_Saturne Kernel; if not, write to the
-#     Free Software Foundation, Inc.,
-#     51 Franklin St, Fifth Floor,
-#     Boston, MA  02110-1301  USA
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+# details.
 #
+# You should have received a copy of the GNU General Public License along with
+# this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
+# Street, Fifth Floor, Boston, MA 02110-1301, USA.
+
 #-------------------------------------------------------------------------------
 
 """
@@ -53,7 +48,7 @@ from PyQt4.QtGui  import *
 
 from Base.Common import LABEL_LENGTH_MAX
 from Base.Toolbox import GuiParam
-from TimeAveragesForm import Ui_TimeAveragesForm
+from Pages.TimeAveragesForm import Ui_TimeAveragesForm
 from Base.QtPage import IntValidator, RegExpValidator, ComboModel
 from Pages.StartRestartModel import StartRestartModel
 from Pages.TimeAveragesModel import TimeAveragesModel
@@ -242,7 +237,7 @@ class TimeAveragesView(QWidget, Ui_TimeAveragesForm):
 
         # Is it a following calculation ?
 
-        if StartRestartModel(self.case).getRestart() == 'off':
+        if not StartRestartModel(self.case).getRestartPath():
             self.labelRestart.setDisabled(True)
             self.comboBoxIMOOLD.setDisabled(True)
             self.lineEditRestart.setDisabled(True)
@@ -269,7 +264,7 @@ class TimeAveragesView(QWidget, Ui_TimeAveragesForm):
             default['list'] = self.mdl.getTimeAverageLabels()
             rx = "[\-_A-Za-z0-9]{1," + str(LABEL_LENGTH_MAX) + "}"
             default['regexp'] = QRegExp(rx)
-            from VerifyExistenceLabelDialogView import VerifyExistenceLabelDialogView
+            from Pages.VerifyExistenceLabelDialogView import VerifyExistenceLabelDialogView
             dialog = VerifyExistenceLabelDialogView(self, default)
             if dialog.exec_():
                 result = dialog.get_result()
@@ -382,7 +377,7 @@ class TimeAveragesView(QWidget, Ui_TimeAveragesForm):
             log.debug("slotAddAverage -> %s" % (label,))
 
             ntdmom = self.start
-            if StartRestartModel(self.case).getRestart() != 'off':
+            if StartRestartModel(self.case).getRestartPath():
                 imoold = self.restart
             else:
                 imoold = self.mdl.defaultValues()['restart']
@@ -452,7 +447,7 @@ class TimeAveragesView(QWidget, Ui_TimeAveragesForm):
                 log.debug("slotEditAverage -> %s" % (new_label,))
 
                 new_start = self.start
-                if StartRestartModel(self.case).getRestart() != 'off':
+                if StartRestartModel(self.case).getRestartPath():
                     new_restart = self.restart
                 else:
                     new_restart = self.mdl.defaultValues()['restart']
@@ -478,7 +473,7 @@ class TimeAveragesView(QWidget, Ui_TimeAveragesForm):
         self.lineEditAverage.setText(QString(label))
         self.lineEditStart.setText(QString(str(ntdmom)))
 
-        if StartRestartModel(self.case).getRestart() != 'off':
+        if StartRestartModel(self.case).getRestartPath():
             if not imoold or imoold == -2:
                 imoold = -2
                 choice = "automatic"
@@ -520,7 +515,7 @@ class TimeAveragesView(QWidget, Ui_TimeAveragesForm):
         """
         self.lineEditAverage.setText(str(""))
         self.lineEditStart.setText(str(""))
-        if StartRestartModel(self.case).getRestart() == 'on':
+        if not StartRestartModel(self.case).getRestartPath():
             self.lineEditRestart.setText(str(""))
         self.modelDrop.setStringList(QStringList())
         self.treeViewAverage.clearSelection()
