@@ -1,53 +1,37 @@
 !-------------------------------------------------------------------------------
 
-!     This file is part of the Code_Saturne Kernel, element of the
-!     Code_Saturne CFD tool.
-
-!     Copyright (C) 1998-2009 EDF S.A., France
-
-!     contact: saturne-support@edf.fr
-
-!     The Code_Saturne Kernel is free software; you can redistribute it
-!     and/or modify it under the terms of the GNU General Public License
-!     as published by the Free Software Foundation; either version 2 of
-!     the License, or (at your option) any later version.
-
-!     The Code_Saturne Kernel is distributed in the hope that it will be
-!     useful, but WITHOUT ANY WARRANTY; without even the implied warranty
-!     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-!     GNU General Public License for more details.
-
-!     You should have received a copy of the GNU General Public License
-!     along with the Code_Saturne Kernel; if not, write to the
-!     Free Software Foundation, Inc.,
-!     51 Franklin St, Fifth Floor,
-!     Boston, MA  02110-1301  USA
+! This file is part of Code_Saturne, a general-purpose CFD tool.
+!
+! Copyright (C) 1998-2011 EDF S.A.
+!
+! This program is free software; you can redistribute it and/or modify it under
+! the terms of the GNU General Public License as published by the Free Software
+! Foundation; either version 2 of the License, or (at your option) any later
+! version.
+!
+! This program is distributed in the hope that it will be useful, but WITHOUT
+! ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+! FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+! details.
+!
+! You should have received a copy of the GNU General Public License along with
+! this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
+! Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 !-------------------------------------------------------------------------------
 
 subroutine calhyd &
 !================
 
- ( idbia0 , idbra0 ,                                              &
-   ndim   , ncelet , ncel   , nfac   , nfabor , nfml   , nprfml , &
-   nnod   , lndfac , lndfbr , ncelbr ,                            &
-   nvar   , nscal  , nphas  ,                                     &
-   nideve , nrdeve , nituse , nrtuse , iphas  ,                   &
-   ifacel , ifabor , ifmfbr , ifmcel , iprfml ,                   &
-   ipnfac , nodfac , ipnfbr , nodfbr ,                            &
+ ( nvar   , nscal  ,                                              &
    indhyd ,                                                       &
-   idevel , ituser , ia     ,                                     &
-   xyzcen , surfac , surfbo , cdgfac , cdgfbo , xyznod , volume , &
    fextx  , fexty  , fextz  ,                                     &
    dfextx , dfexty , dfextz ,                                     &
    phydr  , flumas , flumab ,                                     &
    coefa  , coefb  ,                                              &
    viscf  , viscb  ,                                              &
    dam    , xam    ,                                              &
-   drtp   , smbr   ,                                              &
-   w1     , w2     , w3     , w4     , w5     , w6     ,          &
-   w7     , w8     , w9     , w10    ,                            &
-   rdevel , rtuser , ra     )
+   drtp   , smbr   )
 
 !===============================================================================
 ! FONCTION :
@@ -61,52 +45,9 @@ subroutine calhyd &
 !__________________.____._____.________________________________________________.
 ! name             !type!mode ! role                                           !
 !__________________!____!_____!________________________________________________!
-! idbia0           ! i  ! <-- ! number of first free position in ia            !
-! idbra0           ! i  ! <-- ! number of first free position in ra            !
-! ndim             ! i  ! <-- ! spatial dimension                              !
-! ncelet           ! i  ! <-- ! number of extended (real + ghost) cells        !
-! ncel             ! i  ! <-- ! number of cells                                !
-! nfac             ! i  ! <-- ! number of interior faces                       !
-! nfabor           ! i  ! <-- ! number of boundary faces                       !
-! nfml             ! i  ! <-- ! number of families (group classes)             !
-! nprfml           ! i  ! <-- ! number of properties per family (group class)  !
-! nnod             ! i  ! <-- ! number of vertices                             !
-! lndfac           ! i  ! <-- ! size of nodfac indexed array                   !
-! lndfbr           ! i  ! <-- ! size of nodfbr indexed array                   !
-! ncelbr           ! i  ! <-- ! number of cells with faces on boundary         !
 ! nvar             ! i  ! <-- ! total number of variables                      !
 ! nscal            ! i  ! <-- ! total number of scalars                        !
-! nphas            ! i  ! <-- ! number of phases                               !
-! nideve, nrdeve   ! i  ! <-- ! sizes of idevel and rdevel arrays              !
-! nituse, nrtuse   ! i  ! <-- ! sizes of ituser and rtuser arrays              !
-! iphas            ! i  ! <-- ! phase number                                   !
-! ifacel(2, nfac)  ! ia ! <-- ! interior faces -> cells connectivity           !
-! ifabor(nfabor)   ! ia ! <-- ! boundary faces -> cells connectivity           !
-! ifmfbr(nfabor)   ! ia ! <-- ! boundary face family numbers                   !
-! ifmcel(ncelet)   ! ia ! <-- ! cell family numbers                            !
-! iprfml           ! ia ! <-- ! property numbers per family                    !
-!  (nfml, nprfml)  !    !     !                                                !
-! ipnfac(nfac+1)   ! ia ! <-- ! interior faces -> vertices index (optional)    !
-! nodfac(lndfac)   ! ia ! <-- ! interior faces -> vertices list (optional)     !
-! ipnfbr(nfabor+1) ! ia ! <-- ! boundary faces -> vertices index (optional)    !
-! nodfbr(lndfbr)   ! ia ! <-- ! boundary faces -> vertices list (optional)     !
-! idevel(nideve)   ! ia ! <-> ! integer work array for temporary development   !
-! ituser(nituse)   ! ia ! <-> ! user-reserved integer work array               !
 ! indhyd           ! e  ! --> ! indicateur de mise a jour de phydr             !
-! ia(*)            ! ia ! --- ! main integer work array                        !
-! xyzcen           ! ra ! <-- ! cell centers                                   !
-!  (ndim, ncelet)  !    !     !                                                !
-! surfac           ! ra ! <-- ! interior faces surface vectors                 !
-!  (ndim, nfac)    !    !     !                                                !
-! surfbo           ! ra ! <-- ! boundary faces surface vectors                 !
-!  (ndim, nfabor)  !    !     !                                                !
-! cdgfac           ! ra ! <-- ! interior faces centers of gravity              !
-!  (ndim, nfac)    !    !     !                                                !
-! cdgfbo           ! ra ! <-- ! boundary faces centers of gravity              !
-!  (ndim, nfabor)  !    !     !                                                !
-! xyznod           ! ra ! <-- ! vertex coordinates (optional)                  !
-!  (ndim, nnod)    !    !     !                                                !
-! volume(ncelet)   ! ra ! <-- ! cell volumes                                   !
 ! dt(ncelet)       ! ra ! <-- ! time step (per cell)                           !
 ! phydr(ncelet)    ! tr ! <-- ! increment de pression hydrostatique            !
 ! propce(ncelet, *)! ra ! <-- ! physical properties at cell centers            !
@@ -124,10 +65,6 @@ subroutine calhyd &
 ! xam(nfac,*)      ! tr ! --- ! tableau de travail pour matrice                !
 ! drtp(ncelet      ! tr ! --- ! tableau de travail pour increment              !
 ! smbr  (ncelet    ! tr ! --- ! tableau de travail pour sec mem                !
-! w1..10(ncelet    ! tr ! --- ! tableau de travail                             !
-! rdevel(nrdeve)   ! ra ! <-> ! real work array for temporary development      !
-! rtuser(nrtuse)   ! ra ! <-> ! user-reserved real work array                  !
-! ra(*)            ! ra ! --- ! main real work array                           !
 !__________________!____!_____!________________________________________________!
 
 !     TYPE : E (ENTIER), R (REEL), A (ALPHANUMERIQUE), T (TABLEAU)
@@ -137,46 +74,30 @@ subroutine calhyd &
 
 !===============================================================================
 
+!===============================================================================
+! Module files
+!===============================================================================
+
+use paramx
+use numvar
+use entsor
+use cstnum
+use optcal
+use parall
+use period
+use mltgrd
+use mesh
+
+!===============================================================================
+
 implicit none
 
-!===============================================================================
-! Common blocks
-!===============================================================================
-
-include "paramx.h"
-include "numvar.h"
-include "entsor.h"
-include "cstnum.h"
-include "optcal.h"
-include "period.h"
-include "parall.h"
-include "mltgrd.h"
-
-!===============================================================================
-
 ! Arguments
 
-integer          idbia0 , idbra0
-integer          ndim   , ncelet , ncel   , nfac   , nfabor
-integer          nfml   , nprfml
-integer          nnod   , lndfac , lndfbr , ncelbr
-integer          nvar   , nscal  , nphas
-integer          nideve , nrdeve , nituse , nrtuse , iphas
+integer          nvar   , nscal
 
-
-integer          ifacel(2,nfac) , ifabor(nfabor)
-integer          ifmfbr(nfabor) , ifmcel(ncelet)
-integer          iprfml(nfml,nprfml)
-integer          ipnfac(nfac+1), nodfac(lndfac)
-integer          ipnfbr(nfabor+1), nodfbr(lndfbr)
 integer          indhyd
-integer          idevel(nideve), ituser(nituse)
-integer          ia(*)
 
-double precision xyzcen(ndim,ncelet)
-double precision surfac(ndim,nfac), surfbo(ndim,nfabor)
-double precision cdgfac(ndim,nfac), cdgfbo(ndim,nfabor)
-double precision xyznod(ndim,nnod), volume(ncelet)
 double precision fextx(ncelet),fexty(ncelet),fextz(ncelet)
 double precision dfextx(ncelet),dfexty(ncelet),dfextz(ncelet)
 double precision phydr(ncelet)
@@ -186,58 +107,50 @@ double precision viscf(nfac), viscb(nfabor)
 double precision dam(ncelet), xam(nfac,2)
 double precision drtp(ncelet)
 double precision smbr(ncelet)
-double precision w1(ncelet), w2(ncelet), w3(ncelet)
-double precision w4(ncelet), w5(ncelet), w6(ncelet)
-double precision w7(ncelet), w8(ncelet), w9(ncelet)
-double precision w10(ncelet)
-double precision rdevel(nrdeve), rtuser(nrtuse), ra(*)
 
 ! Local variables
 
 character*80     chaine
 integer          lchain
-integer          idebia, idebra
 integer          iccocg, inc   , init  , isym  , ipol  , isqrt
 integer          iel   , ical
 integer          ireslp, nswmpr
 integer          isweep, niterf, icycle
 integer          iphydp
 integer          nswrgp, imligp, iwarnp
-integer          ipriph
 integer          iinvpe
 integer          idiffp, iconvp, ndircp
 integer          nitmap, imgrp , ncymap, nitmgp
 integer          iagmax, nagmax, npstmg
+integer          ibsize
+
 double precision residu, rnorm , rnrmf , rnrmdf
 double precision epsrgp, climgp, extrap, epsilp
 double precision precre, precab, thetap
 
+double precision, allocatable, dimension(:) :: w1, w7, w10
+
 !===============================================================================
 
 !===============================================================================
 ! 1.  INITIALISATIONS
 !===============================================================================
 
+! Allocate temporary arrays
+allocate(w1(ncelet), w7(ncelet), w10(ncelet))
+
 ! --- Memoire
-idebia = idbia0
-idebra = idbra0
-
-
-! --- Variables
-ipriph = ipr(iphas)
-
-
 
 ! --- Options de resolution
 !     Symetrique
 !     Preconditionnement diagonal par defaut
 isym  = 1
-if (iresol(ipriph).eq.-1) then
+if (iresol(ipr).eq.-1) then
   ireslp = 0
   ipol   = 0
 else
-  ireslp = mod(iresol(ipriph),1000)
-  ipol   = (iresol(ipriph)-ireslp)/1000
+  ireslp = mod(iresol(ipr),1000)
+  ipol   = (iresol(ipr)-ireslp)/1000
 endif
 
 isqrt = 1
@@ -270,7 +183,7 @@ if (ical.eq.0) then
   return
 endif
 
-if ( mod(ntcabs,ntlist).eq.0 .or. iwarni(iu(1)) .ge.0 )           &
+if ( mod(ntcabs,ntlist).eq.0 .or. iwarni(iu) .ge.0 )           &
      write(nfecra,1000)
 
 #if defined(_CS_LANG_FR)
@@ -307,17 +220,9 @@ enddo
 
 call viscfa                                                       &
 !==========
- ( idebia , idebra ,                                              &
-   ndim   , ncelet , ncel   , nfac   , nfabor , nfml   , nprfml , &
-   nnod   , lndfac , lndfbr , ncelbr ,                            &
-   nideve , nrdeve , nituse , nrtuse , imvisf ,                   &
-   ifacel , ifabor , ifmfbr , ifmcel , iprfml ,                   &
-   ipnfac , nodfac , ipnfbr , nodfbr ,                            &
-   idevel , ituser , ia     ,                                     &
-   xyzcen , surfac , surfbo , cdgfac , cdgfbo , xyznod , volume , &
+ ( imvisf ,                                                       &
    w10    ,                                                       &
-   viscf  , viscb  ,                                              &
-   rdevel , rtuser , ra     )
+   viscf  , viscb  )
 
 
 iconvp = 0
@@ -347,32 +252,23 @@ call matrix                                                       &
 init   = 1
 inc    = 0
 iccocg = 1
-nswrgp = nswrgr(ipriph)
-imligp = imligr(ipriph)
-iwarnp = iwarni(ipriph)
-epsrgp = epsrgr(ipriph)
-climgp = climgr(ipriph)
+nswrgp = nswrgr(ipr)
+imligp = imligr(ipr)
+iwarnp = iwarni(ipr)
+epsrgp = epsrgr(ipr)
+climgp = climgr(ipr)
 
 call projts                                                       &
 !==========
- ( idebia , idebra ,                                              &
-   ndim   , ncelet , ncel   , nfac   , nfabor , nfml   , nprfml , &
-   nnod   , lndfac , lndfbr , ncelbr ,                            &
-   nvar   , nscal  , nphas  ,                                     &
-   nideve , nrdeve , nituse , nrtuse ,                            &
+ ( nvar   , nscal  ,                                              &
    init   , inc    , imrgra , iccocg , nswrgp , imligp ,          &
    iwarnp , nfecra ,                                              &
    epsrgp , climgp ,                                              &
-   ifacel , ifabor , ifmfbr , ifmcel , iprfml ,                   &
-   ipnfac , nodfac , ipnfbr , nodfbr ,                            &
-   idevel , ituser , ia     ,                                     &
-   xyzcen , surfac , surfbo , cdgfac , cdgfbo , xyznod , volume , &
    dfextx , dfexty , dfextz ,                                     &
    coefb     ,                                                    &
    flumas, flumab ,                                               &
    viscf  , viscb  ,                                              &
-   w10    , w10    , w10    ,                                     &
-   rdevel , rtuser , ra     )
+   w10    , w10    , w10    )
 
 init = 1
 call divmas(ncelet,ncel,nfac,nfabor,init,nfecra,                  &
@@ -384,15 +280,15 @@ call prodsc(ncelet,ncel,isqrt,w7,w7,rnorm)
 ! 5.  PREPARATION DU MULTIGRILLE ALGEBRIQUE
 !===============================================================================
 
-if (imgr(ipriph).gt.0) then
+if (imgr(ipr).gt.0) then
 
 !   --- Creation de la hierarchie de maillages
 
   CHAINE = 'PresHydr'
-  iwarnp = iwarni(ipriph)
-  iagmax = iagmx0(ipriph)
-  nagmax = nagmx0(ipriph)
-  npstmg = ncpmgr(ipriph)
+  iwarnp = iwarni(ipr)
+  iagmax = iagmx0(ipr)
+  nagmax = nagmx0(ipr)
+  npstmg = ncpmgr(ipr)
   lchain = 8
 
   call clmlga                                                     &
@@ -401,6 +297,7 @@ if (imgr(ipriph).gt.0) then
    ncelet , ncel   , nfac   ,                                     &
    isym   , iagmax , nagmax , npstmg , iwarnp ,                   &
    ngrmax , ncegrm ,                                              &
+   rlxp1  ,                                                       &
    dam    , xam    )
 
 endif
@@ -410,7 +307,7 @@ endif
 !===============================================================================
 
 ! --- Nombre de sweeps
-nswmpr = nswrsm(ipriph)
+nswmpr = nswrsm(ipr)
 
 ! --- Mise a zero des variables
 !       RTP(.,IPR) sera l'increment de pression cumule
@@ -435,14 +332,14 @@ do isweep = 1, nswmpr
 ! --- Test de convergence du calcul
 
   call prodsc(ncelet,ncel,isqrt,smbr,smbr,residu)
-  if (iwarni(ipriph).ge.2) then
-     CHAINE = 'PresHydr'
-     write(nfecra,1400)chaine(1:8),isweep,residu
+  if (iwarni(ipr).ge.2) then
+     chaine = 'PresHydr'
+     write(nfecra,1400)chaine(1:16),isweep,residu
   endif
 
 !MO IL FAUDRA VERIFIER LA PERTINENCE DU TEST
 
-  if( residu .le. 10.d0*epsrsm(ipriph)*rnorm ) then
+  if( residu .le. 10.d0*epsrsm(ipr)*rnorm ) then
 !     Si convergence,  sortie
 
     goto 101
@@ -454,32 +351,24 @@ do isweep = 1, nswmpr
     drtp(iel) = 0.d0
   enddo
 
-  CHAINE = 'PresHydr'
-  nitmap = nitmax(ipriph)
-  imgrp  = imgr  (ipriph)
-  ncymap = ncymax(ipriph)
-  nitmgp = nitmgf(ipriph)
-  iwarnp = iwarni(ipriph)
-  epsilp = epsilo(ipriph)
+  chaine = 'PresHydr'
+  nitmap = nitmax(ipr)
+  imgrp  = imgr  (ipr)
+  ncymap = ncymax(ipr)
+  nitmgp = nitmgf(ipr)
+  iwarnp = iwarni(ipr)
+  epsilp = epsilo(ipr)
   iinvpe = 1
+  ibsize = 1
 
   call invers                                                     &
   !==========
- ( chaine(1:8)     , idebia , idebra ,                            &
-   ndim   , ncelet , ncel   , nfac   , nfabor , nfml   , nprfml , &
-   nnod   , lndfac , lndfbr , ncelbr ,                            &
-   nideve , nrdeve , nituse , nrtuse ,                            &
-   isym   , ipol   , ireslp , nitmap , imgrp  ,                   &
+ ( chaine(1:16)    , isym   , ibsize ,                            &
+   ipol   , ireslp , nitmap , imgrp  ,                            &
    ncymap , nitmgp ,                                              &
    iwarnp , nfecra , niterf , icycle , iinvpe ,                   &
    epsilp , rnorm  , residu ,                                     &
-   ifacel , ifabor , ifmfbr , ifmcel , iprfml ,                   &
-   ipnfac , nodfac , ipnfbr , nodfbr ,                            &
-   idevel , ituser , ia     ,                                     &
-   xyzcen , surfac , surfbo , cdgfac , cdgfbo , xyznod , volume , &
-   dam    , xam    , smbr   , drtp   ,                            &
-   w3     , w4     , w5     , w6     , w8     , w9     ,          &
-   rdevel , rtuser , ra     )
+   dam    , xam    , smbr   , drtp   )
 
 
   if( isweep.eq.nswmpr ) then
@@ -503,58 +392,50 @@ do isweep = 1, nswmpr
     iccocg = 1
     init = 1
     inc  = 1
-    nswrgp = nswrgr(ipriph)
-    imligp = imligr(ipriph)
-    iwarnp = iwarni(ipriph)
-    epsrgp = epsrgr(ipriph)
-    climgp = climgr(ipriph)
+    nswrgp = nswrgr(ipr)
+    imligp = imligr(ipr)
+    iwarnp = iwarni(ipr)
+    epsrgp = epsrgr(ipr)
+    climgp = climgr(ipr)
     extrap = 0.d0
     iphydp = 1
 
     call itrgrp                                                   &
     !==========
- ( idebia , idebra ,                                              &
-   ndim   , ncelet , ncel   , nfac   , nfabor , nfml   , nprfml , &
-   nnod   , lndfac , lndfbr , ncelbr ,                            &
-   nvar   , nscal  , nphas  ,                                     &
-   nideve , nrdeve , nituse , nrtuse ,                            &
+ ( nvar   , nscal  ,                                              &
    init   , inc    , imrgra , iccocg , nswrgp , imligp , iphydp , &
    iwarnp , nfecra ,                                              &
    epsrgp , climgp , extrap ,                                     &
-   ifacel , ifabor , ifmfbr , ifmcel , iprfml ,                   &
-   ipnfac , nodfac , ipnfbr , nodfbr ,                            &
-   idevel , ituser , ia     ,                                     &
-   xyzcen , surfac , surfbo , cdgfac , cdgfbo , xyznod , volume , &
    dfextx , dfexty , dfextz ,                                     &
    phydr  ,                                                       &
    coefa  , coefb  ,                                              &
    viscf  , viscb  ,                                              &
    w10         , w10         , w10         ,                      &
-   smbr   ,                                                       &
-   w1     , w2     , w3     , w4     , w5     , w6     ,          &
-   rdevel , rtuser , ra     )
+   smbr   )
 
   endif
 
 enddo
 ! --- Boucle de reconstruction : fin
 
-if(iwarni(ipriph).ge.2) then
-   CHAINE = 'PresHydr'
-   write( nfecra,1600)chaine(1:8),nswmpr
+if(iwarni(ipr).ge.2) then
+   chaine = 'PresHydr'
+   write( nfecra,1600)chaine(1:16),nswmpr
 endif
 
  101  continue
 
+! Free memory
+deallocate(w1, w7, w10)
 
 !===============================================================================
 ! 7.  SUPPRESSION DE LA HIERARCHIE DE MAILLAGES
 !===============================================================================
 
-if (imgr(ipriph).gt.0) then
-  CHAINE = 'PresHydr'
-  lchain = 8
-  call dsmlga(chaine(1:8), lchain)
+if (imgr(ipr).gt.0) then
+  chaine = 'PresHydr'
+  lchain = 16
+  call dsmlga(chaine(1:16), lchain)
   !==========
 endif
 
@@ -564,20 +445,20 @@ endif
 
 #if defined(_CS_LANG_FR)
 
- 1400 format(1X,A8,' : SWEEP = ',I5,' NORME SECOND MEMBRE = ',E14.6)
+ 1400 format(1X,A16,' : SWEEP = ',I5,' NORME SECOND MEMBRE = ',E14.6)
  1600 format(                                                           &
 '@                                                            ',/,&
-'@ @@ ATTENTION : ',A8 ,' ETAPE DE PRESSION HYDROSTATIQUE     ',/,&
+'@ @@ ATTENTION : ', A16,' ETAPE DE PRESSION HYDROSTATIQUE    ',/,&
 '@    =========                                               ',/,&
 '@  Nombre d''iterations maximal ',I10   ,' atteint           ',/,&
 '@                                                            '  )
 
 #else
 
- 1400 format(1X,A8,' : SWEEP = ',I5,' RIGHT HAND SIDE NORM = ',E14.6)
+ 1400 format(1X,A16,' : SWEEP = ',I5,' RIGHT HAND SIDE NORM = ',E14.6)
  1600 format(                                                           &
 '@                                                            ',/,&
-'@ @@ WARNING: ',A8 ,' HYDROSTATIC PRESSURE STEP              ',/,&
+'@ @@ WARNING: ', A16,' HYDROSTATIC PRESSURE STEP             ',/,&
 '@    ========                                                ',/,&
 '@  Maximum number of iterations ',I10   ,' reached           ',/,&
 '@                                                            '  )
