@@ -1,52 +1,35 @@
 !-------------------------------------------------------------------------------
 
-!     This file is part of the Code_Saturne Kernel, element of the
-!     Code_Saturne CFD tool.
-
-!     Copyright (C) 1998-2009 EDF S.A., France
-
-!     contact: saturne-support@edf.fr
-
-!     The Code_Saturne Kernel is free software; you can redistribute it
-!     and/or modify it under the terms of the GNU General Public License
-!     as published by the Free Software Foundation; either version 2 of
-!     the License, or (at your option) any later version.
-
-!     The Code_Saturne Kernel is distributed in the hope that it will be
-!     useful, but WITHOUT ANY WARRANTY; without even the implied warranty
-!     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-!     GNU General Public License for more details.
-
-!     You should have received a copy of the GNU General Public License
-!     along with the Code_Saturne Kernel; if not, write to the
-!     Free Software Foundation, Inc.,
-!     51 Franklin St, Fifth Floor,
-!     Boston, MA  02110-1301  USA
+! This file is part of Code_Saturne, a general-purpose CFD tool.
+!
+! Copyright (C) 1998-2011 EDF S.A.
+!
+! This program is free software; you can redistribute it and/or modify it under
+! the terms of the GNU General Public License as published by the Free Software
+! Foundation; either version 2 of the License, or (at your option) any later
+! version.
+!
+! This program is distributed in the hope that it will be useful, but WITHOUT
+! ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+! FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+! details.
+!
+! You should have received a copy of the GNU General Public License along with
+! this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
+! Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 !-------------------------------------------------------------------------------
 
 subroutine covofi &
 !================
 
- ( idbia0 , idbra0 ,                                              &
-   ndim   , ncelet , ncel   , nfac   , nfabor , nfml   , nprfml , &
-   nnod   , lndfac , lndfbr , ncelbr ,                            &
-   nvar   , nscal  , nphas  , ncepdp , ncesmp ,                   &
-   nideve , nrdeve , nituse , nrtuse , iscal  , itspdv ,          &
-   ifacel , ifabor , ifmfbr , ifmcel , iprfml ,                   &
-   ipnfac , nodfac , ipnfbr , nodfbr ,                            &
+ ( nvar   , nscal  , ncepdp , ncesmp ,                            &
+   iscal  , itspdv ,                                              &
    icepdc , icetsm , itypsm ,                                     &
-   idevel , ituser , ia     ,                                     &
-   xyzcen , surfac , surfbo , cdgfac , cdgfbo , xyznod , volume , &
    dt     , rtp    , rtpa   , propce , propfa , propfb , tslagr , &
    coefa  , coefb  , ckupdc , smacel ,                            &
    viscf  , viscb  ,                                              &
-   dam    , xam    ,                                              &
-   drtp   , smbrs  , rovsdt ,                                     &
-   w1     , w2     , w3     , w4     , w5     ,                   &
-   w6     , w7     , w8     , w9     ,                            &
-   rdevel , rtuser ,                                              &
-   ra     )
+   smbrs  , rovsdt )
 
 !===============================================================================
 ! FONCTION :
@@ -60,59 +43,17 @@ subroutine covofi &
 !__________________.____._____.________________________________________________.
 ! name             !type!mode ! role                                           !
 !__________________!____!_____!________________________________________________!
-! idbia0           ! i  ! <-- ! number of first free position in ia            !
-! idbra0           ! i  ! <-- ! number of first free position in ra            !
-! ndim             ! i  ! <-- ! spatial dimension                              !
-! ncelet           ! i  ! <-- ! number of extended (real + ghost) cells        !
-! ncel             ! i  ! <-- ! number of cells                                !
-! nfac             ! i  ! <-- ! number of interior faces                       !
-! nfabor           ! i  ! <-- ! number of boundary faces                       !
-! nfml             ! i  ! <-- ! number of families (group classes)             !
-! nprfml           ! i  ! <-- ! number of properties per family (group class)  !
-! nnod             ! i  ! <-- ! number of vertices                             !
-! lndfac           ! i  ! <-- ! size of nodfac indexed array                   !
-! lndfbr           ! i  ! <-- ! size of nodfbr indexed array                   !
-! ncelbr           ! i  ! <-- ! number of cells with faces on boundary         !
 ! nvar             ! i  ! <-- ! total number of variables                      !
 ! nscal            ! i  ! <-- ! total number of scalars                        !
-! nphas            ! i  ! <-- ! number of phases                               !
 ! ncepdp           ! i  ! <-- ! number of cells with head loss                 !
 ! ncesmp           ! i  ! <-- ! number of cells with mass source term          !
-! nideve, nrdeve   ! i  ! <-- ! sizes of idevel and rdevel arrays              !
-! nituse, nrtuse   ! i  ! <-- ! sizes of ituser and rtuser arrays              !
 ! iscal            ! i  ! <-- ! scalar number                                  !
 ! itspdv           ! e  ! <-- ! calcul termes sources prod et dissip           !
 !                  !    !     !  (0 : non , 1 : oui)                           !
-! ifacel(2, nfac)  ! ia ! <-- ! interior faces -> cells connectivity           !
-! ifabor(nfabor)   ! ia ! <-- ! boundary faces -> cells connectivity           !
-! ifmfbr(nfabor)   ! ia ! <-- ! boundary face family numbers                   !
-! ifmcel(ncelet)   ! ia ! <-- ! cell family numbers                            !
-! iprfml           ! ia ! <-- ! property numbers per family                    !
-!  (nfml, nprfml)  !    !     !                                                !
-! ipnfac(nfac+1)   ! ia ! <-- ! interior faces -> vertices index (optional)    !
-! nodfac(lndfac)   ! ia ! <-- ! interior faces -> vertices list (optional)     !
-! ipnfbr(nfabor+1) ! ia ! <-- ! boundary faces -> vertices index (optional)    !
-! nodfbr(lndfbr)   ! ia ! <-- ! boundary faces -> vertices list (optional)     !
 ! icepdc(ncelet    ! te ! <-- ! numero des ncepdp cellules avec pdc            !
 ! icetsm(ncesmp    ! te ! <-- ! numero des cellules a source de masse          !
 ! itypsm           ! te ! <-- ! type de source de masse pour les               !
 ! (ncesmp,nvar)    !    !     !  variables (cf. ustsma)                        !
-! idevel(nideve)   ! ia ! <-> ! integer work array for temporary development   !
-! ituser(nituse)   ! ia ! <-> ! user-reserved integer work array               !
-! ia(*)            ! ia ! --- ! main integer work array                        !
-! xyzcen           ! ra ! <-- ! cell centers                                   !
-!  (ndim, ncelet)  !    !     !                                                !
-! surfac           ! ra ! <-- ! interior faces surface vectors                 !
-!  (ndim, nfac)    !    !     !                                                !
-! surfbo           ! ra ! <-- ! boundary faces surface vectors                 !
-!  (ndim, nfabor)  !    !     !                                                !
-! cdgfac           ! ra ! <-- ! interior faces centers of gravity              !
-!  (ndim, nfac)    !    !     !                                                !
-! cdgfbo           ! ra ! <-- ! boundary faces centers of gravity              !
-!  (ndim, nfabor)  !    !     !                                                !
-! xyznod           ! ra ! <-- ! vertex coordinates (optional)                  !
-!  (ndim, nnod)    !    !     !                                                !
-! volume(ncelet)   ! ra ! <-- ! cell volumes                                   !
 ! dt(ncelet)       ! ra ! <-- ! time step (per cell)                           !
 ! rtp, rtpa        ! ra ! <-- ! calculated variables at cell centers           !
 !  (ncelet, *)     !    !     !  (at current and previous time steps)          !
@@ -130,75 +71,51 @@ subroutine covofi &
 !                  !    !     !  pour ivar=ipr, smacel=flux de masse           !
 ! viscf(nfac)      ! tr ! --- ! visc*surface/dist aux faces internes           !
 ! viscb(nfabor     ! tr ! --- ! visc*surface/dist aux faces de bord            !
-! dam(ncelet       ! tr ! --- ! tableau de travail pour matrice                !
-! xam(nfac,*)      ! tr ! --- ! tableau de travail pour matrice                !
-! drtp(ncelet      ! tr ! --- ! tableau de travail pour increment              !
 ! smbrs(ncelet     ! tr ! --- ! tableau de travail pour sec mem                !
 ! rovsdt(ncelet    ! tr ! --- ! tableau de travail pour terme instat           !
-! w1...9(ncelet    ! tr ! --- ! tableau de travail                             !
-! rdevel(nrdeve)   ! ra ! <-> ! real work array for temporary development      !
-! rtuser(nrtuse)   ! ra ! <-> ! user-reserved real work array                  !
-! ra(*)            ! ra ! --- ! main real work array                           !
 !__________________!____!_____!________________________________________________!
 
 !     TYPE : E (ENTIER), R (REEL), A (ALPHANUMERIQUE), T (TABLEAU)
 !            L (LOGIQUE)   .. ET TYPES COMPOSES (EX : TR TABLEAU REEL)
 !     MODE : <-- donnee, --> resultat, <-> Donnee modifiee
 !            --- tableau de travail
-!-------------------------------------------------------------------------------
+!===============================================================================
+
+!===============================================================================
+! Module files
+!===============================================================================
+
+use paramx
+use dimens, only: ndimfb
+use numvar
+use entsor
+use optcal
+use cstphy
+use cstnum
+use ppppar
+use ppthch
+use coincl
+use cpincl
+use cs_fuel_incl
+use ppincl
+use lagpar
+use lagran
+use radiat
+use mesh
+
 !===============================================================================
 
 implicit none
 
-!===============================================================================
-! Common blocks
-!===============================================================================
-
-include "dimfbr.h"
-include "paramx.h"
-include "numvar.h"
-include "entsor.h"
-include "optcal.h"
-include "cstphy.h"
-include "cstnum.h"
-include "ppppar.h"
-include "ppthch.h"
-include "coincl.h"
-include "cpincl.h"
-include "fuincl.h"
-include "ppincl.h"
-include "lagpar.h"
-include "lagran.h"
-include "matiss.h"
-include "radiat.h"
-
-!===============================================================================
-
 ! Arguments
 
-integer          idbia0 , idbra0
-integer          ndim   , ncelet , ncel   , nfac   , nfabor
-integer          nfml   , nprfml
-integer          nnod   , lndfac , lndfbr , ncelbr
-integer          nvar   , nscal  , nphas
+integer          nvar   , nscal
 integer          ncepdp , ncesmp
-integer          nideve , nrdeve , nituse , nrtuse
 integer          iscal  , itspdv
 
-integer          ifacel(2,nfac) , ifabor(nfabor)
-integer          ifmfbr(nfabor) , ifmcel(ncelet)
-integer          iprfml(nfml,nprfml)
-integer          ipnfac(nfac+1), nodfac(lndfac)
-integer          ipnfbr(nfabor+1), nodfbr(lndfbr)
 integer          icepdc(ncepdp)
 integer          icetsm(ncesmp), itypsm(ncesmp,nvar)
-integer          idevel(nideve), ituser(nituse)
-integer          ia(*)
 
-double precision xyzcen(ndim,ncelet)
-double precision surfac(ndim,nfac), surfbo(ndim,nfabor)
-double precision cdgfac(ndim,nfac), cdgfbo(ndim,nfabor)
-double precision xyznod(ndim,nnod), volume(ncelet)
 double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
 double precision propce(ncelet,*)
 double precision propfa(nfac,*), propfb(ndimfb,*)
@@ -206,51 +123,52 @@ double precision tslagr(ncelet,*)
 double precision coefa(ndimfb,*), coefb(ndimfb,*)
 double precision ckupdc(ncepdp,6), smacel(ncesmp,nvar)
 double precision viscf(nfac), viscb(nfabor)
-double precision dam(ncelet), xam(nfac,2)
-double precision drtp(ncelet), smbrs(ncelet)
+double precision smbrs(ncelet)
 double precision rovsdt(ncelet)
-double precision w1(ncelet), w2(ncelet), w3(ncelet)
-double precision w4(ncelet), w5(ncelet), w6(ncelet)
-double precision w7(ncelet), w8(ncelet), w9(ncelet)
-double precision rdevel(nrdeve), rtuser(nrtuse)
-double precision ra(*)
 
 ! Local variables
 
 character*80     chaine
-integer          idebia, idebra
-integer          ivar  , iphas
+integer          ivar
 integer          ifac  , iel
 integer          init  , inc   , iccocg, isqrt, iii, iiun, ibcl
 integer          ivarsc, iscala
 integer          iiscav, iicp
-integer          ikiph , ieiph , iomgip
-integer          ir11ip, ir22ip, ir33ip
 integer          iclvar, iclvaf
 integer          ipcrom, ipcvst, ipcvsl, iflmas, iflmab
-integer          ippvar, ipp   , iphydp, iptsca, ipcvso
+integer          ippvar, ipp   , iptsca, ipcvso
 integer          nswrgp, imligp, iwarnp
 integer          iconvp, idiffp, ndircp, ireslp, nitmap
 integer          nswrsp, ircflp, ischcp, isstpp, iescap
 integer          imgrp , ncymxp, nitmfp
-integer          maxelt, ils   , idbia1
+
 double precision epsrgp, climgp, extrap, relaxp, blencp, epsilp
 double precision epsrsp
 double precision rhovst, xk    , xe    , sclnor
 double precision thetv , thets , thetap, thetp1
 double precision smbexp
 
+double precision rvoid(1)
+
+double precision, allocatable, dimension(:) :: w1, w2, w3
+double precision, allocatable, dimension(:,:) :: grad
+
 !===============================================================================
 
 !===============================================================================
 ! 1. INITIALISATION
 !===============================================================================
 
-idebia = idbia0
-idebra = idbra0
+! Allocate temporary arrays
+allocate(w1(ncelet))
+
+! Initialize variables to avoid compiler warnings
+
+xe = 0.d0
+xk = 0.d0
+
+! --- Memoire
 
-! ---  Numero de phase associee au scalaire traite
-iphas  = iphsca(iscal)
 
 ! --- Numero de variable de calcul et de post associe au scalaire traite
 ivar   = isca(iscal)
@@ -265,27 +183,13 @@ else
   ivarsc = 0
 endif
 
-! --- Numero des variables de calcul
-if(itytur(iphas).eq.2 .or. iturb(iphas).eq.50) then
-  ikiph  = ik  (iphas)
-  ieiph  = iep (iphas)
-elseif(itytur(iphas).eq.3) then
-  ir11ip = ir11(iphas)
-  ir22ip = ir22(iphas)
-  ir33ip = ir33(iphas)
-  ieiph  = iep (iphas)
-elseif(iturb(iphas).eq.60) then
-  ikiph  = ik  (iphas)
-  iomgip = iomg(iphas)
-endif
-
 ! --- Numero des conditions aux limites
 iclvar = iclrtp(ivar,icoef)
 iclvaf = iclrtp(ivar,icoeff)
 
 ! --- Numero des grandeurs physiques
-ipcrom = ipproc(irom  (iphas))
-ipcvst = ipproc(ivisct(iphas))
+ipcrom = ipproc(irom  )
+ipcvst = ipproc(ivisct)
 iflmas = ipprof(ifluma(ivar ))
 iflmab = ipprob(ifluma(ivar ))
 if(ivisls(iscal).gt.0) then
@@ -328,61 +232,14 @@ enddo
 
 iscala = iscal
 
-
-if (imatis.eq.1) then
-
-!     Matisse
-  call mttssc                                                     &
-  !==========
- ( idebia , idebra ,                                              &
-   ndim   , ncelet , ncel   , nfac   , nfabor , nfml   , nprfml , &
-   nnod   , lndfac , lndfbr , ncelbr ,                            &
-   nvar   , nscal  , nphas  , ncepdp , ncesmp ,                   &
-   nideve , nrdeve , nituse , nrtuse , iscala ,                   &
-   ifacel , ifabor , ifmfbr , ifmcel , iprfml ,                   &
-   ipnfac , nodfac , ipnfbr , nodfbr , icepdc , icetsm , itypsm , &
-   ia(iiconr) ,                                                   &
-   idevel , ituser , ia     ,                                     &
-   xyzcen , surfac , surfbo , cdgfac , cdgfbo , xyznod , volume , &
-   dt     , rtpa   , rtp    , propce , propfa , propfb ,          &
-   coefa  , coefb  , ckupdc , smacel ,                            &
-   smbrs  , rovsdt ,                                              &
-!        ------   ------
-   viscf  , viscb  , xam    ,                                     &
-   w1     , w2     , w3     , w4     , w5     ,                   &
-   w6     , w7     , w8     , w9     , drtp   , dam    ,          &
-   rdevel , rtuser , ra     )
-
-else
-
-!     Utilisateur standard
-
-  maxelt = max(ncelet,nfac,nfabor)
-  ils    = idebia
-  idbia1 = ils + maxelt
-  CALL IASIZE('COVOFI',IDBIA1)
-
-  call ustssc                                                     &
-  !==========
- ( idbia1 , idebra ,                                              &
-   ndim   , ncelet , ncel   , nfac   , nfabor , nfml   , nprfml , &
-   nnod   , lndfac , lndfbr , ncelbr ,                            &
-   nvar   , nscal  , nphas  , ncepdp , ncesmp ,                   &
-   nideve , nrdeve , nituse , nrtuse , iscala ,                   &
-   ifacel , ifabor , ifmfbr , ifmcel , iprfml , maxelt , ia(ils), &
-   ipnfac , nodfac , ipnfbr , nodfbr , icepdc , icetsm , itypsm , &
-   idevel , ituser , ia     ,                                     &
-   xyzcen , surfac , surfbo , cdgfac , cdgfbo , xyznod , volume , &
-   dt     , rtpa   , rtp    , propce , propfa , propfb ,          &
-   coefa  , coefb  , ckupdc , smacel ,                            &
-   smbrs  , rovsdt ,                                              &
-!        ------   ------
-   viscf  , viscb  , xam    ,                                     &
-   w1     , w2     , w3     , w4     , w5     ,                   &
-   w6     , w7     , w8     , w9     , drtp   , dam    ,          &
-   rdevel , rtuser , ra     )
-
-endif
+call ustssc &
+!==========
+( nvar   , nscal  , ncepdp , ncesmp ,                            &
+  iscala ,                                                       &
+  icepdc , icetsm , itypsm ,                                     &
+  dt     , rtpa   , rtp    , propce , propfa , propfb ,          &
+  coefa  , coefb  , ckupdc , smacel ,                            &
+  smbrs  , rovsdt )
 
 !     Si on extrapole les TS :
 !       SMBRS recoit -theta PROPCE du pas de temps precedent
@@ -422,41 +279,30 @@ endif
 if (ippmod(iphpar).ge.1) then
   call pptssc                                                     &
   !==========
- ( idebia , idebra ,                                              &
-   ndim   , ncelet , ncel   , nfac   , nfabor , nfml   , nprfml , &
-   nnod   , lndfac , lndfbr , ncelbr ,                            &
-   nvar   , nscal  , nphas  , ncepdp , ncesmp ,                   &
-   nideve , nrdeve , nituse , nrtuse , iscala ,                   &
-   ifacel , ifabor , ifmfbr , ifmcel , iprfml ,                   &
-   ipnfac , nodfac , ipnfbr , nodfbr , icepdc , icetsm , itypsm , &
-   idevel , ituser , ia     ,                                     &
-   xyzcen , surfac , surfbo , cdgfac , cdgfbo , xyznod , volume , &
+ ( nvar   , nscal  , ncepdp , ncesmp ,                            &
+   iscala ,                                                       &
+   icepdc , icetsm , itypsm ,                                     &
    dt     , rtpa   , rtp    , propce , propfa , propfb ,          &
    coefa  , coefb  , ckupdc , smacel ,                            &
-   smbrs  , rovsdt , tslagr ,                                     &
-!        ------   ------
-   viscf  , viscb  , xam    ,                                     &
-   w1     , w2     , w3     , w4     , w5     ,                   &
-   w6     , w7     , w8     , w9     , drtp   , dam    ,          &
-   rdevel , rtuser , ra     )
+   smbrs  , rovsdt , tslagr )
 endif
 
 ! --> Rayonnement
 !     Ordre 2 non pris en compte
 
-if ( iirayo.ge.1 .and. iphas.eq.irapha) then
+if ( iirayo.ge.1 ) then
 
-  if (iscal.eq.iscalt(iphas)) then
+  if (iscal.eq.iscalt) then
     call raysca                    &
     !==========
-  ( iscalt(iphas),ncelet,ncel,     &
+  ( iscalt,ncelet,ncel,     &
     smbrs, rovsdt,volume,propce )
   endif
 
   !-> Charbon pulverise
   !   Ordre 2 non pris en compte
-
-  if ( ippmod(icp3pl) .gt. 0 ) then
+  ! old model
+  if ( ippmod(icp3pl) .ge. 0 ) then
     if ( isca(iscal).ge.isca(ih2(1)) .and.       &
          isca(iscal).le.isca(ih2(nclacp)) ) then
 
@@ -467,17 +313,29 @@ if ( iirayo.ge.1 .and. iphas.eq.irapha) then
 
     endif
   endif
+  ! new model
+  if ( ippmod(iccoal) .ge. 0 ) then
+    if ( isca(iscal).ge.isca(ih2(1)) .and.       &
+         isca(iscal).le.isca(ih2(nclacp)) ) then
+!
+      call cs_coal_radst           &
+     !===============================
+          ( ivar  ,ncelet, ncel  ,                &
+            volume,propce,smbrs,rovsdt)
+!
+    endif
+  endif
 
   ! -> Fuel
   !    Ordre 2 non pris en compte
   !    Pour l'instant rayonnement non compatible avec Fuel
 
   if ( ippmod(icfuel) .ge. 0 ) then
-    if ( isca(iscal).ge.isca(ihlf(1)) .and.       &
-         isca(iscal).le.isca(ihlf(nclafu)) ) then
+    if ( isca(iscal).ge.isca(ih2(1)) .and.       &
+         isca(iscal).le.isca(ih2(nclafu)) ) then
 
-      call furays                  &
-      !==========
+      call cs_fuel_radst             &
+     !===============================
     ( ivar  ,ncelet, ncel  ,       &
       volume,rtpa  , propce,smbrs,rovsdt)
 
@@ -489,7 +347,7 @@ endif
 ! --> Lagrangien (couplage retour thermique)
 !     Ordre 2 non pris en compte
 
-if (iilagr.eq.2 .and. ltsthe.eq.1 .and. iphas.eq.ilphas)  then
+if (iilagr.eq.2 .and. ltsthe.eq.1)  then
 
   if (iscsth(iscal).eq.2) then
 
@@ -504,20 +362,20 @@ if (iilagr.eq.2 .and. ltsthe.eq.1 .and. iphas.eq.ilphas)  then
 
 !    --> Temperature  :
 
-    if (icp(iphas).eq.0) then
+    if (icp.eq.0) then
 
 !       --> Cp constant
 
       do iel = 1,ncel
-        smbrs (iel) = smbrs(iel)  + tslagr(iel,itste)/cp0(iphas)
+        smbrs (iel) = smbrs(iel)  + tslagr(iel,itste)/cp0
         rovsdt(iel) = rovsdt(iel) + max(tslagr(iel,itsti),zero)
       enddo
 
-    else if (icp(iphas).gt.0) then
+    else if (icp.gt.0) then
 
 !       --> Cp variable
 
-      iicp = ipproc(icp(iphas))
+      iicp = ipproc(icp)
       do iel = 1,ncel
         smbrs (iel) = smbrs(iel) + tslagr(iel,itste)              &
                                  / propce(iel,iicp)
@@ -542,7 +400,7 @@ if (ncesmp.gt.0) then
   !==========
  ( ncelet , ncel   , ncesmp , iiun   , isso2t(iscal) , thetv  ,   &
    icetsm , itypsm(1,ivar) ,                                      &
-   volume , rtpa(1,ivar) , smacel(1,ivar) , smacel(1,ipr(iphas)), &
+   volume , rtpa(1,ivar) , smacel(1,ivar) , smacel(1,ipr), &
    smbrs , rovsdt , w1)
 
 !       Si on extrapole les TS on met Gamma Pinj dans PROPCE
@@ -593,11 +451,14 @@ enddo
 
 if (itspdv.eq.1) then
 
-  if(itytur(iphas).eq.2.or.itytur(iphas).eq.3                     &
-       .or.iturb(iphas).eq.50 .or. iturb(iphas).eq.60) then
+  if(itytur.eq.2.or.itytur.eq.3                     &
+       .or.itytur.eq.5 .or. iturb.eq.60) then
 
-! Remarque : on a prevu la possibilite de scalaire associe non
-!  variable de calcul, mais des adaptations sont requises
+    ! Allocate a temporary array for the gradient reconstruction
+    allocate(grad(ncelet,3))
+
+    ! Remarque : on a prevu la possibilite de scalaire associe non
+    !  variable de calcul, mais des adaptations sont requises
 
     if(ivarsc.gt.0) then
       iii = ivarsc
@@ -614,28 +475,15 @@ if (itspdv.eq.1) then
     epsrgp = epsrgr(iii)
     climgp = climgr(iii)
     extrap = extrag(iii)
-    iphydp = 0
 
     call grdcel                                                   &
     !==========
- ( idebia , idebra ,                                              &
-   ndim   , ncelet , ncel   , nfac   , nfabor , nfml   , nprfml , &
-   nnod   , lndfac , lndfbr , ncelbr , nphas  ,                   &
-   nideve , nrdeve , nituse , nrtuse ,                            &
-   iii    , imrgra , inc    , iccocg , nswrgp , imligp , iphydp , &
+ ( iii    , imrgra , inc    , iccocg , nswrgp , imligp ,          &
    iwarnp , nfecra ,                                              &
    epsrgp , climgp , extrap ,                                     &
-   ifacel , ifabor , ifmfbr , ifmcel , iprfml ,                   &
-   ipnfac , nodfac , ipnfbr , nodfbr ,                            &
-   idevel , ituser , ia     ,                                     &
-   xyzcen , surfac , surfbo , cdgfac , cdgfbo , xyznod , volume , &
-   w1     , w1     , w1     ,                                     &
    rtpa(1,iii) , coefa(1,iclrtp(iii,icoef)) ,                     &
                  coefb(1,iclrtp(iii,icoef)) ,                     &
-   w1     , w2     , w3     ,                                     &
-!        ------   ------   ------
-   w4     , w5     , w6     ,                                     &
-   rdevel , rtuser , ra     )
+   grad   )
 
 !     Traitement de la production
 !     On utilise MAX(PROPCE,ZERO) car en LES dynamique on fait un clipping
@@ -648,12 +496,12 @@ if (itspdv.eq.1) then
     if (isso2t(iscal).gt.0) then
 !         On prend la viscosite a l'instant n, meme si elle est extrapolee
       ipcvso = ipcvst
-      if(iviext(iphas).gt.0) ipcvso = ipproc(ivista(iphas))
+      if(iviext.gt.0) ipcvso = ipproc(ivista)
       do iel = 1, ncel
         propce(iel,iptsca) = propce(iel,iptsca)                   &
              + 2.d0*max(propce(iel,ipcvso),zero)                  &
              *volume(iel)/sigmas(iscal)                           &
-               *(w1(iel)**2 + w2(iel)**2 + w3(iel)**2)
+             *(grad(iel,1)**2 + grad(iel,2)**2 + grad(iel,3)**2)
       enddo
 !       Sinon : dans SMBRS
     else
@@ -662,10 +510,13 @@ if (itspdv.eq.1) then
         smbrs(iel) = smbrs(iel)                                   &
              + 2.d0*max(propce(iel,ipcvso),zero)                  &
              *volume(iel)/sigmas(iscal)                           &
-             *(w1(iel)**2 + w2(iel)**2 + w3(iel)**2)
+             *(grad(iel,1)**2 + grad(iel,2)**2 + grad(iel,3)**2)
       enddo
     endif
 
+    ! Free memory
+    deallocate(grad)
+
 !     Traitement de la dissipation
     if (isso2t(iscal).gt.0) then
       thetap = thetv
@@ -673,16 +524,16 @@ if (itspdv.eq.1) then
       thetap = 1.d0
     endif
     do iel = 1, ncel
-      if(itytur(iphas).eq.2 .or. iturb(iphas).eq.50) then
-        xk     = rtpa(iel,ikiph)
-        xe     = rtpa(iel,ieiph)
-      elseif(itytur(iphas).eq.3) then
+      if(itytur.eq.2 .or. itytur.eq.5) then
+        xk     = rtpa(iel,ik)
+        xe     = rtpa(iel,iep)
+      elseif(itytur.eq.3) then
         xk     =                                                  &
-        0.5d0*(rtpa(iel,ir11ip)+rtpa(iel,ir22ip)+rtpa(iel,ir33ip))
-        xe     = rtpa(iel,ieiph)
-      elseif(iturb(iphas).eq.60) then
-        xk     = rtpa(iel,ikiph)
-        xe     = cmu*xk*rtpa(iel,iomgip)
+        0.5d0*(rtpa(iel,ir11)+rtpa(iel,ir22)+rtpa(iel,ir33))
+        xe     = rtpa(iel,iep)
+      elseif(iturb.eq.60) then
+        xk     = rtpa(iel,ik)
+        xe     = cmu*xk*rtpa(iel,iomg)
       endif
       rhovst = propce(iel,ipcrom)*xe/                             &
                  (xk * rvarfl(iscal))*volume(iel)
@@ -724,17 +575,9 @@ if( idiff(ivar).ge. 1 ) then
   endif
   call viscfa                                                     &
   !==========
- ( idebia , idebra ,                                              &
-   ndim   , ncelet , ncel   , nfac   , nfabor , nfml   , nprfml , &
-   nnod   , lndfac , lndfbr , ncelbr ,                            &
-   nideve , nrdeve , nituse , nrtuse , imvisf ,                   &
-   ifacel , ifabor , ifmfbr , ifmcel , iprfml ,                   &
-   ipnfac , nodfac , ipnfbr , nodfbr ,                            &
-   idevel , ituser , ia     ,                                     &
-   xyzcen , surfac , surfbo , cdgfac , cdgfbo , xyznod , volume , &
+ ( imvisf ,                                                       &
    w1     ,                                                       &
-   viscf  , viscb  ,                                              &
-   rdevel , rtuser , ra     )
+   viscf  , viscb  )
 
 else
 
@@ -779,31 +622,20 @@ relaxp = relaxv(ivar)
 
 call codits                                                       &
 !==========
- ( idebia , idebra ,                                              &
-   ndim   , ncelet , ncel   , nfac   , nfabor , nfml   , nprfml , &
-   nnod   , lndfac , lndfbr , ncelbr ,                            &
-   nvar   , nscal  , nphas  ,                                     &
-   nideve , nrdeve , nituse , nrtuse ,                            &
+ ( nvar   , nscal  ,                                              &
    idtvar , ivar   , iconvp , idiffp , ireslp , ndircp , nitmap , &
    imrgra , nswrsp , nswrgp , imligp , ircflp ,                   &
    ischcp , isstpp , iescap ,                                     &
    imgrp  , ncymxp , nitmfp , ipp    , iwarnp ,                   &
    blencp , epsilp , epsrsp , epsrgp , climgp , extrap ,          &
    relaxp , thetv  ,                                              &
-   ifacel , ifabor , ifmfbr , ifmcel , iprfml ,                   &
-   ipnfac , nodfac , ipnfbr , nodfbr ,                            &
-   idevel , ituser , ia     ,                                     &
-   xyzcen , surfac , surfbo , cdgfac , cdgfbo , xyznod , volume , &
    rtpa(1,ivar)    , rtpa(1,ivar)    ,                            &
                      coefa(1,iclvar) , coefb(1,iclvar) ,          &
                      coefa(1,iclvaf) , coefb(1,iclvaf) ,          &
                      propfa(1,iflmas), propfb(1,iflmab),          &
    viscf  , viscb  , viscf  , viscb  ,                            &
    rovsdt , smbrs  , rtp(1,ivar)     ,                            &
-   dam    , xam    , drtp   ,                                     &
-   w1     , w2     , w3     , w4     , w5     ,                   &
-   w6     , w7     , w8     , w9     ,                            &
-   rdevel , rtuser , ra     )
+   rvoid  )
 
 !===============================================================================
 ! 4. IMPRESSIONS ET CLIPPINGS
@@ -841,6 +673,9 @@ if (iwarni(ivar).ge.2) then
   write(nfecra,1200)chaine(1:8) ,sclnor
 endif
 
+! Free memory
+deallocate(w1)
+
 !--------
 ! FORMATS
 !--------
