@@ -1,27 +1,22 @@
 !-------------------------------------------------------------------------------
 
-!     This file is part of the Code_Saturne Kernel, element of the
-!     Code_Saturne CFD tool.
-
-!     Copyright (C) 1998-2009 EDF S.A., France
-
-!     contact: saturne-support@edf.fr
-
-!     The Code_Saturne Kernel is free software; you can redistribute it
-!     and/or modify it under the terms of the GNU General Public License
-!     as published by the Free Software Foundation; either version 2 of
-!     the License, or (at your option) any later version.
-
-!     The Code_Saturne Kernel is distributed in the hope that it will be
-!     useful, but WITHOUT ANY WARRANTY; without even the implied warranty
-!     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-!     GNU General Public License for more details.
-
-!     You should have received a copy of the GNU General Public License
-!     along with the Code_Saturne Kernel; if not, write to the
-!     Free Software Foundation, Inc.,
-!     51 Franklin St, Fifth Floor,
-!     Boston, MA  02110-1301  USA
+! This file is part of Code_Saturne, a general-purpose CFD tool.
+!
+! Copyright (C) 1998-2011 EDF S.A.
+!
+! This program is free software; you can redistribute it and/or modify it under
+! the terms of the GNU General Public License as published by the Free Software
+! Foundation; either version 2 of the License, or (at your option) any later
+! version.
+!
+! This program is distributed in the hope that it will be useful, but WITHOUT
+! ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+! FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+! details.
+!
+! You should have received a copy of the GNU General Public License along with
+! this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
+! Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 !-------------------------------------------------------------------------------
 
@@ -49,36 +44,35 @@ subroutine iniini
 !            --- tableau de travail
 !===============================================================================
 
+!===============================================================================
+! Module files
+!===============================================================================
+
+use paramx
+use cstnum
+use dimens
+use numvar
+use optcal
+use cstphy
+use entsor
+use pointe
+use albase
+use alstru
+use alaste
+use parall
+use period
+use mltgrd
+use ihmpre
+use cplsat
+use mesh
+
+!===============================================================================
+
 implicit none
 
-!===============================================================================
-! Common blocks
-!===============================================================================
-
-include "paramx.h"
-include "cstnum.h"
-include "dimens.h"
-include "numvar.h"
-include "optcal.h"
-include "cstphy.h"
-include "entsor.h"
-include "pointe.h"
-include "vector.h"
-include "albase.h"
-include "alstru.h"
-include "alaste.h"
-include "period.h"
-include "parall.h"
-include "mltgrd.h"
-include "ihmpre.h"
-include "matiss.h"
-include "cplsat.h"
-
-!===============================================================================
-
 ! Local variables
 
-integer          ii, jj, ivar, iscal, iphas, iprop, iest, imom
+integer          ii, jj, ivar, iscal, iprop, iest, imom
 integer          istr
 
 !===============================================================================
@@ -118,7 +112,7 @@ write(nfecra, 900)
 #endif
 
 !===============================================================================
-! 2. ENTREES SORTIES entsor.h
+! 2. ENTREES SORTIES entsor.f90
 !===============================================================================
 
 ! ---> Impressions standard
@@ -129,44 +123,18 @@ enddo
 
 ! ---> NFECRA vaut 6 par defaut ou 9 en parallele (CSINIT)
 
-! ---> Geometrie
-
-impgeo = 10
-FICGEO = 'geomet'
-
-! ---> Fichier amont
-
-FICAMO = 'suiamo'
-FICAMX = 'suiamx'
-
-!    Module thermique 1D en paroi
-FICMT1 = 't1damo'
-
-!    Module aerorefrigerants
-FICMCT = 'ctwamo'
-
 !    Methode des vortex : on utilise la meme unite
 !                  Pour le fichier de donnees, on specifie l'unite ici, mais le
 !                  nom est laisse dans usvort. On utilise 20 et pas 11
 !                  car en cas d'entree multiple, les deux fichiers doivent etre
 !                  ouverts en meme temps dans VORINI
 impmvo = 11
-FICMVO = 'voramo'
 impdvo = 20
 
-!    Rayonnement
-FICAMR = 'rayamo'
-
-!    Lagrangien
-!      Fichier suite calcul
-FICAML = 'lagamo'
-!      Fichier suite statistique
-FICMLS = 'lasamo'
-
 ! ---> Fichier stop
 
 impstp = 12
-FICSTP = 'ficstp'
+ficstp = 'ficstp'
 
 ! ---> Fichier aval
 
@@ -176,90 +144,27 @@ FICSTP = 'ficstp'
 !              0    : par defaut (4 fois par calcul)
 !              > 0  : periode
 
-
-FICAVA = 'suiava'
-FICAVX = 'suiavx'
-
 ntsuit = 0
 
-!    Module thermique 1D en paroi
-FICVT1 = 't1dava'
-
-!    Module aerorefrigerants
-FICVCT = 'ctwava'
-
 !    Methode des vortex : on utilise la meme unite
 !                  et le format ascii obligatoirement
 !                  (pas de detection automatique, fichiers de taille faible)
 impvvo = 20
-FICVVO = 'vorava'
-
-!    Rayonnement : on utilise la meme unite (pour le moment)
-!                  et le meme format (voir modini)
-FICAVR = 'rayava'
-
-!    Lagrangien
-!      Fichier suite calcul
-FICAVL = 'lagava'
-!      Fichier suite statistique
-FICVLS = 'lasava'
 
 !    Fichier listing Lagrangien
 
 implal = 80
-FICLAL = 'listla'
+ficlal = 'listla'
 ntlal  = 1
 
-!    Fichier historique Lagrangien
-
-impli1 = 81
-impli2 = 82
-
-
 !    Post traitement
-
-!       ICHRVL : Post traitement du domaine fluide
-!         (1 oui, 0 non)
-!       ICHRBO : Post traitement du bord du domaine
-!         (1 oui, 0 non)
-!       ICHRSY : Post traitement des zones couplees avec SYRTHES
-!         (1 oui, 0 non)
-!       ICHRZE: Post traitement des zones d'change aerorefrigerants
-!         (1 oui, 0 non)
-
-!       ICHRMD : indique si les maillages ecrits seront :
-!         0 : fixes,
-!         1 : deformables a topologie constante,
-!         2 : modifiables (pourront etre completement redefinis en
-!             cours de calcul via le sous-programme USMPST).
-!        10 : comme INDMOD = 0, avec champ de dplacement
-!        11 : comme INDMOD = 1, avec champ de dplacement
-!        12 : comme INDMOD = 2, avec champ de dplacement
-
-!       NTCHR  : Periode   de sortie Post
-!         -1 : une seule sortie a la fin
-!         >0 : periode
 !       ICHRVR  : Variables a sortir
 !         (1 oui, 0 non, sinon : non initialise)
 
-ichrvl = 1
-ichrbo = 0
-ichrsy = 0
-ichrze = 0
-
-ichrmd = 0
-ntchr  = -1
-
 do ii = 1, nvppmx
   ichrvr(ii )   = -999
 enddo
 
-!       FMTCHR : format ('EnSight Gold', 'MED_fichier', ou 'CGNS')
-!       OPTCHR : options associees au format de sortie
-
-FMTCHR = 'EnSight Gold'
-OPTCHR = 'binary'
-
 ! ---> Fichier thermochinie
 !        FPP : utilisateur
 !        JNF : Janaf
@@ -268,24 +173,19 @@ OPTCHR = 'binary'
 !      En prime, INDJON (janaf=1 ou non=0)
 
 impfpp = 25
-FICFPP = 'dp_tch'
+ficfpp = 'dp_thch'
 
 impjnf = impfpp
-FICJNF = 'JANAF'
+ficjnf = 'JANAF'
 
 indjon = 1
 
 ! ---> Fichiers module atmospherique
 impmet = 26
-FICMET = 'meteo'
-
-! ---> Fichier resuMatisse
-impmat = 28
-
+ficmet = 'meteo'
 
 ! ---> Fichiers historiques
 
-!     IMPHIS : fichier stock + unite d'ecriture des variables
 !     EMPHIS : EMPlacement
 !     PREHIS : PREfixe
 !     EXTHIS : EXTension
@@ -294,44 +194,41 @@ impmat = 28
 !     IMPSTH : fichier stock + unite d'ecriture des variables
 !              des structures mobiles
 
-imphis(1) = 30
-imphis(2) = 31
-impsth(1) = 32
-!     Les fichiers d'ecriture ne sont pas ouverts en meme temps
-impsth(2) = imphis(2)
+impsth(1) = 30
+impsth(2) = 31
 
-emphis = './'
+emphis = 'monitoring/'
 prehis = 'probes_'
-exthis = 'dat'
 
 do ii = 1, nushmx
   impush(ii) = 32+ii
   if (irangp .le. 0) then
-     WRITE(FICUSH(II),'(1A3,I3.3)')'ush',II
+    write(ficush(ii),'(1a3,i3.3)')'ush',ii
   else
-     WRITE(FICUSH(II),'(1A3,I3.3,1A3,I4.4)')'ush',II,             &
-                                            '.n_',IRANGP+1
+    write(ficush(ii),'(1a3,i3.3,1a3,i4.4)')'ush',ii,'.n_',irangp+1
   endif
 enddo
 
-!     NCAPT  : nombre de sondes total (limite a NCAPTM)
-!     NTHIST : Periode de sortie
-!         ( > 0 ou -1 (jamais))
-!     NTHSAV : Periode de sauvegarde
-!         ( > 0 ou -1 (a la fin) ou 0 (NTMABS/4))
-!     IHISVR : nb de sonde et numero par variable
-!         (-999 non initialise)
-!     IHISTR : indicateur d'ecriture des historiques des structures
-!              mobiles internes (=0 ou 1)
-!     NCAPT  : nombre de sondes total (limite a NCAPTM)
-!     NODCAP : element correspondant aux sondes
-!     NDRCAP : rang du processus contenant NODCAP (parallelisme)
-!     XYZCAP : position demandee des sondes
+! tplfmt : time plot format (1: .dat, 2: .csv, 3: both)
+! ncapt  : nombre de sondes total (limite a ncaptm)
+! nthist : periode de sortie (> 0 ou -1 (jamais))
+! frhist : frequence de sortie, en secondes (prioritaire sur nthist si > 0)
+! nthsav : periode de sauvegarde (> 0 (fichiers ouverts et refermes) ou -1 )
+! ihisvr : nb de sonde et numero par variable (-999 non initialise)
+! ihistr : indicateur d'ecriture des historiques des structures
+!          mobiles internes (=0 ou 1)
+! ncapt  : nombre de sondes total (limite a ncaptm)
+! nodcap : element correspondant aux sondes
+! ndrcap : rang du processus contenant nodcap (parallelisme)
+! xyzcap : position demandee des sondes
+! tplflw : time plot flush wall-time interval (none if <= 0)
 
+tplfmt = 1
 ncapt = 0
 
 nthist = 1
-nthsav = 0
+frhist = -1.d0
+nthsav = -1
 
 do ii = 1, nvppmx
   do jj = 1, ncaptm+1
@@ -352,7 +249,7 @@ do ii = 1, ncaptm
   xyzcap(3,ii) = 0.d0
 enddo
 
-
+tplflw = -1.d0
 
 ! ---> Fichiers Lagrangiens
 
@@ -388,10 +285,9 @@ impla5(15) = 68
 do ii = 1, nusrmx
   impusr(ii) = 69+ii
   if (irangp .le. 0) then
-     WRITE(FICUSR(II),'(1A4,I2.2)')'usrf',II
+    write(ficusr(ii),'(1a4,i2.2)')'usrf',ii
   else
-     WRITE(FICUSR(II),'(1A4,I2.2,1A3,I4.4)')'usrf',II,            &
-                                            '.n_',IRANGP+1
+    write(ficusr(ii),'(1a4,i2.2,1a3,i4.4)')'usrf',ii,'.n_',irangp+1
   endif
 enddo
 
@@ -423,7 +319,7 @@ do ii = 1, nvppmx
 enddo
 
 do ii = 1, nvppmx
-  NOMVAR(II)    = ' '
+  nomvar(ii)    = ' '
   ilisvr(ii)    = -999
   itrsvr(ii)    = 0
 enddo
@@ -466,11 +362,7 @@ enddo
 
 ! ---> Post traitement automatique (bord)
 
-if (ifoenv .eq. 0) then
-  ipstdv = 0
-else
-  ipstdv = ipstyp*ipstcl*ipstft*ipstfo
-endif
+ipstdv = ipstyp*ipstcl*ipstft*ipstfo
 
 
 ! ---> CPU
@@ -481,73 +373,54 @@ endif
 tmarus = -1.d0
 
 
-! Ici entsor.h est completement initialise
+! Ici entsor.f90 est completement initialise
 
 !===============================================================================
-! 3. DIMENSIONS DE dimens.h (GEOMETRIE, sauf NCELBR)
+! 3. DIMENSIONS DE dimens.f90 (GEOMETRIE, sauf NCELBR)
 !===============================================================================
 
 !---> GEOMETRIE
 
 !---> LECTURE SELON UTILISATION PREPROCESSEUR OU ANCIEN FICHIER
 
-   ndim   = 0
-   ncel   = 0
-   ncelet = 0
-   nfac   = 0
-   nfabor = 0
-   nfml   = 0
-   nprfml = 0
-   nnod   = 0
-   lndfac = 0
-   lndfbr = 0
-   ncelbr = 0
+ncel   = 0
+ncelet = 0
+nfac   = 0
+nfabor = 0
+nfml   = 0
+nprfml = 0
+nnod   = 0
+lndfac = 0
+lndfbr = 0
+ncelbr = 0
 
-   ncelgb = 0
-   nfacgb = 0
-   nfbrgb = 0
-   nsomgb = 0
+ncelgb = 0
+nfacgb = 0
+nfbrgb = 0
+nsomgb = 0
 
 ! Par defaut, on suppose qu'il n'y a pas de periodicite
-   iperio = 0
-   iperot = 0
+iperio = 0
+iperot = 0
 
-if (ifoenv .eq. 0) then
+! Lecture des dimensions du maillage.
+! Les tableaux seront lus apres allocation.
+! On initialise les dimensions a 0 avant la lecture, certaines
+!   rubriques etant optionnelles.
 
-!        NECESSITE FICGEO
-
-   call ledgeo                                                    &
-   !==========
-        ( ndim   , ncelet , ncel   , nfac   , nfabor ,            &
-          nprfml , nfml   , nnod   , lndfac , lndfbr )
-
-
-! --- Pas de decoupage en parallele prevu sans preprocesseur.
-!     NCELET=NCEL est fait dans ledgeo
-
-else if (ifoenv .eq. 1) then
-
-! --- PASSAGE DANS LEDEVI :
-!        On ne lit ici que les dimensions.
-!        Les tableaux seront lus apres allocation.
-!        On initialise les dimensions a 0 avant la lecture, certaines
-!          rubriques etant optionnelles.
-
-   call ledevi                                                    &
-   !==========
-   ( ndim   , nfml   , nprfml , iperio , iperot )
-
-endif
+call ledevi(ndim, nfml, nprfml, iperio, iperot)
+!==========
 
+call tstjpe(iperio, iperot)
+!==========
 
 !===============================================================================
-! 4. DIMENSIONS de dimens.h (PHYSIQUE)
+! 4. DIMENSIONS de dimens.f90 (PHYSIQUE)
 !===============================================================================
 
-! --- Nombre de phases, de scalaires, de scalaires a diffusivite
+! --- Nombre de scalaires, de scalaires a diffusivite
 !            variable, de variables
 
-nphas  = 0
 nscal  = 0
 nscaus = 0
 nscapp = 0
@@ -566,27 +439,27 @@ ncofab = 0
 
 
 !===============================================================================
-! 5. POSITION DES VARIABLES DE numvar.h
+! 5. POSITION DES VARIABLES DE numvar.f90
 !===============================================================================
 
 ! --- Variables de calcul resolues (RTP, RTPA)
 
-do iphas = 1, nphsmx
-  ipr   (iphas) = 0
-  iu    (iphas) = 0
-  iv    (iphas) = 0
-  iw    (iphas) = 0
-  ik    (iphas) = 0
-  iep   (iphas) = 0
-  ir11  (iphas) = 0
-  ir22  (iphas) = 0
-  ir33  (iphas) = 0
-  ir12  (iphas) = 0
-  ir13  (iphas) = 0
-  ir23  (iphas) = 0
-  iphi  (iphas) = 0
-  ifb   (iphas) = 0
-enddo
+ipr    = 0
+iu     = 0
+iv     = 0
+iw     = 0
+ik     = 0
+iep    = 0
+ir11   = 0
+ir22   = 0
+ir33   = 0
+ir12   = 0
+ir13   = 0
+ir23   = 0
+iphi   = 0
+ifb    = 0
+ial    = 0
+inusa  = 0
 
 do iscal = 1, nscamx
   isca  (iscal) = 0
@@ -606,15 +479,13 @@ do iprop  = 1, npromx
   ipprob(iprop) = 0
 enddo
 
-do iphas = 1, nphsmx
-  irom  (iphas) = 0
-  iviscl(iphas) = 0
-  ivisct(iphas) = 0
-  icour (iphas) = 0
-  ifour (iphas) = 0
-  icp   (iphas) = 0
-  iprtot(iphas) = 0
-enddo
+irom   = 0
+iviscl = 0
+ivisct = 0
+icour  = 0
+ifour  = 0
+icp    = 0
+iprtot = 0
 
 do iscal = 1, nscamx
   ivisls(iscal) = -1
@@ -638,73 +509,7 @@ enddo
 ! --- Ici tout numvar est initialise.
 
 !===============================================================================
-! 6. POSITION DES VARIABLES DE pointe.h
-!===============================================================================
-
-! --- Geometrie
-
-iicelb = 0
-isrfan = 0
-isrfbn = 0
-idist  = 0
-idistb = 0
-ipond  = 0
-idijpf = 0
-idiipb = 0
-idofij = 0
-
-! --- Auxiliaires independants du nb phases
-
-icocg  = 0
-icocgb = 0
-itpuco = 0
-idipar = 0
-iyppar = 0
-nfpt1d = 0
-nmxt1d = 0
-inppt1 = 0
-iifpt1 = 0
-iiclt1 = 0
-ieppt1 = 0
-irgpt1 = 0
-itppt1 = 0
-itept1 = 0
-ihept1 = 0
-ifept1 = 0
-ixlmt1 = 0
-ircpt1 = 0
-idtpt1 = 0
-
-! --- Autres auxiliaires dependant du nb de phases
-
-iitypf = 0
-iitrif = 0
-iisymp = 0
-
-do iphas = 1, nphsmx
-  iifapa(iphas) = 0
-  ncepdc(iphas) = 0
-  iicepd(iphas) = 0
-  ickupd(iphas) = 0
-  ncetsm(iphas) = 0
-  iicesm(iphas) = 0
-  iitpsm(iphas) = 0
-  ismace(iphas) = 0
-  is2kw (iphas) = 0
-  idvukw(iphas) = 0
-enddo
-
-! --- Auxiliaires pour la periodicite
-
-idudxy =0
-idrdxy =0
-iwdudx =0
-iwdrdx =0
-
-! --- Ici tout pointe.h est initialise
-
-!===============================================================================
-! 7. OPTIONS DU CALCUL : TABLEAUX DE optcal.h
+! 6. OPTIONS DU CALCUL : TABLEAUX DE optcal.f90
 !===============================================================================
 
 ! --- Definition des equations
@@ -735,9 +540,7 @@ enddo
 !     si on veut, on peut en rajouter.
 !     Cette variable conditionne toutes les autres de maniere automatique,
 !     pour definir des schemas coherents dans modini.
-do iphas = 1, nphsmx
-  ischtp(iphas) = -999
-enddo
+ischtp = -999
 
 !   -- Variables
 !     Pour un schema centre (en n+1/2) il faut prendre theta = 0.5
@@ -751,14 +554,12 @@ do ii = 1, nvarmx
   thetav(ii) =-999.d0
 enddo
 
-do iphas = 1, nphsmx
-
 !   -- Flux de masse (-999 = non initialise)
 !     = 1 Standard d'ordre 1 (THETFL = -999 inutile)
 !     = 0 Explicite (THETFL = 0)
 !     = 2 Ordre deux (THETFL = 0.5)
-  istmpf(iphas) = -999
-  thetfl(iphas) =-999.d0
+istmpf = -999
+thetfl =-999.d0
 
 !   -- Termes sources Navier Stokes
 !     Pour les termes sources explicites en std, I..EXT definit
@@ -775,8 +576,8 @@ do iphas = 1, nphsmx
 !     > 0 utilisation du thetav
 !     Noter cpdt que le TS d'acc. masse n'est pas regi par I..EXT
 !       (il suit bilsc2)
-  isno2t(iphas) = -999
-  thetsn(iphas) =-999.d0
+isno2t = -999
+thetsn =-999.d0
 !   -- Termes sources Grandeurs turbulentes
 !     Pour les termes sources explicites en std, I..EXT definit
 !       l'extrapolation -theta ancien + (1+theta) nouveau
@@ -792,8 +593,8 @@ do iphas = 1, nphsmx
 !     > 0 utilisation du thetav
 !     Noter cpdt que le TS d'acc. masse n'est pas regi par I..EXT
 !       (il suit bilsc2)
-  isto2t(iphas) = -999
-  thetst(iphas) =-999.d0
+isto2t = -999
+thetst =-999.d0
 
 !    -- Proprietes physiques
 !     I..EXT definit l'extrapolation -theta ancien + (1+theta) nouveau
@@ -807,26 +608,24 @@ do iphas = 1, nphsmx
 !       fichier suite portant les valeurs adaptees)
 
 !     Masse volumique
-  iroext(iphas) = -999
-  thetro(iphas) = -999.d0
-  initro(iphas) = 0
+iroext = -999
+thetro = -999.d0
+initro = 0
 !     Viscosite totale
-  iviext(iphas) = -999
-  thetvi(iphas) = -999.d0
-  initvi(iphas) = 0
+iviext = -999
+thetvi = -999.d0
+initvi = 0
 !     Chaleur specifique
-  icpext(iphas) = -999
-  thetcp(iphas) = -999.d0
-  initcp(iphas) = 0
+icpext = -999
+thetcp = -999.d0
+initcp = 0
 
 !   -- Convergence point fixe vitesse pression
-  epsup (iphas) = 1.d-5
+epsup  = 1.d-5
 
 !   -- Tab de travail pour normes de navsto
-  xnrmu0(iphas) = 0.d0
-  xnrmu (iphas) = 0.d0
-
-enddo
+xnrmu0 = 0.d0
+xnrmu  = 0.d0
 
 !   -- Nb d'iter point fixe vitesse pression
 nterup = 1
@@ -946,6 +745,13 @@ enddo
 ncegrm = 30
 ngrmax = 25
 
+! --- Parallel merging parameters
+
+mltmmn = 300
+mltmgl = 500
+mltmmr = 1
+mltmst = 1
+
 rlxp1 = 0.95d0
 
 ! --- Suite de calcul
@@ -1002,7 +808,7 @@ do ii = 1, nvarmx
   cdtvar(ii) = 1.d0
   relaxv(ii) =-999.d0
 enddo
-relxst = 0.9d0
+relxst = 0.7d0
 
 
 !     Par defaut, pas de limitation du pas de temps liee aux
@@ -1015,46 +821,43 @@ iptlro = 0
 !     En fait on n'a pas besoin d'initialiser ITYTUR (cf. varpos)
 !     On suppose qu'il n'y a pas de temperature
 
-do iphas = 1, nphsmx
-  iturb (iphas) =-999
-  itytur(iphas) =-999
-  iscalt(iphas) =-1
+iturb  =-999
+itytur =-999
+iscalt =-1
 ! Parfois, IGRHOK=1 donne des vecteurs non physiques en paroi
-!        IGRHOK(IPHAS) = 1
-  igrhok(iphas) = 0
-  igrake(iphas) = 1
-  ideuch(iphas) =-999
-  ilogpo(iphas) = 1
-  iclkep(iphas) = 0
-  ikecou(iphas) =-999
-  irijnu(iphas) = 0
-  irijrb(iphas) = 0
-  irijec(iphas) = 0
-  igrari(iphas) = 1
-  idifre(iphas) = 1
-  iclsyr(iphas) = 0
-  iclptr(iphas) = 0
-  idries(iphas) =-1
-enddo
-
+!        IGRHOK = 1
+igrhok = 0
+igrake = 1
+ideuch =-999
+ilogpo = 1
+iclkep = 0
+ikecou =-999
+irijnu = 0
+irijrb = 0
+irijec = 0
+igrari = 1
+idifre = 1
+iclsyr = 0
+iclptr = 0
+idries =-1
 
 ! --- Viscosite secondaire
 
-do iphas = 1, nphsmx
-  ivisse(iphas) = 1
-enddo
+ivisse = 1
 
 ! --- Stokes
 !     On suppose que l'on traite l'etape de Stokes
 
 iprco  = 1
-do iphas = 1, nphsmx
-  irevmc(iphas) = 0
-  arak  (iphas) = 1.d0
-enddo
+irevmc = 0
+arak   = 1.d0
 !     indicateur developpeur temporaire sur le test de conv resolp
 irnpnw = 1
 
+! --- Resolution couplee des composantes de vitesse
+
+ivelco = 0
+
 ! --- Couplage U-P
 !       Non active par defaut
 
@@ -1084,10 +887,8 @@ imvisf = 0
 !       Sera calcule apres usclim.
 
 do ii = 1, ntypmx
-  do iphas = 1, nphsmx
-    idebty(ii,iphas) = 0
-    ifinty(ii,iphas) = 0
-  enddo
+  idebty(ii) = 0
+  ifinty(ii) = 0
 enddo
 
 ! --- Traitement de la temperature pour couplage SYRTHES
@@ -1137,33 +938,27 @@ enddo
 
 !     On evalue l'estimateur IEST selon les valeurs de IESCAL
 
-!        IESCAL(IEST,IPHAS) = 0 : l'estimateur IEST n'est pas calcule
-!        IESCAL(IEST,IPHAS) = 1 : l'estimateur IEST   est     calcule,
+!        IESCAL(IEST) = 0 : l'estimateur IEST n'est pas calcule
+!        IESCAL(IEST) = 1 : l'estimateur IEST   est     calcule,
 !                         sans contribution du volume  (on prend abs(I))
-!        IESCAL(IEST,IPHAS) = 2 : l'estimateur IEST   est     calcule,
+!        IESCAL(IEST) = 2 : l'estimateur IEST   est     calcule,
 !                         avec contribution du volume ("norme L2")
 !                         soit abs(I)*SQRT(Volume_cellule),
 !                         sauf pour IESCOR : on calcule abs(I)*Volume_cellule
 !                         pour mesurer l'ecart en kg/s
 
 
-do iphas = 1, nphsmx
-  do iest = 1, nestmx
-    iescal(iest,iphas) = 0
-  enddo
+do iest = 1, nestmx
+  iescal(iest) = 0
 enddo
 
 ! --- Somme de NCEPDC (pour les calculs paralleles)
 
-do iphas = 1, nphsmx
-  ncpdct(iphas) = 0
-enddo
+ncpdct = 0
 
 ! --- Somme de NCETSM (pour les calculs paralleles)
 
-do iphas = 1, nphsmx
-  nctsmt(iphas) = 0
-enddo
+nctsmt = 0
 
 ! --- Somme de NFPT1D (pour les calculs paralleles)
 
@@ -1241,10 +1036,10 @@ ivrtex = 0
 ! --- Calcul des efforts aux parois
 ineedf = 0
 
-! --- Ici tout optcal.h est initialise
+! --- Ici tout optcal.f90 est initialise
 
 !===============================================================================
-! 8. TABLEAUX DE cstphy.h
+! 7. TABLEAUX DE cstphy.f90
 !===============================================================================
 
 ! --- Gravite
@@ -1278,28 +1073,24 @@ omegaz = 0.d0
 !         (du moins, on l'espere...) : on adopte la meme methode pour la
 !         symetrie.
 
-do iphas = 1, nphsmx
-  irovar(iphas) = -1
-  ivivar(iphas) = -1
-  ro0   (iphas) = -grand*10.d0
-  viscl0(iphas) = -grand*10.d0
-  p0    (iphas) = 1.013d5
-  pred0 (iphas) = 0.d0
-  xyzp0(1,iphas)= -rinfin
-  xyzp0(2,iphas)= -rinfin
-  xyzp0(3,iphas)= -rinfin
-  ixyzp0(iphas) = -1
-  t0    (iphas) = 0.d0
-  cp0   (iphas) = -grand*10.d0
-enddo
+irovar = -1
+ivivar = -1
+ro0    = -grand*10.d0
+viscl0 = -grand*10.d0
+p0     = 1.013d5
+pred0  = 0.d0
+xyzp0(1)= -rinfin
+xyzp0(2)= -rinfin
+xyzp0(3)= -rinfin
+ixyzp0 = -1
+t0     = 0.d0
+cp0    = -grand*10.d0
 
 ! --- Turbulence
 !     YPLULI est mis a -GRAND*10. Si l'utilisateur ne l'a pas specifie dans usini1, on
 !     modifie sa valeur dans modini (10.88 avec les lois de paroi invariantes,
 !     1/kappa sinon)
-do iphas = 1, nphsmx
-  ypluli(iphas) = -grand*10.d0
-enddo
+ypluli = -grand*10.d0
 xkappa  = 0.42d0
 cstlog  = 5.2d0
 
@@ -1338,16 +1129,14 @@ cssgr5  = 0.20d0
 cssge2  = 1.83d0
 
 !   pour la LES
-do iphas = 1, nphsmx
-  xlesfl(iphas) = 2.d0
-  ales(iphas)   = 1.d0
-  bles(iphas)   = 1.d0/3.d0
-  csmago(iphas) = 0.065d0
-  cwale(iphas)  = 0.25d0
-  xlesfd(iphas) = 1.5d0
-  smagmx(iphas) = 10.d0*csmago(iphas)
-  cdries(iphas) = 26.d0
-enddo
+xlesfl = 2.d0
+ales   = 1.d0
+bles   = 1.d0/3.d0
+csmago = 0.065d0
+cwale  = 0.25d0
+xlesfd = 1.5d0
+smagmx = 10.d0*csmago
+cdries = 26.d0
 
 !   pour le v2f phi-model
 cv2fa1 = 0.05d0
@@ -1359,6 +1148,19 @@ cv2fct = 6.d0
 cv2fcl = 0.25d0
 cv2fet = 110.d0
 
+!   pour le v2f BL-v2/k (previously known as v2-f phi-alpha, hence the cpal**)
+cpale1 = 1.44d0
+cpale2 = 1.83d0
+cpale3 = 2.3d0
+cpale4 = 0.4d0
+cpalse = 1.5d0
+cpalmu = 0.22d0
+cpalct = 4.d0
+cpalcl = 0.164d0
+cpalet = 75.d0
+cpalc1 = 1.7d0
+cpalc2 = 0.9d0
+
 !   pour le modele k-omega sst
 ckwsk1 = 1.d0/0.85d0
 ckwsk2 = 1.d0
@@ -1371,29 +1173,32 @@ ckwgm2 = ckwbt2/cmu - xkappa**2/(ckwsw2*sqrt(cmu))
 ckwa1  = 0.31d0
 ckwc1  = 10.d0
 
+!   pour le modele de Spalart Allmaras
+csab1    = 0.1355d0
+csab2    = 0.622d0
+csav1    = 7.1d0
+csasig   = 2.d0/3.d0
+csaw1    = csab1/xkappa**2 + 1.d0/csasig*(1.d0 + csab2)
+csaw2    = 0.3d0
+csaw3    = 2.d0
+
 !   echelle de longueur negative, recalculee par la suite
 !    ou entree par l'utilisateur
-do iphas = 1, nphsmx
-  almax(iphas)   = -grand*10.d0
-enddo
+almax   = -grand*10.d0
 
 !   vitesse de reference pour l'initialisation de la turbulence
 !    doit etre entree par l'utilisateur, sauf s'il initialise lui-meme
 !    la turbulence.
-do iphas = 1, nphsmx
-  uref(iphas)    = -grand*10.d0
-enddo
+uref    = -grand*10.d0
 
 !   longueur caracteristique pour le modele de longueur de melange
 !    doit etre entree par l'utilisateur
-do iphas = 1, nphsmx
-  xlomlg(iphas)    = -grand*10.d0
-enddo
+  xlomlg    = -grand*10.d0
 
 ! --- Scalaires
 !       L'utilisateur devra remplir VISLS0
 !       On remplira plus tard, selon les modifs utilisateur,
-!         ISCSTH, IPHSCA
+!         ISCSTH
 !       On modifiera eventuellement plus tard, selon modifs utilisateur,
 !         IVISLS, ce dernier a ete initialise plus haut
 !       On donne la valeur par defaut pour les autres
@@ -1405,7 +1210,6 @@ do iscal = 1, nscamx
   iscsth(iscal) =-10
   iclvfl(iscal) = -1
   iscavr(iscal) = 0
-  iphsca(iscal) = 0
   scamin(iscal) =-grand
   scamax(iscal) =+grand
   visls0(iscal) =-grand*10.d0
@@ -1416,7 +1220,7 @@ enddo
 ! --- Ici tout cstphy a ete initialise
 
 !===============================================================================
-! 9. INDICATEURS DE VECTORISATION
+! 8. INDICATEURS DE VECTORISATION
 !===============================================================================
 
 !  On les prend ici egaux a -1 ; si l'utilisateur ne les positionne pas
@@ -1432,14 +1236,14 @@ ivecti = -1
 ivectb = -1
 
 !===============================================================================
-! 10. INITIALISATION DES PARAMETRES DE PERIODICITE de period.h
+! 9. INITIALISATION DES PARAMETRES DE PERIODICITE de period.f90
 !===============================================================================
 
 iguper = 0
 igrper = 0
 
 !===============================================================================
-! 11. INITIALISATION DES PARAMETRES DE IHM de ihmpre.h
+! 10. INITIALISATION DES PARAMETRES DE IHM de ihmpre.f90
 !===============================================================================
 
 !     Par defaut, pas de fichier IHM consulte (on regarde ensuite si on
@@ -1448,7 +1252,7 @@ igrper = 0
 iihmpr = 0
 
 !===============================================================================
-! 12. INITIALISATION DES PARAMETRES ALE de albase.h et alstru.h
+! 11. INITIALISATION DES PARAMETRES ALE de albase.f90 et alstru.f90
 !===============================================================================
 
 ! --- Methode ALE
@@ -1512,7 +1316,7 @@ betnmk = -grand
 gamnmk = -grand
 
 !===============================================================================
-! 14. INITIALISATION DES PARAMETRES DE COUPLAGE CS/CS
+! 12. INITIALISATION DES PARAMETRES DE COUPLAGE CS/CS
 !===============================================================================
 
 ! --- Nombre de couplage
@@ -1522,7 +1326,7 @@ nbrcpl = 0
 ifaccp = 0
 
 !===============================================================================
-! 15. SORTIE
+! 13. SORTIE
 !===============================================================================
 
 return
