@@ -1,45 +1,31 @@
 !-------------------------------------------------------------------------------
 
-!     This file is part of the Code_Saturne Kernel, element of the
-!     Code_Saturne CFD tool.
-
-!     Copyright (C) 1998-2009 EDF S.A., France
-
-!     contact: saturne-support@edf.fr
-
-!     The Code_Saturne Kernel is free software; you can redistribute it
-!     and/or modify it under the terms of the GNU General Public License
-!     as published by the Free Software Foundation; either version 2 of
-!     the License, or (at your option) any later version.
-
-!     The Code_Saturne Kernel is distributed in the hope that it will be
-!     useful, but WITHOUT ANY WARRANTY; without even the implied warranty
-!     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-!     GNU General Public License for more details.
-
-!     You should have received a copy of the GNU General Public License
-!     along with the Code_Saturne Kernel; if not, write to the
-!     Free Software Foundation, Inc.,
-!     51 Franklin St, Fifth Floor,
-!     Boston, MA  02110-1301  USA
+! This file is part of Code_Saturne, a general-purpose CFD tool.
+!
+! Copyright (C) 1998-2011 EDF S.A.
+!
+! This program is free software; you can redistribute it and/or modify it under
+! the terms of the GNU General Public License as published by the Free Software
+! Foundation; either version 2 of the License, or (at your option) any later
+! version.
+!
+! This program is distributed in the hope that it will be useful, but WITHOUT
+! ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+! FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+! details.
+!
+! You should have received a copy of the GNU General Public License along with
+! this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
+! Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 !-------------------------------------------------------------------------------
 
 subroutine iniva0 &
 !================
 
- ( idbia0 , idbra0 ,                                              &
-   ndim   , ncelet , ncel   , nfac   , nfabor , nfml   , nprfml , &
-   nnod   , lndfac , lndfbr , ncelbr ,                            &
-   nvar   , nscal  , nphas  , ncofab ,                            &
-   nideve , nrdeve , nituse , nrtuse ,                            &
-   ifacel , ifabor , ifmfbr , ifmcel , iprfml ,                   &
-   ipnfac , nodfac , ipnfbr , nodfbr ,                            &
-   idevel , ituser , ia     ,                                     &
-   xyzcen , surfac , surfbo , cdgfac , cdgfbo , xyznod , volume , &
-   dt     , rtp    , propce , propfa , propfb ,                   &
-   coefa  , coefb  , frcxt  ,                                     &
-   rdevel , rtuser , ra     )
+ ( nvar   , nscal  , ncofab ,                                     &
+   dt     , tpucou , rtp    , propce , propfa , propfb ,          &
+   coefa  , coefb  , frcxt  )
 
 !===============================================================================
 ! FONCTION :
@@ -55,52 +41,9 @@ subroutine iniva0 &
 !__________________.____._____.________________________________________________.
 ! name             !type!mode ! role                                           !
 !__________________!____!_____!________________________________________________!
-! idbia0           ! i  ! <-- ! number of first free position in ia            !
-! idbra0           ! i  ! <-- ! number of first free position in ra            !
-! ndim             ! i  ! <-- ! spatial dimension                              !
-! ncelet           ! i  ! <-- ! number of extended (real + ghost) cells        !
-! ncel             ! i  ! <-- ! number of cells                                !
-! nfac             ! i  ! <-- ! number of interior faces                       !
-! nfabor           ! i  ! <-- ! number of boundary faces                       !
-! nfml             ! i  ! <-- ! number of families (group classes)             !
-! nprfml           ! i  ! <-- ! number of properties per family (group class)  !
-! nnod             ! i  ! <-- ! number of vertices                             !
-! lndfac           ! i  ! <-- ! size of nodfac indexed array                   !
-! lndfbr           ! i  ! <-- ! size of nodfbr indexed array                   !
-! ncelbr           ! i  ! <-- ! number of cells with faces on boundary         !
 ! nvar             ! i  ! <-- ! total number of variables                      !
 ! nscal            ! i  ! <-- ! total number of scalars                        !
-! nphas            ! i  ! <-- ! number of phases                               !
 ! ncofab           ! e  ! <-- ! nombre de couples coefa/b pour les cl          !
-! nideve, nrdeve   ! i  ! <-- ! sizes of idevel and rdevel arrays              !
-! nituse, nrtuse   ! i  ! <-- ! sizes of ituser and rtuser arrays              !
-! ifacel(2, nfac)  ! ia ! <-- ! interior faces -> cells connectivity           !
-! ifabor(nfabor)   ! ia ! <-- ! boundary faces -> cells connectivity           !
-! ifmfbr(nfabor)   ! ia ! <-- ! boundary face family numbers                   !
-! ifmcel(ncelet)   ! ia ! <-- ! cell family numbers                            !
-! iprfml           ! ia ! <-- ! property numbers per family                    !
-!  (nfml, nprfml)  !    !     !                                                !
-! ipnfac(nfac+1)   ! ia ! <-- ! interior faces -> vertices index (optional)    !
-! nodfac(lndfac)   ! ia ! <-- ! interior faces -> vertices list (optional)     !
-! ipnfbr(nfabor+1) ! ia ! <-- ! boundary faces -> vertices index (optional)    !
-! nodfbr(lndfbr)   ! ia ! <-- ! boundary faces -> vertices list (optional)     !
-! idevel(nideve)   ! ia ! <-> ! integer work array for temporary development   !
-! ituser(nituse)   ! ia ! <-> ! user-reserved integer work array               !
-! ia(*)            ! ia ! --- ! main integer work array                        !
-! xyzcen           ! ra ! <-- ! cell centers                                   !
-!  (ndim, ncelet)  !    !     !                                                !
-! surfac           ! ra ! <-- ! interior faces surface vectors                 !
-!  (ndim, nfac)    !    !     !                                                !
-! surfbo           ! ra ! <-- ! boundary faces surface vectors                 !
-!  (ndim, nfabor)  !    !     !                                                !
-! cdgfac           ! ra ! <-- ! interior faces centers of gravity              !
-!  (ndim, nfac)    !    !     !                                                !
-! cdgfbo           ! ra ! <-- ! boundary faces centers of gravity              !
-!  (ndim, nfabor)  !    !     !                                                !
-! xyznod           ! ra ! <-- ! vertex coordinates (optional)                  !
-!  (ndim, nnod)    !    !     !                                                !
-!                  !    !     !  a la face interne                             !
-! volume(ncelet)   ! ra ! <-- ! cell volumes                                   !
 ! dt(ncelet)       ! tr ! <-- ! valeur du pas de temps                         !
 ! rtp              ! tr ! <-- ! variables de calcul au centre des              !
 ! (ncelet,*)       !    !     !    cellules                                    !
@@ -109,11 +52,8 @@ subroutine iniva0 &
 ! propfb(nfabor, *)! ra ! <-- ! physical properties at boundary face centers   !
 ! coefa coefb      ! tr ! <-- ! conditions aux limites aux                     !
 !  (nfabor,*)      !    !     !    faces de bord                               !
-! frcxt(ncelet,    ! tr ! <-- ! force exterieure generant la pression          !
-!   3,nphas)       !    !     !  hydrostatique                                 !
-! rdevel(nrdeve)   ! ra ! <-> ! real work array for temporary development      !
-! rtuser(nrtuse)   ! ra ! <-> ! user-reserved real work array                  !
-! ra(*)            ! ra ! --- ! main real work array                           !
+! frcxt(ncelet,3)  ! tr ! <-- ! force exterieure generant la pression          !
+!                  !    !     !  hydrostatique                                 !
 !__________________!____!_____!________________________________________________!
 
 !     TYPE : E (ENTIER), R (REEL), A (ALPHANUMERIQUE), T (TABLEAU)
@@ -122,60 +62,44 @@ subroutine iniva0 &
 !            --- tableau de travail
 !===============================================================================
 
+!===============================================================================
+! Module files
+!===============================================================================
+
+use paramx
+use numvar
+use optcal
+use cstphy
+use cstnum
+use pointe
+use entsor
+use albase
+use parall
+use period
+use ppppar
+use ppthch
+use ppincl
+use cplsat
+use mesh
+
+!===============================================================================
+
 implicit none
 
-!===============================================================================
-! Common blocks
-!===============================================================================
-
-include "paramx.h"
-include "numvar.h"
-include "optcal.h"
-include "cstphy.h"
-include "cstnum.h"
-include "pointe.h"
-include "entsor.h"
-include "albase.h"
-include "period.h"
-include "parall.h"
-include "ppppar.h"
-include "ppthch.h"
-include "ppincl.h"
-include "cplsat.h"
-
-!===============================================================================
-
 ! Arguments
 
-integer          idbia0 , idbra0
-integer          ndim   , ncelet , ncel   , nfac   , nfabor
-integer          nfml   , nprfml
-integer          nnod   , lndfac , lndfbr , ncelbr
-integer          nvar   , nscal  , nphas  , ncofab
-integer          nideve , nrdeve , nituse , nrtuse
+integer          nvar   , nscal  , ncofab
 
-integer          ifacel(2,nfac) , ifabor(nfabor)
-integer          ifmfbr(nfabor) , ifmcel(ncelet)
-integer          iprfml(nfml,nprfml)
-integer          ipnfac(nfac+1), nodfac(lndfac)
-integer          ipnfbr(nfabor+1), nodfbr(lndfbr)
-integer          idevel(nideve), ituser(nituse), ia(*)
 
-double precision xyzcen(ndim,ncelet)
-double precision surfac(ndim,nfac), surfbo(ndim,nfabor)
-double precision cdgfac(ndim,nfac), cdgfbo(ndim,nfabor)
-double precision xyznod(ndim,nnod), volume(ncelet)
-double precision dt(ncelet), rtp(ncelet,*), propce(ncelet,*)
+double precision dt(ncelet), tpucou(ncelet,3), rtp(ncelet,*), propce(ncelet,*)
 double precision propfa(nfac,*), propfb(nfabor,*)
 double precision coefa(nfabor,ncofab), coefb(nfabor,ncofab)
-double precision frcxt(ncelet,3,nphas)
-double precision rdevel(nrdeve), rtuser(nrtuse), ra(*)
+double precision frcxt(ncelet,3)
 
 ! Local variables
 
-integer          idebia, idebra
-integer          iis   , ivar  , iphas , iphass, iscal , imom
-integer          iel   , ifac
+integer          iis   , ivar  , iscal , imom
+integer          iel   , ifac  , isou  , jsou
 integer          iclip , ii    , jj    , idim
 integer          iiflum, iiflua
 integer          iirom , iiromb, iiroma
@@ -183,27 +107,31 @@ integer          iivisl, iivist, iivisa, iivism
 integer          iicp  , iicpa
 integer          iiviss, iiptot
 integer          iptsna, iptsta, iptsca
-integer          ikiph , ieiph , iphiph, ifbiph, iomgip
-integer          ir11ip, ir22ip, ir33ip, ir12ip, ir13ip, ir23ip
 integer          nn
-double precision ro0iph, visiph
+
 double precision xxk, xcmu, trii
 
+double precision rvoid(1)
+
 !===============================================================================
 
 !===============================================================================
 ! 1.  INITIALISATION
 !===============================================================================
 
-idebia = idbia0
-idebra = idbra0
+! Initialize variables to avoid compiler warnings
+
+jj = 0
+
+! Memoire
+
 
 ! En compressible, ISYMPA initialise (= 1) car utile dans le calcul
 !     du pas de temps variable avant passage dans les C.L.
 
 if ( ippmod(icompf).ge.0 ) then
-  do ifac = 1, nfabor*nphas
-    ia(iisymp+ifac-1) = 1
+  do ifac = 1, nfabor
+    isympa(ifac) = 1
   enddo
 endif
 
@@ -219,86 +147,79 @@ enddo
 ! 3.  INITIALISATION DES PROPRIETES PHYSIQUES
 !===============================================================================
 
-do iphas = 1, nphas
-
 !     Masse volumique
-  iirom  = ipproc(irom  (iphas))
-  iiromb = ipprob(irom  (iphas))
-  ro0iph = ro0   (iphas)
+iirom  = ipproc(irom  )
+iiromb = ipprob(irom  )
 
 !     Masse volumique aux cellules (et au pdt precedent si ordre2 ou icalhy)
+do iel = 1, ncel
+  propce(iel,iirom)  = ro0
+enddo
+if(iroext.gt.0.or.icalhy.eq.1) then
+  iiroma = ipproc(iroma )
   do iel = 1, ncel
-    propce(iel,iirom)  = ro0iph
+    propce(iel,iiroma) = propce(iel,iirom)
   enddo
-  if(iroext(iphas).gt.0.or.icalhy.eq.1) then
-    iiroma = ipproc(iroma (iphas))
-    do iel = 1, ncel
-      propce(iel,iiroma) = propce(iel,iirom)
-    enddo
-  endif
+endif
 !     Masse volumique aux faces de bord (et au pdt precedent si ordre2)
+do ifac = 1, nfabor
+  propfb(ifac,iiromb) = ro0
+enddo
+if(iroext.gt.0) then
+  iiroma = ipprob(iroma )
   do ifac = 1, nfabor
-    propfb(ifac,iiromb) = ro0iph
+    propfb(ifac,iiroma) = propfb(ifac,iiromb)
   enddo
-  if(iroext(iphas).gt.0) then
-    iiroma = ipprob(iroma (iphas))
-    do ifac = 1, nfabor
-      propfb(ifac,iiroma) = propfb(ifac,iiromb)
-    enddo
-  endif
+endif
 
 !     Viscosite moleculaire
-  iivisl = ipproc(iviscl(iphas))
-  iivist = ipproc(ivisct(iphas))
-  visiph = viscl0(iphas)
+iivisl = ipproc(iviscl)
+iivist = ipproc(ivisct)
 
 !     Viscosite moleculaire aux cellules (et au pdt precedent si ordre2)
+do iel = 1, ncel
+  propce(iel,iivisl) = viscl0
+enddo
+if(iviext.gt.0) then
+  iivisa = ipproc(ivisla)
   do iel = 1, ncel
-    propce(iel,iivisl) = visiph
+    propce(iel,iivisa) = propce(iel,iivisl)
   enddo
-  if(iviext(iphas).gt.0) then
-    iivisa = ipproc(ivisla(iphas))
-    do iel = 1, ncel
-      propce(iel,iivisa) = propce(iel,iivisl)
-    enddo
-  endif
+endif
 !     Viscosite turbulente aux cellules (et au pdt precedent si ordre2)
+do iel = 1, ncel
+  propce(iel,iivist) = 0.d0
+enddo
+if(iviext.gt.0) then
+  iivisa = ipproc(ivista)
   do iel = 1, ncel
-    propce(iel,iivist) = 0.d0
+    propce(iel,iivisa) = propce(iel,iivist)
   enddo
-  if(iviext(iphas).gt.0) then
-    iivisa = ipproc(ivista(iphas))
-    do iel = 1, ncel
-      propce(iel,iivisa) = propce(iel,iivist)
-    enddo
-  endif
+endif
 
 !     Chaleur massique aux cellules (et au pdt precedent si ordre2)
-  if(icp(iphas).gt.0) then
-    iicp = ipproc(icp(iphas))
+if(icp.gt.0) then
+  iicp = ipproc(icp)
+  do iel = 1, ncel
+    propce(iel,iicp) = cp0
+  enddo
+  if(icpext.gt.0) then
+    iicpa  = ipproc(icpa)
     do iel = 1, ncel
-      propce(iel,iicp) = cp0(iphas)
+      propce(iel,iicpa ) = propce(iel,iicp)
     enddo
-    if(icpext(iphas).gt.0) then
-      iicpa  = ipproc(icpa(iphas))
-      do iel = 1, ncel
-        propce(iel,iicpa ) = propce(iel,iicp)
-      enddo
-    endif
   endif
+endif
 
 ! La pression totale sera initialisee a P0 + rho.g.r dans INIVAR
 !  si l'utilisateur n'a pas fait d'initialisation personnelle
 ! Non valable en compressible
-  if (ippmod(icompf).lt.0) then
-    iiptot = ipproc(iprtot(iphas))
-    do iel = 1, ncel
-      propce(iel,iiptot) = - rinfin
-    enddo
-  endif
-
-enddo
-
+if (ippmod(icompf).lt.0) then
+  iiptot = ipproc(iprtot)
+  do iel = 1, ncel
+    propce(iel,iiptot) = - rinfin
+  enddo
+endif
 
 !     Diffusivite des scalaires
 do iscal = 1, nscal
@@ -343,18 +264,16 @@ do ivar = 1, nvar
 enddo
 
 !     On met la pression P* a PRED0
-do iphas = 1, nphas
-  do iel = 1, ncel
-    rtp(iel,ipr(iphas)) = pred0(iphas)
-  enddo
+do iel = 1, ncel
+  rtp(iel,ipr) = pred0
 enddo
 
 !     Couplage U-P
 if(ipucou.eq.1) then
   do iel = 1, ncel
-    ra(itpuco+iel-1         ) = 0.d0
-    ra(itpuco+iel-1+  ncelet) = 0.d0
-    ra(itpuco+iel-1+2*ncelet) = 0.d0
+    tpucou(iel,1) = 0.d0
+    tpucou(iel,2) = 0.d0
+    tpucou(iel,3) = 0.d0
   enddo
 endif
 
@@ -367,116 +286,119 @@ endif
 !    -10*GRAND. On testera ensuite si l'utilisateur les a modifiees dans
 !    usiniv ou en lisant un fichier suite.
 
-do iphas = 1, nphas
+if(itytur.eq.2 .or. itytur.eq.5) then
 
-  if(itytur(iphas).eq.2 .or. iturb(iphas).eq.50) then
+  xcmu = cmu
+  if (iturb.eq.50) xcmu = cv2fmu
+  if (iturb.eq.51) xcmu = cpalmu
 
-    ikiph  = ik (iphas)
-    ieiph  = iep(iphas)
+  if (uref.ge.0.d0) then
+    do iel = 1, ncel
+      rtp(iel,ik) = 1.5d0*(0.02d0*uref)**2
+      rtp(iel,iep) = rtp(iel,ik)**1.5d0*xcmu/almax
+    enddo
 
-    xcmu = cmu
-    if (iturb(iphas).eq.50) xcmu = cv2fmu
+    iclip = 1
+    call clipke(ncelet , ncel   , nvar    ,     &
+         iclip  , iwarni(ik),                   &
+         propce , rtp    )
 
+  else
+    do iel = 1, ncel
+      rtp(iel,ik) = -grand
+      rtp(iel,iep) = -grand
+    enddo
+  endif
 
-    if (uref(iphas).ge.0.d0) then
-      do iel = 1, ncel
-        rtp(iel,ikiph) = 1.5d0*(0.02d0*uref(iphas))**2
-        rtp(iel,ieiph) = rtp(iel,ikiph)**1.5d0*xcmu/almax(iphas)
-      enddo
+  if (iturb.eq.50) then
+    do iel = 1, ncel
+      rtp(iel,iphi) = 2.d0/3.d0
+      rtp(iel,ifb) = 0.d0
+    enddo
+  endif
+  if (iturb.eq.51) then
+    do iel = 1, ncel
+      rtp(iel,iphi) = 2.d0/3.d0
+      rtp(iel,ial) = 1.d0
+    enddo
+  endif
 
-      iclip = 1
-      iphass = iphas
-      call clipke(ncelet , ncel   , nvar    , nphas  ,            &
-                  iphass , iclip  , iwarni(ikiph),                &
-                  propce , rtp    )
+elseif(itytur.eq.3) then
 
-    else
-      do iel = 1, ncel
-        rtp(iel,ikiph) = -grand
-        rtp(iel,ieiph) = -grand
-      enddo
-    endif
+  if (uref.ge.0.d0) then
 
-    if (iturb(iphas).eq.50) then
-      iphiph = iphi(iphas)
-      ifbiph = ifb (iphas)
-      do iel = 1, ncel
-        rtp(iel,iphiph) = 2.d0/3.d0
-        rtp(iel,ifbiph) = 0.d0
-      enddo
-    endif
+    trii   = (0.02d0*uref)**2
 
-  elseif(itytur(iphas).eq.3) then
+    do iel = 1, ncel
+      rtp(iel,ir11) = trii
+      rtp(iel,ir22) = trii
+      rtp(iel,ir33) = trii
+      rtp(iel,ir12) = 0.d0
+      rtp(iel,ir13) = 0.d0
+      rtp(iel,ir23) = 0.d0
+      xxk = 0.5d0*(rtp(iel,ir11)+                             &
+           rtp(iel,ir22)+rtp(iel,ir33))
+      rtp(iel,iep) = xxk**1.5d0*cmu/almax
+    enddo
+    iclip = 1
+    call clprij(ncelet , ncel   , nvar    ,     &
+         iclip  ,                               &
+         propce , rtp    , rtp    )
 
-    ir11ip = ir11(iphas)
-    ir22ip = ir22(iphas)
-    ir33ip = ir33(iphas)
-    ir12ip = ir12(iphas)
-    ir13ip = ir13(iphas)
-    ir23ip = ir23(iphas)
-    ieiph  = iep (iphas)
+  else
 
-    if (uref(iphas).ge.0.d0) then
-
-      trii   = (0.02d0*uref(iphas))**2
-
-      do iel = 1, ncel
-        rtp(iel,ir11ip) = trii
-        rtp(iel,ir22ip) = trii
-        rtp(iel,ir33ip) = trii
-        rtp(iel,ir12ip) = 0.d0
-        rtp(iel,ir13ip) = 0.d0
-        rtp(iel,ir23ip) = 0.d0
-        xxk = 0.5d0*(rtp(iel,ir11ip)+                             &
-                     rtp(iel,ir22ip)+rtp(iel,ir33ip))
-        rtp(iel,ieiph) = xxk**1.5d0*cmu/almax(iphas)
-      enddo
-      iclip = 1
-      iphass = iphas
-      call clprij(ncelet , ncel   , nvar    , nphas  ,            &
-                  iphass , iclip  ,                               &
-                  propce , rtp    , rtp    )
-
-    else
-
-      do iel = 1, ncel
-        rtp(iel,ir11ip) = -grand
-        rtp(iel,ir22ip) = -grand
-        rtp(iel,ir33ip) = -grand
-        rtp(iel,ir12ip) = -grand
-        rtp(iel,ir13ip) = -grand
-        rtp(iel,ir23ip) = -grand
-        rtp(iel,ieiph)  = -grand
-      enddo
-
-    endif
-
-  elseif(iturb(iphas).eq.60) then
-
-    ikiph   = ik  (iphas)
-    iomgip  = iomg(iphas)
-
-    if (uref(iphas).ge.0.d0) then
-
-      do iel = 1, ncel
-        rtp(iel,ikiph ) = 1.5d0*(0.02d0*uref(iphas))**2
-!     on utilise la formule classique eps=k**1.5/Cmu/ALMAX et omega=eps/Cmu/k
-        rtp(iel,iomgip) = rtp(iel,ikiph)**0.5d0/almax(iphas)
-      enddo
-!     pas la peine de clipper, les valeurs sont forcement positives
-
-    else
-
-      do iel = 1, ncel
-        rtp(iel,ikiph ) = -grand
-        rtp(iel,iomgip) = -grand
-      enddo
-
-    endif
+    do iel = 1, ncel
+      rtp(iel,ir11) = -grand
+      rtp(iel,ir22) = -grand
+      rtp(iel,ir33) = -grand
+      rtp(iel,ir12) = -grand
+      rtp(iel,ir13) = -grand
+      rtp(iel,ir23) = -grand
+      rtp(iel,iep)  = -grand
+    enddo
 
   endif
 
-enddo
+elseif(iturb.eq.60) then
+
+  if (uref.ge.0.d0) then
+
+    do iel = 1, ncel
+      rtp(iel,ik ) = 1.5d0*(0.02d0*uref)**2
+      !     on utilise la formule classique eps=k**1.5/Cmu/ALMAX et omega=eps/Cmu/k
+      rtp(iel,iomg) = rtp(iel,ik)**0.5d0/almax
+    enddo
+    !     pas la peine de clipper, les valeurs sont forcement positives
+
+  else
+
+    do iel = 1, ncel
+      rtp(iel,ik ) = -grand
+      rtp(iel,iomg) = -grand
+    enddo
+
+  endif
+
+elseif(iturb.eq.70) then
+
+  if (uref.ge.0.d0) then
+
+    do iel = 1, ncel
+      rtp(iel,inusa ) = sqrt(1.5d0)*(0.02d0*uref)*almax
+      !     on utilise la formule classique eps=k**1.5/Cmu/ALMAX
+      !     et nusa=Cmu*k**2/eps
+    enddo
+    !     pas la peine de clipper, les valeurs sont forcement positives
+
+  else
+
+    do iel = 1, ncel
+      rtp(iel,inusa ) = -grand
+    enddo
+
+  endif
+
+endif
 
 !===============================================================================
 ! 6.  CLIPPING DES GRANDEURS SCALAIRES (SF K-EPS VOIR CI DESSUS)
@@ -491,7 +413,7 @@ if (nscal.gt.0) then
       call clpsca                                                 &
       !==========
      ( ncelet , ncel   , nvar   , nscal  , iscal  ,               &
-       propce , ra     , rtp    )
+       propce , rvoid  , rtp    )
     endif
   enddo
 
@@ -503,7 +425,7 @@ if (nscal.gt.0) then
       call clpsca                                                 &
       !==========
      ( ncelet , ncel   , nvar   , nscal  , iscal  ,               &
-       propce , ra     , rtp    )
+       propce , rvoid  , rtp    )
     endif
   enddo
 
@@ -536,11 +458,30 @@ do ii = 1, ncofab
   enddo
 enddo
 
-do iphas = 1, nphas
+! Boundary conditions for the velocity if coupling of the components
+if (ivelco.eq.1) then
   do ifac = 1, nfabor
-    ia(iitypf-1+ifac+nfabor*(iphas-1)) = 0
-    ia(iitrif-1+ifac+nfabor*(iphas-1)) = 0
+    do isou = 1, 3
+      coefau(isou,ifac) = 0.d0
+      cofafu(isou,ifac) = 0.d0
+      do jsou = 1, 3
+        if (jsou.eq.isou) then
+          coefbu(isou,jsou,ifac) = 1.d0
+          cofbfu(isou,jsou,ifac) = 1.d0
+        else
+          coefbu(isou,jsou,ifac) = 0.d0
+          cofbfu(isou,jsou,ifac) = 0.d0
+        endif
+      enddo
+    enddo
   enddo
+endif
+
+
+
+do ifac = 1, nfabor
+  itypfb(ifac) = 0
+  itrifb(ifac) = 0
 enddo
 
 ! Type symtrie : on en a besoin dans le cas du calcul des gradients
@@ -549,10 +490,8 @@ enddo
 !     Habituellement, on vite l'extrapolation sur les faces de symtries
 !     pour ne pas tomber sur une indtermination et une matrice 3*3 non
 !     inversible dans les configurations 2D).
-do iphas = 1, nphas
-  do ifac = 1, nfabor
-    ia(iisymp-1+ifac+nfabor*(iphas-1)) = 0
-  enddo
+do ifac = 1, nfabor
+  isympa(ifac) = 0
 enddo
 
 ! Flux de masse (on essaye de ne pas trop faire les choses 2 fois,
@@ -592,33 +531,30 @@ enddo
 ! 8.  INITIALISATION DES TERMES SOURCES SI EXTRAPOLES
 !===============================================================================
 
-do iphas = 1, nphas
-
 !     les termes sources de Navier Stokes
-  if(isno2t(iphas).gt.0) then
-    iptsna = ipproc(itsnsa(iphas))
-    do ii = 1, ndim
-      do iel = 1, ncel
-        propce(iel,iptsna+ii-1) = 0.d0
-      enddo
+if(isno2t.gt.0) then
+  iptsna = ipproc(itsnsa)
+  do ii = 1, ndim
+    do iel = 1, ncel
+      propce(iel,iptsna+ii-1) = 0.d0
     enddo
-  endif
+  enddo
+endif
 
 !     les termes sources turbulents
-  if(isto2t(iphas).gt.0) then
-    if(itytur(iphas).eq.2) jj = 2
-    if(itytur(iphas).eq.3) jj = 7
-    if(iturb(iphas).eq.50) jj = 4
-    if(iturb(iphas).eq.60) jj = 2
-    iptsta = ipproc(itstua(iphas))
-    do ii = 1, jj
-      do iel = 1, ncel
-        propce(iel,iptsta+ii-1) = 0.d0
-      enddo
+if(isto2t.gt.0) then
+  if(itytur.eq.2) jj = 2
+  if(itytur.eq.3) jj = 7
+  if(iturb.eq.50) jj = 4
+  if(iturb.eq.60) jj = 2
+  if(iturb.eq.70) jj = 1
+  iptsta = ipproc(itstua)
+  do ii = 1, jj
+    do iel = 1, ncel
+      propce(iel,iptsta+ii-1) = 0.d0
     enddo
-  endif
-
-enddo
+  enddo
+endif
 
 !     les termes sources des scalaires
 do iis = 1, nscal
@@ -652,40 +588,34 @@ enddo
 ! 10.  INITIALISATION CONSTANTE DE SMAGORINSKY EN MODELE DYNAMIQUE
 !===============================================================================
 
-do iphas = 1, nphas
-  if(iturb(iphas).eq.41) then
-    do iel = 1, ncel
-      propce(iel,ipproc(ismago(iphas))) = 0.d0
-    enddo
-  endif
-enddo
+if(iturb.eq.41) then
+  do iel = 1, ncel
+    propce(iel,ipproc(ismago)) = 0.d0
+  enddo
+endif
 
 !===============================================================================
 ! 11.  INITIALISATION DU NUMERO DE LA FACE DE PAROI 5 LA PLUS PROCHE
 !===============================================================================
 
-!     Si IFAPA existe,
+!     Si IFAPAT existe,
 !     on suppose qu'il faut le (re)calculer : on init le tab a -1.
 
-do iphas = 1, nphas
-  if(iifapa(iphas).gt.0) then
-    do iel = 1, ncel
-      ia(iifapa(iphas)-1+ iel) = -1
-    enddo
-  endif
-enddo
+if(abs(icdpar).eq.2) then
+  do iel = 1, ncel
+    ifapat(iel) = -1
+  enddo
+endif
 
 !===============================================================================
 ! 12.  INITIALISATION DE LA FORCE EXTERIEURE QUAND IPHYDR=1
 !===============================================================================
 
 if(iphydr.eq.1) then
-  do iphas = 1, nphas
-    do iel = 1, ncel
-      frcxt(iel,1,iphas) = 0.d0
-      frcxt(iel,2,iphas) = 0.d0
-      frcxt(iel,3,iphas) = 0.d0
-    enddo
+  do iel = 1, ncel
+    frcxt(iel,1) = 0.d0
+    frcxt(iel,2) = 0.d0
+    frcxt(iel,3) = 0.d0
   enddo
 endif
 
@@ -695,9 +625,9 @@ endif
 
 if (iale.eq.1) then
   do ii = 1, nnod
-    ia(iimpal+ii-1) = 0
+    impale(ii) = 0
     do idim = 1, 3
-      ra(idepal+(idim-1)*nnod+ii-1) = 0.d0
+      depale(ii,idim) = 0.d0
     enddo
   enddo
 endif
@@ -705,7 +635,7 @@ endif
 if (iale.eq.1.or.imobil.eq.1) then
   do ii = 1, nnod
     do idim = 1, 3
-      ra(ixyzn0+(ii-1)*ndim+idim-1) = xyznod(idim,ii)
+      xyzno0(idim,ii) = xyznod(idim,ii)
     enddo
   enddo
 endif
