@@ -1,27 +1,22 @@
 !-------------------------------------------------------------------------------
 
-!     This file is part of the Code_Saturne Kernel, element of the
-!     Code_Saturne CFD tool.
-
-!     Copyright (C) 1998-2009 EDF S.A., France
-
-!     contact: saturne-support@edf.fr
-
-!     The Code_Saturne Kernel is free software; you can redistribute it
-!     and/or modify it under the terms of the GNU General Public License
-!     as published by the Free Software Foundation; either version 2 of
-!     the License, or (at your option) any later version.
-
-!     The Code_Saturne Kernel is distributed in the hope that it will be
-!     useful, but WITHOUT ANY WARRANTY; without even the implied warranty
-!     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-!     GNU General Public License for more details.
-
-!     You should have received a copy of the GNU General Public License
-!     along with the Code_Saturne Kernel; if not, write to the
-!     Free Software Foundation, Inc.,
-!     51 Franklin St, Fifth Floor,
-!     Boston, MA  02110-1301  USA
+! This file is part of Code_Saturne, a general-purpose CFD tool.
+!
+! Copyright (C) 1998-2011 EDF S.A.
+!
+! This program is free software; you can redistribute it and/or modify it under
+! the terms of the GNU General Public License as published by the Free Software
+! Foundation; either version 2 of the License, or (at your option) any later
+! version.
+!
+! This program is distributed in the hope that it will be useful, but WITHOUT
+! ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+! FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+! details.
+!
+! You should have received a copy of the GNU General Public License along with
+! this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
+! Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 !-------------------------------------------------------------------------------
 
@@ -72,16 +67,18 @@ subroutine tstvec &
 !            --- tableau de travail
 !===============================================================================
 
+!===============================================================================
+! Module files
+!===============================================================================
+
+use paramx
+use entsor
+use parall
+
+!===============================================================================
+
 implicit none
 
-!===============================================================================
-! Common blocks
-!===============================================================================
-
-include "paramx.h"
-include "vector.h"
-include "entsor.h"
-
 ! Arguments
 
 integer          ncelet, ncel, nfac, nfabor
