@@ -1,54 +1,38 @@
 !-------------------------------------------------------------------------------
 
-!     This file is part of the Code_Saturne Kernel, element of the
-!     Code_Saturne CFD tool.
-
-!     Copyright (C) 1998-2009 EDF S.A., France
-
-!     contact: saturne-support@edf.fr
-
-!     The Code_Saturne Kernel is free software; you can redistribute it
-!     and/or modify it under the terms of the GNU General Public License
-!     as published by the Free Software Foundation; either version 2 of
-!     the License, or (at your option) any later version.
-
-!     The Code_Saturne Kernel is distributed in the hope that it will be
-!     useful, but WITHOUT ANY WARRANTY; without even the implied warranty
-!     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-!     GNU General Public License for more details.
-
-!     You should have received a copy of the GNU General Public License
-!     along with the Code_Saturne Kernel; if not, write to the
-!     Free Software Foundation, Inc.,
-!     51 Franklin St, Fifth Floor,
-!     Boston, MA  02110-1301  USA
+! This file is part of Code_Saturne, a general-purpose CFD tool.
+!
+! Copyright (C) 1998-2011 EDF S.A.
+!
+! This program is free software; you can redistribute it and/or modify it under
+! the terms of the GNU General Public License as published by the Free Software
+! Foundation; either version 2 of the License, or (at your option) any later
+! version.
+!
+! This program is distributed in the hope that it will be useful, but WITHOUT
+! ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+! FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+! details.
+!
+! You should have received a copy of the GNU General Public License along with
+! this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
+! Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 !-------------------------------------------------------------------------------
 
 subroutine cfcdts &
 !================
 
- ( idbia0 , idbra0 ,                                              &
-   ndim   , ncelet , ncel   , nfac   , nfabor , nfml   , nprfml , &
-   nnod   , lndfac , lndfbr , ncelbr ,                            &
-   nvar   , nscal  , nphas  ,                                     &
-   nideve , nrdeve , nituse , nrtuse ,                            &
+ ( nvar   , nscal  ,                                              &
    ivar   , iconvp , idiffp , ireslp , ndircp , nitmap ,          &
    imrgra , nswrsp , nswrgp , imligp , ircflp ,                   &
-   ischcp , isstpp , iescap , iifbru ,                            &
+   ischcp , isstpp , iescap ,                                     &
    imgrp  , ncymxp , nitmfp , ipp    , iwarnp ,                   &
    blencp , epsilp , epsrsp , epsrgp , climgp , extrap , thetap , &
-   ifacel , ifabor , ifmfbr , ifmcel , iprfml , ifrusb ,          &
-   ipnfac , nodfac , ipnfbr , nodfbr ,                            &
-   idevel , ituser , ia     ,                                     &
-   xyzcen , surfac , surfbo , cdgfac , cdgfbo , xyznod , volume , &
    pvara  , coefap , coefbp , cofafp , cofbfp , flumas , flumab , &
    viscfm , viscbm , viscfs , viscbs ,                            &
    rovsdt , smbrp  , pvar   ,                                     &
-   dam    , xam    , dpvar  ,                                     &
-   w1     , w2     , w3     , w4     , w5     ,                   &
-   w6     , w7     , w8     , smbini ,                            &
-   rdevel , rtuser , ra     )
+   eswork )
 
 !===============================================================================
 ! FONCTION :
@@ -89,24 +73,8 @@ subroutine cfcdts &
 !__________________.____._____.________________________________________________.
 ! name             !type!mode ! role                                           !
 !__________________!____!_____!________________________________________________!
-! idbia0           ! i  ! <-- ! number of first free position in ia            !
-! idbra0           ! i  ! <-- ! number of first free position in ra            !
-! ndim             ! i  ! <-- ! spatial dimension                              !
-! ncelet           ! i  ! <-- ! number of extended (real + ghost) cells        !
-! ncel             ! i  ! <-- ! number of cells                                !
-! nfac             ! i  ! <-- ! number of interior faces                       !
-! nfabor           ! i  ! <-- ! number of boundary faces                       !
-! nfml             ! i  ! <-- ! number of families (group classes)             !
-! nprfml           ! i  ! <-- ! number of properties per family (group class)  !
-! nnod             ! i  ! <-- ! number of vertices                             !
-! lndfac           ! i  ! <-- ! size of nodfac indexed array                   !
-! lndfbr           ! i  ! <-- ! size of nodfbr indexed array                   !
-! ncelbr           ! i  ! <-- ! number of cells with faces on boundary         !
 ! nvar             ! i  ! <-- ! total number of variables                      !
 ! nscal            ! i  ! <-- ! total number of scalars                        !
-! nphas            ! i  ! <-- ! number of phases                               !
-! nideve, nrdeve   ! i  ! <-- ! sizes of idevel and rdevel arrays              !
-! nituse, nrtuse   ! i  ! <-- ! sizes of ituser and rtuser arrays              !
 ! iconvp           ! e  ! <-- ! indicateur = 1 convection, 0 sinon             !
 ! idiffp           ! e  ! <-- ! indicateur = 1 diffusion , 0 sinon             !
 ! ndircp           ! e  ! <-- ! indicateur = 0 si decalage diagonale           !
@@ -128,7 +96,6 @@ subroutine cfcdts &
 ! isstpp           ! e  ! <-- ! indicateur = 1 sans test de pente              !
 !                  !    !     !            = 0 avec test de pente              !
 ! iescap           ! e  ! <-- ! =1 calcul de l'indicateur prediction           !
-! iifbru           ! e  ! <-- ! pointeur flux de bord rusanov                  !
 ! imgrp            ! e  ! <-- ! indicateur = 0 pas de mgm                      !
 !                  !    !     !            = 1 sinon                           !
 ! nitmap           ! e  ! <-- ! nombre max d'iter pour resol iterativ          !
@@ -141,33 +108,6 @@ subroutine cfcdts &
 !                  !    !     !  reconstruction des gradients 97               !
 ! climgp           ! r  ! <-- ! coef gradient*distance/ecart                   !
 ! extrap           ! r  ! <-- ! coef extrap gradient                           !
-! ifacel(2, nfac)  ! ia ! <-- ! interior faces -> cells connectivity           !
-! ifabor(nfabor)   ! ia ! <-- ! boundary faces -> cells connectivity           !
-! ifmfbr(nfabor)   ! ia ! <-- ! boundary face family numbers                   !
-! ifmcel(ncelet)   ! ia ! <-- ! cell family numbers                            !
-! iprfml           ! ia ! <-- ! property numbers per family                    !
-!  (nfml, nprfml)  !    !     !                                                !
-! ifrusb(nfabor    ! te ! <-- ! indicateur flux de rusanov                     !
-! ipnfac(nfac+1)   ! ia ! <-- ! interior faces -> vertices index (optional)    !
-! nodfac(lndfac)   ! ia ! <-- ! interior faces -> vertices list (optional)     !
-! ipnfbr(nfabor+1) ! ia ! <-- ! boundary faces -> vertices index (optional)    !
-! nodfbr(lndfbr)   ! ia ! <-- ! boundary faces -> vertices list (optional)     !
-! idevel(nideve)   ! ia ! <-> ! integer work array for temporary development   !
-! ituser(nituse)   ! ia ! <-> ! user-reserved integer work array               !
-! ia(*)            ! ia ! --- ! main integer work array                        !
-! xyzcen           ! ra ! <-- ! cell centers                                   !
-!  (ndim, ncelet)  !    !     !                                                !
-! surfac           ! ra ! <-- ! interior faces surface vectors                 !
-!  (ndim, nfac)    !    !     !                                                !
-! surfbo           ! ra ! <-- ! boundary faces surface vectors                 !
-!  (ndim, nfabor)  !    !     !                                                !
-! cdgfac           ! ra ! <-- ! interior faces centers of gravity              !
-!  (ndim, nfac)    !    !     !                                                !
-! cdgfbo           ! ra ! <-- ! boundary faces centers of gravity              !
-!  (ndim, nfabor)  !    !     !                                                !
-! xyznod           ! ra ! <-- ! vertex coordinates (optional)                  !
-!  (ndim, nnod)    !    !     !                                                !
-! volume(ncelet)   ! ra ! <-- ! cell volumes                                   !
 ! pvara(ncelet     ! tr ! <-- ! variable resolue (instant precedent)           !
 ! coefap, b        ! tr ! <-- ! tableaux des cond lim pour p                   !
 !   (nfabor)       !    !     !  sur la normale a la face de bord              !
@@ -184,14 +124,7 @@ subroutine cfcdts &
 ! rovsdt(ncelet    ! tr ! <-- ! rho*volume/dt                                  !
 ! smbrp(ncelet     ! tr ! <-- ! bilan au second membre                         !
 ! pvar (ncelet     ! tr ! <-- ! variable resolue                               !
-! dam(ncelet       ! tr ! --> ! tableau de travail pour matrice                !
-!                  !    !     !  et resultat estimateur                        !
-! xam(nfac,*)      ! tr ! --- ! tableau de travail pour matrice                !
-! w1...8(ncelet    ! tr ! --- ! tableau de travail                             !
-! smbini(ncelet    ! tr ! --- ! tableau de travail                             !
-! rdevel(nrdeve)   ! ra ! <-> ! real work array for temporary development      !
-! rtuser(nrtuse)   ! ra ! <-> ! user-reserved real work array                  !
-! ra(*)            ! ra ! --- ! main real work array                           !
+! eswork(ncelet)   ! ra ! <-- ! prediction-stage error estimator (iescap > 0)  !
 !__________________!____!_____!________________________________________________!
 
 !     TYPE : E (ENTIER), R (REEL), A (ALPHANUMERIQUE), T (TABLEAU)
@@ -200,51 +133,35 @@ subroutine cfcdts &
 !            --- tableau de travail
 !===============================================================================
 
+!===============================================================================
+! Module files
+!===============================================================================
+
+use paramx
+use numvar
+use cstnum
+use entsor
+use parall
+use period
+use mesh
+
+!===============================================================================
+
 implicit none
 
-!===============================================================================
-! Common blocks
-!===============================================================================
-
-include "paramx.h"
-include "numvar.h"
-include "cstnum.h"
-include "entsor.h"
-include "period.h"
-include "parall.h"
-
-!===============================================================================
-
 ! Arguments
 
-integer          idbia0 , idbra0
-integer          ndim   , ncelet , ncel   , nfac   , nfabor
-integer          nfml   , nprfml
-integer          nnod   , lndfac , lndfbr , ncelbr
-integer          nvar   , nscal  , nphas
-integer          nideve , nrdeve , nituse , nrtuse
+integer          nvar   , nscal
 integer          ivar   , iconvp , idiffp , ndircp
 integer          nitmap
 integer          imrgra , nswrsp , nswrgp , imligp , ircflp
-integer          ischcp , isstpp , iescap , iifbru , imgrp
+integer          ischcp , isstpp , iescap , imgrp
 integer          ncymxp , nitmfp
 integer          ipp    , iwarnp
 double precision blencp , epsilp , epsrgp , climgp , extrap
 double precision thetap , epsrsp
 
-integer          ifacel(2,nfac) , ifabor(nfabor)
-integer          ifmfbr(nfabor) , ifmcel(ncelet)
-integer          iprfml(nfml,nprfml)
-integer          ifrusb(nfabor)
-integer          ipnfac(nfac+1), nodfac(lndfac)
-integer          ipnfbr(nfabor+1), nodfbr(lndfbr)
-integer          idevel(nideve), ituser(nituse)
-integer          ia(*)
 
-double precision xyzcen(ndim,ncelet)
-double precision surfac(ndim,nfac), surfbo(ndim,nfabor)
-double precision cdgfac(ndim,nfac), cdgfbo(ndim,nfabor)
-double precision xyznod(ndim,nnod), volume(ncelet)
 double precision pvara(ncelet), coefap(nfabor), coefbp(nfabor)
 double precision                cofafp(nfabor), cofbfp(nfabor)
 double precision flumas(nfac), flumab(nfabor)
@@ -252,41 +169,37 @@ double precision viscfm(nfac), viscbm(nfabor)
 double precision viscfs(nfac), viscbs(nfabor)
 double precision rovsdt(ncelet), smbrp(ncelet)
 double precision pvar(ncelet)
-double precision dam(ncelet), xam(nfac ,2)
-double precision dpvar(ncelet)
-double precision w1(ncelet), w2(ncelet), w3(ncelet), w4(ncelet)
-double precision w5(ncelet), w6(ncelet), w7(ncelet), w8(ncelet)
-double precision smbini(ncelet)
-double precision rdevel(nrdeve), rtuser(nrtuse), ra(*)
+double precision eswork(ncelet)
 
 ! Local variables
 
 character*80     chaine
-character*8      cnom
-integer          idebia, idebra
+character*16     cnom
 integer          isym,ireslp,ireslq,ipol,isqrt
 integer          inc,isweep,niterf,iccocg,iel,icycle,nswmod
-integer          iphas,idimte,itenso,iinvpe, iinvpp
+integer          idimte,itenso,iinvpe, iinvpp,ibsize
+
 double precision residu,rnorm
 
+double precision, allocatable, dimension(:) :: dam
+double precision, allocatable, dimension(:,:) :: xam
+double precision, allocatable, dimension(:) :: dpvar, smbini, w1
+
 !===============================================================================
 
 !===============================================================================
 ! 1.  INITIALISATIONS
 !===============================================================================
 
-idebia = idbia0
-idebra = idbra0
 
 ! NOMS
 chaine = nomvar(ipp)
-cnom   = chaine(1:8)
+cnom   = chaine(1:16)
 
 ! MATRICE A PRIORI SYMETRIQUE ( = 1)
 isym  = 1
 if( iconvp.gt.0 ) isym  = 2
 
-
 ! METHODE DE RESOLUTION ET DEGRE DU PRECOND DE NEUMANN
 !     0 SI CHOIX AUTOMATIQUE GRADCO OU BICGSTAB
 !     0 SI CHOIX AUTOMATIQUE JACOBI
@@ -323,28 +236,25 @@ if(iperio.eq.1) then
 
   iinvpe = 1
 
-  do iphas = 1, nphas
-    if(ivar.eq.iu(iphas).or.ivar.eq.iv(iphas).or.                 &
-                            ivar.eq.iw(iphas).or.                 &
-       ivar.eq.ir11(iphas).or.ivar.eq.ir12(iphas).or.             &
-       ivar.eq.ir13(iphas).or.ivar.eq.ir22(iphas).or.             &
-       ivar.eq.ir23(iphas).or.ivar.eq.ir33(iphas)) then
+  if(ivar.eq.iu.or.ivar.eq.iv.or.ivar.eq.iw.or.     &
+       ivar.eq.ir11.or.ivar.eq.ir12.or.             &
+       ivar.eq.ir13.or.ivar.eq.ir22.or.             &
+       ivar.eq.ir23.or.ivar.eq.ir33) then
 
-!    Pour la vitesse et les tensions de Reynolds
-!      seules seront echangees les informations sur les faces periodiques
-!      de translation dans percom ; on ne touche pas aux informations
-!      relatives aux faces de periodicite de rotation.
-      idimte = 0
-      itenso = 1
+    !    Pour la vitesse et les tensions de Reynolds
+    !      seules seront echangees les informations sur les faces periodiques
+    !      de translation dans percom ; on ne touche pas aux informations
+    !      relatives aux faces de periodicite de rotation.
+    idimte = 0
+    itenso = 1
 
-!      Lors de la resolution par increments, on echangera egalement les
-!      informations relatives aux faces de periodicite de translation.
-!      Pour les faces de periodicite de rotation, l'increment sera
-!      annule dans percom (iinvpe=2).
-      iinvpe = 2
+    !      Lors de la resolution par increments, on echangera egalement les
+    !      informations relatives aux faces de periodicite de translation.
+    !      Pour les faces de periodicite de rotation, l'increment sera
+    !      annule dans percom (iinvpe=2).
+    iinvpe = 2
 
-    endif
-  enddo
+  endif
 
 endif
 
@@ -409,26 +319,14 @@ do 100 isweep = 1, nswmod
 
   call cfbsc2                                                     &
   !==========
- ( idebia , idebra ,                                              &
-   ndim   , ncelet , ncel   , nfac   , nfabor , nfml   , nprfml , &
-   nnod   , lndfac , lndfbr , ncelbr ,                            &
-   nvar   , nscal  , nphas  ,                                     &
-   nideve , nrdeve , nituse , nrtuse ,                            &
+ ( nvar   , nscal  ,                                              &
    ivar   , iconvp , idiffp , nswrgp , imligp , ircflp ,          &
-   ischcp , isstpp , inc    , imrgra , iccocg , iifbru ,          &
+   ischcp , isstpp , inc    , imrgra , iccocg ,                   &
    ipp    , iwarnp ,                                              &
    blencp , epsrgp , climgp , extrap ,                            &
-   ifacel , ifabor , ifmfbr , ifmcel , iprfml , ifrusb ,          &
-   ipnfac , nodfac , ipnfbr , nodfbr ,                            &
-   idevel , ituser , ia     ,                                     &
-   xyzcen , surfac , surfbo , cdgfac , cdgfbo , xyznod , volume , &
    pvar   , coefap , coefbp , cofafp , cofbfp ,                   &
    flumas , flumab , viscfs , viscbs ,                            &
-   smbrp  ,                                                       &
-!        ------
-   w1     , w2     , w3     , w4     , w5     , w6     ,          &
-   rdevel , rtuser , ra     )
-
+   smbrp  )
 
   call prodsc(ncelet,ncel,isqrt,smbrp,smbrp,residu)
 
@@ -445,6 +343,8 @@ do 100 isweep = 1, nswmod
 !         Pour les autres variables (scalaires) IINVPE=1 permettra de
 !         tout echanger, meme si c'est superflu.
   if( isweep.eq.1 ) then
+    ! Allocate a temporary array
+    allocate(w1(ncelet))
     if(iinvpe.eq.2) then
       iinvpp = 3
     else
@@ -457,6 +357,8 @@ do 100 isweep = 1, nswmod
     enddo
     call prodsc(ncelet,ncel,isqrt,w1,w1,rnorm)
     rnsmbr(ipp) = rnorm
+    ! Free memory
+    deallocate(w1)
   endif
 
 ! ---> RESOLUTION IMPLICITE SUR L'INCREMENT DPVAR
@@ -465,23 +367,15 @@ do 100 isweep = 1, nswmod
     dpvar(iel) = 0.d0
   enddo
 
+  ibsize = 1
+
   call invers                                                     &
   !==========
- ( cnom   , idebia , idebra ,                                     &
-   ndim   , ncelet , ncel   , nfac   , nfabor , nfml   , nprfml , &
-   nnod   , lndfac , lndfbr , ncelbr ,                            &
-   nideve , nrdeve , nituse , nrtuse ,                            &
-   isym   , ipol   , ireslq , nitmap , imgrp  ,                   &
+ ( cnom   , isym   , ibsize , ipol   , ireslq , nitmap , imgrp  , &
    ncymxp , nitmfp ,                                              &
    iwarnp , nfecra , niterf , icycle , iinvpe ,                   &
    epsilp , rnorm  , residu ,                                     &
-   ifacel , ifabor , ifmfbr , ifmcel , iprfml ,                   &
-   ipnfac , nodfac , ipnfbr , nodfbr ,                            &
-   idevel , ituser , ia     ,                                     &
-   xyzcen , surfac , surfbo , cdgfac , cdgfbo , xyznod , volume , &
-   dam    , xam    , smbrp  , dpvar  ,                            &
-   w3     , w4     , w5     , w6     , w7     , w8     ,          &
-   rdevel , rtuser , ra     )
+   dam    , xam    , smbrp  , dpvar  )
 
 
   nbivar(ipp) = niterf
@@ -520,19 +414,19 @@ call prodsc(ncelet,ncel,isqrt,smbrp,smbrp,residu)
 
 if( residu.le.epsrsp*rnorm ) then
    if(iwarnp.ge.1) then
-      write( nfecra,1000) cnom,isweep,residu,rnorm
+      write(nfecra,1000) cnom,isweep,residu,rnorm
    endif
    goto 200
 endif
 
 if(iwarnp.ge.3) then
-   write( nfecra,1000) cnom,isweep,residu,rnorm
+   write(nfecra,1000) cnom,isweep,residu,rnorm
 endif
 
  100  continue
 
 if(iwarnp.ge.2) then
-   write( nfecra,1100)cnom, nswmod
+   write(nfecra,1100) cnom, nswmod
 endif
 
 !===============================================================================
@@ -561,44 +455,37 @@ if (iescap.gt.0) then
 
   call cfbsc2                                                     &
   !==========
- ( idebia , idebra ,                                              &
-   ndim   , ncelet , ncel   , nfac   , nfabor , nfml   , nprfml , &
-   nnod   , lndfac , lndfbr , ncelbr ,                            &
-   nvar   , nscal  , nphas  ,                                     &
-   nideve , nrdeve , nituse , nrtuse ,                            &
+ ( nvar   , nscal  ,                                              &
    ivar   , iconvp , idiffp , nswrgp , imligp , ircflp ,          &
-   ischcp , isstpp , inc    , imrgra , iccocg , iifbru ,          &
+   ischcp , isstpp , inc    , imrgra , iccocg ,                   &
    ipp    , iwarnp ,                                              &
    blencp , epsrgp , climgp , extrap ,                            &
-   ifacel , ifabor , ifmfbr , ifmcel , iprfml , ifrusb ,          &
-   ipnfac , nodfac , ipnfbr , nodfbr ,                            &
-   idevel , ituser , ia     ,                                     &
-   xyzcen , surfac , surfbo , cdgfac , cdgfbo , xyznod , volume , &
    pvar   , coefap , coefbp , cofafp , cofbfp ,                   &
    flumas , flumab , viscfs , viscbs ,                            &
-   smbrp  ,                                                       &
-!        ------
-   w1     , w2     , w3     , w4     , w5     , w6     ,          &
-   rdevel , rtuser , ra     )
+   smbrp  )
 
 !     CONTRIBUTION DES NORMES L2 DES DIFFERENTES COMPOSANTES
-!       DANS LE TABLEAU DAM QUI EST ICI DISPONIBLE.
+!       DANS LE TABLEAU ESWORK
 
   do iel = 1,ncel
-    dam(iel) = (smbrp(iel)/ volume(iel))**2
+    eswork(iel) = (smbrp(iel)/ volume(iel))**2
   enddo
 
 endif
 
+! Free memory
+deallocate(dam, xam)
+deallocate(dpvar, smbini)
+
 !--------
 ! FORMATS
 !--------
 
  1000 format (                                                          &
- 1X,A8,' : CV-DIF-TS',I5,' IT - RES= ',E12.5,' NORME= ', E12.5)
+ 1X,A16,' : CV-DIF-TS',I5,' IT - RES= ',E12.5,' NORME= ', E12.5)
  1100 format (                                                          &
 '@                                                            ',/,&
-'@ @@ ATTENTION : ',A8 ,' CONVECTION-DIFFUSION-TERMES SOURCES ',/,&
+'@ @@ ATTENTION : ',A16 ,' CONVECTION-DIFFUSION-TERMES SOURCES ',/,&
 '@    =========                                               ',/,&
 '@  Nombre d''iterations maximal ',I10   ,' atteint           ',/,&
 '@                                                            '  )
