@@ -1,32 +1,28 @@
 !-------------------------------------------------------------------------------
 
-!     This file is part of the Code_Saturne Kernel, element of the
-!     Code_Saturne CFD tool.
-
-!     Copyright (C) 1998-2009 EDF S.A., France
-
-!     contact: saturne-support@edf.fr
-
-!     The Code_Saturne Kernel is free software; you can redistribute it
-!     and/or modify it under the terms of the GNU General Public License
-!     as published by the Free Software Foundation; either version 2 of
-!     the License, or (at your option) any later version.
-
-!     The Code_Saturne Kernel is distributed in the hope that it will be
-!     useful, but WITHOUT ANY WARRANTY; without even the implied warranty
-!     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-!     GNU General Public License for more details.
-
-!     You should have received a copy of the GNU General Public License
-!     along with the Code_Saturne Kernel; if not, write to the
-!     Free Software Foundation, Inc.,
-!     51 Franklin St, Fifth Floor,
-!     Boston, MA  02110-1301  USA
+! This file is part of Code_Saturne, a general-purpose CFD tool.
+!
+! Copyright (C) 1998-2011 EDF S.A.
+!
+! This program is free software; you can redistribute it and/or modify it under
+! the terms of the GNU General Public License as published by the Free Software
+! Foundation; either version 2 of the License, or (at your option) any later
+! version.
+!
+! This program is distributed in the hope that it will be useful, but WITHOUT
+! ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+! FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+! details.
+!
+! You should have received a copy of the GNU General Public License along with
+! this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
+! Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 !-------------------------------------------------------------------------------
 
 subroutine colecd
 !================
+
 !===============================================================================
 !  FONCTION  :
 !  ---------
@@ -47,26 +43,26 @@ subroutine colecd
 !            --- tableau de travail
 !===============================================================================
 
+!===============================================================================
+! Module files
+!===============================================================================
+
+use paramx
+use pointe
+use entsor
+use cstnum
+use cstphy
+use ppppar
+use ppthch
+use coincl
+use cpincl
+use ppincl
+use radiat
+
+!===============================================================================
+
 implicit none
 
-!===============================================================================
-! Common blocks
-!===============================================================================
-
-include "paramx.h"
-include "pointe.h"
-include "entsor.h"
-include "cstnum.h"
-include "cstphy.h"
-include "ppppar.h"
-include "ppthch.h"
-include "coincl.h"
-include "cpincl.h"
-include "ppincl.h"
-include "radiat.h"
-
-!===============================================================================
-
 ! Arguments
 
 ! Local variables
@@ -97,6 +93,13 @@ double precision moxyd
 ! -0. INITIALISATION et VERIFICATIONS
 !===============================================================================
 
+! Initialize variables to avoid compiler warnings
+
+iico2 = 0
+iih2o = 0
+
+mfuel = 0.d0
+moxyd = 0.d0
 
 epsi = 1.d-9
 
