@@ -1,47 +1,32 @@
 !-------------------------------------------------------------------------------
 
-!     This file is part of the Code_Saturne Kernel, element of the
-!     Code_Saturne CFD tool.
-
-!     Copyright (C) 1998-2009 EDF S.A., France
-
-!     contact: saturne-support@edf.fr
-
-!     The Code_Saturne Kernel is free software; you can redistribute it
-!     and/or modify it under the terms of the GNU General Public License
-!     as published by the Free Software Foundation; either version 2 of
-!     the License, or (at your option) any later version.
-
-!     The Code_Saturne Kernel is distributed in the hope that it will be
-!     useful, but WITHOUT ANY WARRANTY; without even the implied warranty
-!     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-!     GNU General Public License for more details.
-
-!     You should have received a copy of the GNU General Public License
-!     along with the Code_Saturne Kernel; if not, write to the
-!     Free Software Foundation, Inc.,
-!     51 Franklin St, Fifth Floor,
-!     Boston, MA  02110-1301  USA
+! This file is part of Code_Saturne, a general-purpose CFD tool.
+!
+! Copyright (C) 1998-2011 EDF S.A.
+!
+! This program is free software; you can redistribute it and/or modify it under
+! the terms of the GNU General Public License as published by the Free Software
+! Foundation; either version 2 of the License, or (at your option) any later
+! version.
+!
+! This program is distributed in the hope that it will be useful, but WITHOUT
+! ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+! FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+! details.
+!
+! You should have received a copy of the GNU General Public License along with
+! this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
+! Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 !-------------------------------------------------------------------------------
 
 subroutine ebutcl &
 !================
 
- ( idbia0 , idbra0 ,                                              &
-   ndim   , ncelet , ncel   , nfac   , nfabor , nfml   , nprfml , &
-   nnod   , lndfac , lndfbr , ncelbr ,                            &
-   nvar   , nscal  , nphas  ,                                     &
-   nideve , nrdeve , nituse , nrtuse ,                            &
-   ifacel , ifabor , ifmfbr , ifmcel , iprfml ,                   &
-   ipnfac , nodfac , ipnfbr , nodfbr ,                            &
+ ( nvar   , nscal  ,                                              &
    icodcl , itrifb , itypfb , izfppp ,                            &
-   idevel , ituser , ia     ,                                     &
-   xyzcen , surfac , surfbo , cdgfac , cdgfbo , xyznod , volume , &
    dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
-   coefa  , coefb  , rcodcl ,                                     &
-   w1     , w2     , w3     , w4     , w5     , w6     , coefu  , &
-   rdevel , rtuser , ra     )
+   coefa  , coefb  , rcodcl )
 
 !===============================================================================
 ! FONCTION :
@@ -57,34 +42,8 @@ subroutine ebutcl &
 !__________________.____._____.________________________________________________.
 ! name             !type!mode ! role                                           !
 !__________________!____!_____!________________________________________________!
-! idbia0           ! i  ! <-- ! number of first free position in ia            !
-! idbra0           ! i  ! <-- ! number of first free position in ra            !
-! ndim             ! i  ! <-- ! spatial dimension                              !
-! ncelet           ! i  ! <-- ! number of extended (real + ghost) cells        !
-! ncel             ! i  ! <-- ! number of cells                                !
-! nfac             ! i  ! <-- ! number of interior faces                       !
-! nfabor           ! i  ! <-- ! number of boundary faces                       !
-! nfml             ! i  ! <-- ! number of families (group classes)             !
-! nprfml           ! i  ! <-- ! number of properties per family (group class)  !
-! nnod             ! i  ! <-- ! number of vertices                             !
-! lndfac           ! i  ! <-- ! size of nodfac indexed array                   !
-! lndfbr           ! i  ! <-- ! size of nodfbr indexed array                   !
-! ncelbr           ! i  ! <-- ! number of cells with faces on boundary         !
 ! nvar             ! i  ! <-- ! total number of variables                      !
 ! nscal            ! i  ! <-- ! total number of scalars                        !
-! nphas            ! i  ! <-- ! number of phases                               !
-! nideve, nrdeve   ! i  ! <-- ! sizes of idevel and rdevel arrays              !
-! nituse, nrtuse   ! i  ! <-- ! sizes of ituser and rtuser arrays              !
-! ifacel(2, nfac)  ! ia ! <-- ! interior faces -> cells connectivity           !
-! ifabor(nfabor)   ! ia ! <-- ! boundary faces -> cells connectivity           !
-! ifmfbr(nfabor)   ! ia ! <-- ! boundary face family numbers                   !
-! ifmcel(ncelet)   ! ia ! <-- ! cell family numbers                            !
-! iprfml           ! ia ! <-- ! property numbers per family                    !
-!  (nfml, nprfml)  !    !     !                                                !
-! ipnfac(nfac+1)   ! ia ! <-- ! interior faces -> vertices index (optional)    !
-! nodfac(lndfac)   ! ia ! <-- ! interior faces -> vertices list (optional)     !
-! ipnfbr(nfabor+1) ! ia ! <-- ! boundary faces -> vertices index (optional)    !
-! nodfbr(lndfbr)   ! ia ! <-- ! boundary faces -> vertices list (optional)     !
 ! icodcl           ! te ! --> ! code de condition limites aux faces            !
 !  (nfabor,nvar    !    !     !  de bord                                       !
 !                  !    !     ! = 1   -> dirichlet                             !
@@ -95,27 +54,9 @@ subroutine ebutcl &
 !                  !    !     ! = 9   -> entree/sortie libre (vitesse          !
 !                  !    !     !  entrante eventuelle     bloquee               !
 ! itrifb           ! ia ! <-- ! indirection for boundary faces ordering        !
-!  (nfabor, nphas) !    !     !                                                !
 ! itypfb           ! ia ! <-- ! boundary face types                            !
-!  (nfabor, nphas) !    !     !                                                !
 ! izfppp           ! te ! <-- ! numero de zone de la face de bord              !
 ! (nfabor)         !    !     !  pour le module phys. part.                    !
-! idevel(nideve)   ! ia ! <-> ! integer work array for temporary development   !
-! ituser(nituse)   ! ia ! <-> ! user-reserved integer work array               !
-! ia(*)            ! ia ! --- ! main integer work array                        !
-! xyzcen           ! ra ! <-- ! cell centers                                   !
-!  (ndim, ncelet)  !    !     !                                                !
-! surfac           ! ra ! <-- ! interior faces surface vectors                 !
-!  (ndim, nfac)    !    !     !                                                !
-! surfbo           ! ra ! <-- ! boundary faces surface vectors                 !
-!  (ndim, nfabor)  !    !     !                                                !
-! cdgfac           ! ra ! <-- ! interior faces centers of gravity              !
-!  (ndim, nfac)    !    !     !                                                !
-! cdgfbo           ! ra ! <-- ! boundary faces centers of gravity              !
-!  (ndim, nfabor)  !    !     !                                                !
-! xyznod           ! ra ! <-- ! vertex coordinates (optional)                  !
-!  (ndim, nnod)    !    !     !                                                !
-! volume(ncelet)   ! ra ! <-- ! cell volumes                                   !
 ! dt(ncelet)       ! ra ! <-- ! time step (per cell)                           !
 ! rtp, rtpa        ! ra ! <-- ! calculated variables at cell centers           !
 !  (ncelet, *)     !    !     !  (at current and previous time steps)          !
@@ -136,13 +77,6 @@ subroutine ebutcl &
 !                  !    !     ! pour la pression             dt*gradp          !
 !                  !    !     ! pour les scalaires                             !
 !                  !    !     !        cp*(viscls+visct/sigmas)*gradt          !
-! w1,2,3,4,5,6     ! ra ! --- ! work arrays                                    !
-!  (ncelet)        !    !     !  (computation of pressure gradient)            !
-! coefu            ! ra ! --- ! work array                                     !
-!  (nfabor, 3)     !    !     !  (computation of pressure gradient)            !
-! rdevel(nrdeve)   ! ra ! <-> ! real work array for temporary development      !
-! rtuser(nrtuse)   ! ra ! <-> ! user-reserved real work array                  !
-! ra(*)            ! ra ! --- ! main real work array                           !
 !__________________!____!_____!________________________________________________!
 
 !     TYPE : E (ENTIER), R (REEL), A (ALPHANUMERIQUE), T (TABLEAU)
@@ -151,66 +85,47 @@ subroutine ebutcl &
 !            --- tableau de travail
 !===============================================================================
 
+!===============================================================================
+! Module files
+!===============================================================================
+
+! Arguments
+
+use paramx
+use numvar
+use optcal
+use cstphy
+use cstnum
+use entsor
+use parall
+use ppppar
+use ppthch
+use coincl
+use cpincl
+use ppincl
+use mesh
+
+!===============================================================================
+
 implicit none
 
-!===============================================================================
-! Common blocks
-!===============================================================================
-
 ! Arguments
 
-include "paramx.h"
-include "numvar.h"
-include "optcal.h"
-include "cstphy.h"
-include "cstnum.h"
-include "entsor.h"
-include "parall.h"
-include "ppppar.h"
-include "ppthch.h"
-include "coincl.h"
-include "cpincl.h"
-include "ppincl.h"
+integer          nvar   , nscal
 
-!===============================================================================
-
-! Arguments
-
-integer          idbia0 , idbra0
-integer          ndim   , ncelet , ncel   , nfac   , nfabor
-integer          nfml   , nprfml
-integer          nnod   , lndfac , lndfbr , ncelbr
-integer          nvar   , nscal  , nphas
-integer          nideve , nrdeve , nituse , nrtuse
-
-integer          ifacel(2,nfac) , ifabor(nfabor)
-integer          ifmfbr(nfabor) , ifmcel(ncelet)
-integer          iprfml(nfml,nprfml)
-integer          ipnfac(nfac+1), nodfac(lndfac)
-integer          ipnfbr(nfabor+1), nodfbr(lndfbr)
 integer          icodcl(nfabor,nvar)
-integer          itrifb(nfabor,nphas), itypfb(nfabor,nphas)
+integer          itrifb(nfabor), itypfb(nfabor)
 integer          izfppp(nfabor)
-integer          idevel(nideve), ituser(nituse), ia(*)
 
-double precision xyzcen(ndim,ncelet)
-double precision surfac(ndim,nfac), surfbo(ndim,nfabor)
-double precision cdgfac(ndim,nfac), cdgfbo(ndim,nfabor)
-double precision xyznod(ndim,nnod), volume(ncelet)
 double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
 double precision propce(ncelet,*)
 double precision propfa(nfac,*), propfb(nfabor,*)
 double precision coefa(nfabor,*), coefb(nfabor,*)
 double precision rcodcl(nfabor,nvar,3)
-double precision w1(ncelet),w2(ncelet),w3(ncelet)
-double precision w4(ncelet),w5(ncelet),w6(ncelet)
-double precision coefu(nfabor,ndim)
-double precision rdevel(nrdeve), rtuser(nrtuse), ra(*)
 
 ! Local variables
 
-integer          idebia, idebra
-integer          igg, iphas, ifac, izone, mode
+integer          igg, ifac, izone, mode
 integer          ipbrom, icke, ipcvis, ii, iel, iok
 double precision qisqc, viscla, d2s3, uref2, rhomoy, dhy, xiturb
 double precision ustar2, xkent, xeent, hgazf , tgazf, hgazb, tgazb
@@ -222,12 +137,9 @@ double precision coefg(ngazgm)
 ! 1.  INITIALISATIONS
 !===============================================================================
 
-idebia = idbia0
-idebra = idbra0
 
-iphas = 1
-ipbrom = ipprob(irom  (iphas))
-ipcvis = ipproc(iviscl(iphas))
+ipbrom = ipprob(irom  )
+ipcvis = ipproc(iviscl)
 
 d2s3 = 2.d0/3.d0
 
@@ -283,9 +195,9 @@ enddo
 do ifac = 1, nfabor
   izone = izfppp(ifac)
   qcalc(izone) = qcalc(izone) - propfb(ifac,ipbrom) *             &
-     ( rcodcl(ifac,iu(iphas),1)*surfbo(1,ifac) +                  &
-       rcodcl(ifac,iv(iphas),1)*surfbo(2,ifac) +                  &
-       rcodcl(ifac,iw(iphas),1)*surfbo(3,ifac) )
+     ( rcodcl(ifac,iu,1)*surfbo(1,ifac) +                  &
+       rcodcl(ifac,iv,1)*surfbo(2,ifac) +                  &
+       rcodcl(ifac,iw,1)*surfbo(3,ifac) )
 enddo
 if(irangp.ge.0) then
   call parrsm(nozapm,qcalc)
@@ -316,9 +228,9 @@ do ifac = 1, nfabor
   izone = izfppp(ifac)
   if ( iqimp(izone).eq.1 ) then
     qisqc = qimp(izone)/qcalc(izone)
-    rcodcl(ifac,iu(iphas),1) = rcodcl(ifac,iu(iphas),1)*qisqc
-    rcodcl(ifac,iv(iphas),1) = rcodcl(ifac,iv(iphas),1)*qisqc
-    rcodcl(ifac,iw(iphas),1) = rcodcl(ifac,iw(iphas),1)*qisqc
+    rcodcl(ifac,iu,1) = rcodcl(ifac,iu,1)*qisqc
+    rcodcl(ifac,iv,1) = rcodcl(ifac,iv,1)*qisqc
+    rcodcl(ifac,iw,1) = rcodcl(ifac,iw,1)*qisqc
   endif
 enddo
 
@@ -339,9 +251,9 @@ enddo
 '@  Le calcul ne peut etre execute.                           ',/,&
 '@                                                            ',/,&
 '@  Verifier usebuc, et en particulier                        ',/,&
-'@    - que le vecteur  RCODCL(IFAC,IU(IPHAS),1),             ',/,&
-'@                      RCODCL(IFAC,IV(IPHAS),1),             ',/,&
-'@                      RCODCL(IFAC,IW(IPHAS),1) qui determine',/,&
+'@    - que le vecteur  RCODCL(IFAC,IU,1),             ',/,&
+'@                      RCODCL(IFAC,IV,1),             ',/,&
+'@                      RCODCL(IFAC,IW,1) qui determine',/,&
 '@      la direction de la vitesse est non nul et n''est pas  ',/,&
 '@      uniformement perpendiculaire aux face d''entree       ',/,&
 '@    - que la surface de l''entree n''est pas nulle (ou que  ',/,&
@@ -367,7 +279,7 @@ do ifac = 1, nfabor
 
 !      ELEMENT ADJACENT A LA FACE DE BORD
 
-  if ( itypfb(ifac,iphas).eq.ientre ) then
+  if ( itypfb(ifac).eq.ientre ) then
 
 ! ----  Traitement automatique de la turbulence
 
@@ -380,9 +292,9 @@ do ifac = 1, nfabor
 !            de reference et de l'intensite turvulente
 !            adaptes a l'entree courante si ICALKE = 2
 
-      uref2 = rcodcl(ifac,iu(iphas),1)**2                         &
-            + rcodcl(ifac,iv(iphas),1)**2                         &
-            + rcodcl(ifac,iw(iphas),1)**2
+      uref2 = rcodcl(ifac,iu,1)**2                         &
+            + rcodcl(ifac,iv,1)**2                         &
+            + rcodcl(ifac,iw,1)**2
       uref2 = max(uref2,epzero)
       rhomoy = propfb(ifac,ipbrom)
       iel    = ifabor(ifac)
@@ -404,32 +316,36 @@ do ifac = 1, nfabor
         ( uref2, xiturb, dhy, cmu, xkappa, xkent, xeent )
       endif
 
-      if (itytur(iphas).eq.2) then
+      if (itytur.eq.2) then
 
-        rcodcl(ifac,ik(iphas),1)  = xkent
-        rcodcl(ifac,iep(iphas),1) = xeent
+        rcodcl(ifac,ik,1)  = xkent
+        rcodcl(ifac,iep,1) = xeent
 
-      elseif (itytur(iphas).eq.3) then
+      elseif (itytur.eq.3) then
 
-        rcodcl(ifac,ir11(iphas),1) = d2s3*xkent
-        rcodcl(ifac,ir22(iphas),1) = d2s3*xkent
-        rcodcl(ifac,ir33(iphas),1) = d2s3*xkent
-        rcodcl(ifac,ir12(iphas),1) = 0.d0
-        rcodcl(ifac,ir13(iphas),1) = 0.d0
-        rcodcl(ifac,ir23(iphas),1) = 0.d0
-        rcodcl(ifac,iep(iphas),1)  = xeent
+        rcodcl(ifac,ir11,1) = d2s3*xkent
+        rcodcl(ifac,ir22,1) = d2s3*xkent
+        rcodcl(ifac,ir33,1) = d2s3*xkent
+        rcodcl(ifac,ir12,1) = 0.d0
+        rcodcl(ifac,ir13,1) = 0.d0
+        rcodcl(ifac,ir23,1) = 0.d0
+        rcodcl(ifac,iep,1)  = xeent
 
-      elseif (iturb(iphas).eq.50) then
+      elseif (iturb.eq.50) then
 
-        rcodcl(ifac,ik(iphas),1)   = xkent
-        rcodcl(ifac,iep(iphas),1)  = xeent
-        rcodcl(ifac,iphi(iphas),1) = d2s3
-        rcodcl(ifac,ifb(iphas),1)  = 0.d0
+        rcodcl(ifac,ik,1)   = xkent
+        rcodcl(ifac,iep,1)  = xeent
+        rcodcl(ifac,iphi,1) = d2s3
+        rcodcl(ifac,ifb,1)  = 0.d0
 
-      elseif (iturb(iphas).eq.60) then
+      elseif (iturb.eq.60) then
 
-        rcodcl(ifac,ik(iphas),1)   = xkent
-        rcodcl(ifac,iomg(iphas),1) = xeent/cmu/xkent
+        rcodcl(ifac,ik,1)   = xkent
+        rcodcl(ifac,iomg,1) = xeent/cmu/xkent
+
+      elseif(iturb.eq.70) then
+
+        rcodcl(ifac,inusa,1) = cmu*xkent**2/xeent
 
       endif
 
@@ -445,8 +361,6 @@ enddo
 !    (modele ebu)
 !===============================================================================
 
-iphas  = 1
-
 ! --- FRMEL et TGF (on n'en veut qu'un : on prend le max)
 !     EBU nominal est a f homogene
 !     On se limite pour l'instant a une temperature
@@ -455,7 +369,7 @@ iphas  = 1
 frmel = 0.d0
 tgf   = 0.d0
 do ifac = 1, nfabor
-  if ( itypfb(ifac,iphas).eq.ientre ) then
+  if ( itypfb(ifac).eq.ientre ) then
     izone = izfppp(ifac)
     if ( ippmod(icoebu).eq.0 .or. ippmod(icoebu).eq.1 ) then
       frmel = max(fment(izone),frmel)
@@ -475,7 +389,7 @@ endif
 !  presentes sur le proc local. Ca suffit pour le traitement qui suit.
 do ifac = 1, nfabor
   izone = izfppp(ifac)
-  if ( itypfb(ifac,iphas).eq.ientre ) then
+  if ( itypfb(ifac).eq.ientre ) then
     if ( ippmod(icoebu).eq.0 .or. ippmod(icoebu).eq.1 ) then
       fment(izone) = frmel
     endif
@@ -499,8 +413,6 @@ enddo
 ! ---> Combustion gaz USEBUC
 !      Flamme de premelange modele EBU
 
-iphas = 1
-
 !      Enthalpie du melange gazeux :
 !         hors de la boucle pour eviter un appel par face.
 !         Suppose que une entree est forcement IENTGF=1 ou IENTGB=1
@@ -548,7 +460,7 @@ do ifac = 1, nfabor
 
 !      ELEMENT ADJACENT A LA FACE DE BORD
 
-  if ( itypfb(ifac,iphas).eq.ientre ) then
+  if ( itypfb(ifac).eq.ientre ) then
 
 ! ----  Traitement automatique des scalaires physiques particulieres
 
