@@ -1,27 +1,22 @@
 !-------------------------------------------------------------------------------
 
-!     This file is part of the Code_Saturne Kernel, element of the
-!     Code_Saturne CFD tool.
-
-!     Copyright (C) 1998-2009 EDF S.A., France
-
-!     contact: saturne-support@edf.fr
-
-!     The Code_Saturne Kernel is free software; you can redistribute it
-!     and/or modify it under the terms of the GNU General Public License
-!     as published by the Free Software Foundation; either version 2 of
-!     the License, or (at your option) any later version.
-
-!     The Code_Saturne Kernel is distributed in the hope that it will be
-!     useful, but WITHOUT ANY WARRANTY; without even the implied warranty
-!     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-!     GNU General Public License for more details.
-
-!     You should have received a copy of the GNU General Public License
-!     along with the Code_Saturne Kernel; if not, write to the
-!     Free Software Foundation, Inc.,
-!     51 Franklin St, Fifth Floor,
-!     Boston, MA  02110-1301  USA
+! This file is part of Code_Saturne, a general-purpose CFD tool.
+!
+! Copyright (C) 1998-2011 EDF S.A.
+!
+! This program is free software; you can redistribute it and/or modify it under
+! the terms of the GNU General Public License as published by the Free Software
+! Foundation; either version 2 of the License, or (at your option) any later
+! version.
+!
+! This program is distributed in the hope that it will be useful, but WITHOUT
+! ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+! FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+! details.
+!
+! You should have received a copy of the GNU General Public License along with
+! this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
+! Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 !-------------------------------------------------------------------------------
 
@@ -31,7 +26,7 @@ subroutine enswaf &
  ( nbpmax , nvp    , nvp1   , nvep   , nivep  ,                   &
    nfin   ,                                                       &
    itepa  ,                                                       &
-   ettp   , tepa , trav   )
+   ettp   , tepa   )
 
 !===============================================================================
 ! FONCTION :
@@ -66,29 +61,27 @@ subroutine enswaf &
 !                  !    !     !   etape courante ou precedente                 !
 ! tepa             ! tr ! <-- ! info particulaires (reels)                     !
 ! (nbpmax,nvep)    !    !     !   (poids statistiques,...)                     !
-! trav(nbpmax,3    ! tr ! --- ! tableaux de travail                            !
 !__________________!____!_____!________________________________________________!
 
 !     TYPE : E (ENTIER), R (REEL), A (ALPHANUMERIQUE), T (TABLEAU)
 !            L (LOGIQUE)   .. ET TYPES COMPOSES (EX : TR TABLEAU REEL)
 !     MODE : <-- donnee, --> resultat, <-> Donnee modifiee
 !            --- tableau de travail
-
 !===============================================================================
 
+!==============================================================================
+! Module files
+!==============================================================================
+
+use paramx
+use entsor
+use lagpar
+use lagran
+
+!==============================================================================
+
 implicit none
 
-!==============================================================================
-! Common blocks
-!==============================================================================
-
-include "paramx.h"
-include "entsor.h"
-include "lagpar.h"
-include "lagran.h"
-
-!==============================================================================
-
 ! Arguments
 
 integer          nbpmax , nvp    , nvp1   , nvep  , nivep
@@ -97,7 +90,6 @@ integer          itepa(nbpmax,nivep)
 
 double precision ettp(nbpmax,nvp)
 double precision tepa(nbpmax,nvep)
-double precision trav(nbpmax,3)
 
 ! Local variables
 
@@ -107,6 +99,8 @@ integer          ii1 , ii2 , lpos , n1 , n2
 
 character        fich*80 , name*80 , entet*80
 
+double precision, allocatable, dimension(:,:) :: trav
+
 integer          ipwaf
 data             ipwaf /0/
 save             ipwaf
@@ -117,6 +111,9 @@ save             ipwaf
 ! 0. GESTION MEMOIRE
 !===============================================================================
 
+! Allocate a work array
+allocate(trav(nbpmax,3))
+
 !===============================================================================
 ! 1. Initialisations
 !===============================================================================
@@ -193,8 +190,11 @@ if ( (mod(ipwaf-1,nvisla).eq.0 .and. nfin.eq.0)   .or.            &
     np = liste(nl)
     if (np.ge.1) then
       if (itepa(np,jisor).ne.0) then
-        write(impla1,'(I8,3E12.5)') np, &
-          ettp(np,jxp), ettp(np,jyp), ettp(np,jzp)
+        write(impla1,'(I8,3E12.5)') &
+                  np,               &
+        ettp(np,jxp),               &
+        ettp(np,jyp),               &
+        ettp(np,jzp)
       endif
     endif
   enddo
@@ -240,7 +240,7 @@ if (ivistp.eq.1) then
         trav(ipt,1) = tepa(np,jrtsp)
       endif
     endif
-  enddo
+ enddo
 
   FICH = ' '
   fich = entet
@@ -599,6 +599,9 @@ if (ivisv2.eq.1) then
 
 endif
 
+! Free memory
+deallocate(trav)
+
 !===============================================================================
 ! 13. Ecriture du deplacement.case au dernier passage
 !===============================================================================
