@@ -1,48 +1,37 @@
 !-------------------------------------------------------------------------------
 
-!     This file is part of the Code_Saturne Kernel, element of the
-!     Code_Saturne CFD tool.
-
-!     Copyright (C) 1998-2009 EDF S.A., France
-
-!     contact: saturne-support@edf.fr
-
-!     The Code_Saturne Kernel is free software; you can redistribute it
-!     and/or modify it under the terms of the GNU General Public License
-!     as published by the Free Software Foundation; either version 2 of
-!     the License, or (at your option) any later version.
-
-!     The Code_Saturne Kernel is distributed in the hope that it will be
-!     useful, but WITHOUT ANY WARRANTY; without even the implied warranty
-!     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-!     GNU General Public License for more details.
-
-!     You should have received a copy of the GNU General Public License
-!     along with the Code_Saturne Kernel; if not, write to the
-!     Free Software Foundation, Inc.,
-!     51 Franklin St, Fifth Floor,
-!     Boston, MA  02110-1301  USA
+! This file is part of Code_Saturne, a general-purpose CFD tool.
+!
+! Copyright (C) 1998-2011 EDF S.A.
+!
+! This program is free software; you can redistribute it and/or modify it under
+! the terms of the GNU General Public License as published by the Free Software
+! Foundation; either version 2 of the License, or (at your option) any later
+! version.
+!
+! This program is distributed in the hope that it will be useful, but WITHOUT
+! ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+! FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+! details.
+!
+! You should have received a copy of the GNU General Public License along with
+! this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
+! Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 !-------------------------------------------------------------------------------
 
 subroutine lages1 &
 !================
 
- ( idbia0 , idbra0 ,                                              &
-   ndim   , ncelet , ncel   , nfac   , nfabor , nfml   ,          &
-   nprfml , nnod   , lndfac , lndfbr , ncelbr ,                   &
-   nvar   , nscal  , nphas  ,                                     &
+ ( nvar   , nscal  ,                                              &
    nbpmax , nvp    , nvp1   , nvep   , nivep  ,                   &
    ntersl , nvlsta , nvisbr ,                                     &
-   nideve , nrdeve , nituse , nrtuse ,                            &
-   itepa  , idevel , ituser , ia     ,                            &
-   xyzcen , surfac , surfbo , cdgfac , cdgfbo , xyznod , volume , &
+   itepa  ,                                                       &
    dt     , rtpa   , propce , propfa , propfb ,                   &
    ettp   , ettpa  , tepa   , statis ,                            &
    taup   , tlag   , piil   ,                                     &
    bx     , vagaus , gradpr , gradvf , romp   ,                   &
-   brgaus , terbru , fextla ,                                     &
-   rdevel , rtuser , ra    )
+   brgaus , terbru , fextla )
 
 !===============================================================================
 ! FONCTION :
@@ -58,22 +47,8 @@ subroutine lages1 &
 !__________________.____._____.________________________________________________.
 ! name             !type!mode ! role                                           !
 !__________________!____!_____!________________________________________________!
-! idbia0           ! i  ! <-- ! number of first free position in ia            !
-! idbra0           ! i  ! <-- ! number of first free position in ra            !
-! ndim             ! i  ! <-- ! spatial dimension                              !
-! ncelet           ! i  ! <-- ! number of extended (real + ghost) cells        !
-! ncel             ! i  ! <-- ! number of cells                                !
-! nfac             ! i  ! <-- ! number of interior faces                       !
-! nfabor           ! i  ! <-- ! number of boundary faces                       !
-! nfml             ! i  ! <-- ! number of families (group classes)             !
-! nprfml           ! i  ! <-- ! number of properties per family (group class)  !
-! nnod             ! i  ! <-- ! number of vertices                             !
-! lndfac           ! i  ! <-- ! size of nodfac indexed array                   !
-! lndfbr           ! i  ! <-- ! size of nodfbr indexed array                   !
-! ncelbr           ! i  ! <-- ! number of cells with faces on boundary         !
 ! nvar             ! i  ! <-- ! total number of variables                      !
 ! nscal            ! i  ! <-- ! total number of scalars                        !
-! nphas            ! i  ! <-- ! number of phases                               !
 ! nbpmax           ! e  ! <-- ! nombre max de particulies autorise             !
 ! nvp              ! e  ! <-- ! nombre de variables particulaires              !
 ! nvp1             ! e  ! <-- ! nvp sans position, vfluide, vpart              !
@@ -82,26 +57,8 @@ subroutine lages1 &
 ! ntersl           ! e  ! <-- ! nbr termes sources de couplage retour          !
 ! nvlsta           ! e  ! <-- ! nombre de var statistiques lagrangien          !
 ! nvisbr           ! e  ! <-- ! nombre de statistiques aux frontieres          !
-! nideve, nrdeve   ! i  ! <-- ! sizes of idevel and rdevel arrays              !
-! nituse, nrtuse   ! i  ! <-- ! sizes of ituser and rtuser arrays              !
 ! itepa            ! te ! <-- ! info particulaires (entiers)                   !
 ! (nbpmax,nivep    !    !     !   (cellule de la particule,...)                !
-! idevel(nideve)   ! ia ! <-> ! integer work array for temporary development   !
-! ituser(nituse)   ! ia ! <-> ! user-reserved integer work array               !
-! ia(*)            ! ia ! --- ! main integer work array                        !
-! xyzcen           ! ra ! <-- ! cell centers                                   !
-!  (ndim, ncelet)  !    !     !                                                !
-! surfac           ! ra ! <-- ! interior faces surface vectors                 !
-!  (ndim, nfac)    !    !     !                                                !
-! surfbo           ! ra ! <-- ! boundary faces surface vectors                 !
-!  (ndim, nfabor)  !    !     !                                                !
-! cdgfac           ! ra ! <-- ! interior faces centers of gravity              !
-!  (ndim, nfac)    !    !     !                                                !
-! cdgfbo           ! ra ! <-- ! boundary faces centers of gravity              !
-!  (ndim, nfabor)  !    !     !                                                !
-! xyznod           ! tr ! <-- ! coordonnes des noeuds                          !
-! (ndim,nnod)      !    !     !                                                !
-! volume(ncelet    ! tr ! <-- ! volume d'un des ncelet elements                !
 ! dt(ncelet)       ! ra ! <-- ! time step (per cell)                           !
 ! rtpa             ! tr ! <-- ! variables de calcul au centre des              !
 ! (ncelet,*)       !    !     !    cellules (pas de temps precedent)           !
@@ -127,56 +84,43 @@ subroutine lages1 &
 ! romp             ! tr ! <-- ! masse volumique des particules                 !
 ! fextla           ! tr ! <-- ! champ de forces exterieur                      !
 !(ncelet,3)        !    !     !    utilisateur (m/s2)                          !
-! rdevel(nrdeve)   ! ra ! <-> ! real work array for temporary development      !
-! rtuser(nrtuse)   ! ra ! <-> ! user-reserved real work array                  !
-! ra(*)            ! ra ! --- ! main real work array                           !
 !__________________!____!_____!________________________________________________!
 
 !     TYPE : E (ENTIER), R (REEL), A (ALPHANUMERIQUE), T (TABLEAU)
 !            L (LOGIQUE)   .. ET TYPES COMPOSES (EX : TR TABLEAU REEL)
 !     MODE : <-- donnee, --> resultat, <-> Donnee modifiee
 !            --- tableau de travail
+!===============================================================================
+
+!===============================================================================
+! Module files
+!===============================================================================
+
+use paramx
+use numvar
+use cstphy
+use cstnum
+use optcal
+use entsor
+use lagpar
+use lagran
+use ppppar
+use ppthch
+use ppincl
+use mesh
 
 !===============================================================================
 
 implicit none
 
-!===============================================================================
-! Common blocks
-!===============================================================================
-
-include "paramx.h"
-include "numvar.h"
-include "cstphy.h"
-include "cstnum.h"
-include "optcal.h"
-include "entsor.h"
-include "lagpar.h"
-include "lagran.h"
-include "ppppar.h"
-include "ppthch.h"
-include "ppincl.h"
-
-!===============================================================================
-
 ! Arguments
 
-integer          idbia0 , idbra0
-integer          ndim   , ncelet , ncel   , nfac   , nfabor
-integer          nfml   , nprfml
-integer          nnod   ,lndfac , lndfbr , ncelbr
-integer          nvar   , nscal  , nphas
+integer          nvar   , nscal
 integer          nbpmax , nvp    , nvp1   , nvep  , nivep
 integer          ntersl , nvlsta , nvisbr
-integer          nideve , nrdeve , nituse , nrtuse
-integer          itepa(nbpmax,nivep)
-integer          idevel(nideve), ituser(nituse)
-integer          ia(*)
 
-double precision xyzcen(ndim,ncelet)
-double precision surfac(ndim,nfac) , surfbo(ndim,nfabor)
-double precision cdgfac(ndim,nfac) , cdgfbo(ndim,nfabor)
-double precision xyznod(ndim,nnod) , volume(ncelet)
+integer          itepa(nbpmax,nivep)
+
 double precision dt(ncelet) , rtpa(ncelet,*)
 double precision propce(ncelet,*)
 double precision propfa(nfac,*) , propfb(nfabor,*)
@@ -189,13 +133,10 @@ double precision brgaus(nbpmax,*) , terbru(nbpmax)
 double precision gradpr(ncelet,3) , gradvf(ncelet,9)
 double precision romp(nbpmax)
 double precision fextla(nbpmax,3)
-double precision rdevel(nrdeve), rtuser(nrtuse)
-double precision ra(*)
 
 ! Local variables
 
-integer          idebia , idebra
-integer          iel , ip , id , i0 , iromf , iphas , mode
+integer          iel , ip , id , i0 , iromf , mode
 
 double precision aa , bb , cc , dd , ee
 double precision aux1 , aux2 ,aux3 , aux4 , aux5 , aux6
@@ -218,14 +159,14 @@ double precision tbrix1, tbrix2, tbriu
 ! 0.  GESTION MEMOIRE
 !===============================================================================
 
-idebia = idbia0
-idebra = idbra0
 
 !===============================================================================
 ! 1. INITIALISATIONS
 !===============================================================================
 
-iphas = ilphas
+! Initialize variables to avoid compiler warnings
+
+vitf = 0.d0
 
 grav(1) = gx
 grav(2) = gy
@@ -236,7 +177,7 @@ grav(3) = gz
 if ( ippmod(icp3pl).ge.0 .or. ippmod(icfuel).ge.0 ) then
   iromf = ipproc(irom1)
 else
-  iromf = ipproc(irom(iphas))
+  iromf = ipproc(irom)
 endif
 
 !===============================================================================
@@ -255,9 +196,9 @@ do id = 1,3
 
       rom = propce(iel,iromf)
 
-      if (id.eq.1) vitf = rtpa(iel,iu(iphas))
-      if (id.eq.2) vitf = rtpa(iel,iv(iphas))
-      if (id.eq.3) vitf = rtpa(iel,iw(iphas))
+      if (id.eq.1) vitf = rtpa(iel,iu)
+      if (id.eq.2) vitf = rtpa(iel,iv)
+      if (id.eq.3) vitf = rtpa(iel,iw)
 
 !---> (2.1) Calcul preliminaires :
 !     ----------------------------
@@ -409,19 +350,19 @@ do id = 1,3
 
           tempf = propce(iel,ipproc(itemp))
 
-        else if ( iscsth(iscalt(iphas)).eq.-1 ) then
-          tempf = rtpa(iel,isca(iscalt(iphas)))
+        else if ( iscsth(iscalt).eq.-1 ) then
+          tempf = rtpa(iel,isca(iscalt))
 
-        else if ( iscsth(iscalt(iphas)).eq.1 ) then
-          tempf = rtpa(iel,isca(iscalt(iphas)))
+        else if ( iscsth(iscalt).eq.1 ) then
+          tempf = rtpa(iel,isca(iscalt))
 
-        else if ( iscsth(iscalt(iphas)).eq.2 ) then
+        else if ( iscsth(iscalt).eq.2 ) then
           mode = 1
-          call usthht(mode,rtpa(iel,isca(iscalt(iphas))),tempf)
+          call usthht(mode,rtpa(iel,isca(iscalt)),tempf)
           !==========
           tempf = tempf+tkelvi
         else
-          tempf = t0(iphas)
+          tempf = t0
         endif
 
         ddbr  = sqrt( 2.d0*kboltz*tempf                           &
