@@ -1,40 +1,34 @@
 !-------------------------------------------------------------------------------
 
-!     This file is part of the Code_Saturne Kernel, element of the
-!     Code_Saturne CFD tool.
-
-!     Copyright (C) 1998-2009 EDF S.A., France
-
-!     contact: saturne-support@edf.fr
-
-!     The Code_Saturne Kernel is free software; you can redistribute it
-!     and/or modify it under the terms of the GNU General Public License
-!     as published by the Free Software Foundation; either version 2 of
-!     the License, or (at your option) any later version.
-
-!     The Code_Saturne Kernel is distributed in the hope that it will be
-!     useful, but WITHOUT ANY WARRANTY; without even the implied warranty
-!     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-!     GNU General Public License for more details.
-
-!     You should have received a copy of the GNU General Public License
-!     along with the Code_Saturne Kernel; if not, write to the
-!     Free Software Foundation, Inc.,
-!     51 Franklin St, Fifth Floor,
-!     Boston, MA  02110-1301  USA
+! This file is part of Code_Saturne, a general-purpose CFD tool.
+!
+! Copyright (C) 1998-2011 EDF S.A.
+!
+! This program is free software; you can redistribute it and/or modify it under
+! the terms of the GNU General Public License as published by the Free Software
+! Foundation; either version 2 of the License, or (at your option) any later
+! version.
+!
+! This program is distributed in the hope that it will be useful, but WITHOUT
+! ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+! FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+! details.
+!
+! You should have received a copy of the GNU General Public License along with
+! this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
+! Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 !-------------------------------------------------------------------------------
 
 subroutine laglec &
 !================
 
- ( idbia0 , idbra0 ,                                              &
-   ndim   , ncelet , ncel   , nfac   , nfabor ,                   &
+ ( ndim   , ncelet , ncel   , nfac   , nfabor ,                   &
    nbpmax , nvp    , nvp1   , nvep   , nivep  ,                   &
    ntersl , nvlsta , nvisbr ,                                     &
-   itepa  , ia     ,                                              &
+   itepa  ,                                                       &
    rtpa   , propce ,                                              &
-   ettp   , tepa   , statis , stativ , parbor , tslagr , ra     )
+   ettp   , tepa   , statis , stativ , parbor , tslagr )
 
 !===============================================================================
 ! FONCTION :
@@ -48,7 +42,7 @@ subroutine laglec &
 !    volumiques et aux frontieres, ainsi que les termes sources
 !    de couplage retour.
 
-!    Tous les tableaux sont initialise a zero avant d'tre remplis
+!    Tous les tableaux sont initialise a zero avant d'être remplis
 !    dans le cas d'une suite (sinon ils restent a zero).
 !    On realise donc ici l'initialisation des tableaux ouverts
 !    dans MEMLA1, ce qui termine l'etape d'initialisation debutee
@@ -60,8 +54,6 @@ subroutine laglec &
 !__________________.____._____.________________________________________________.
 ! name             !type!mode ! role                                           !
 !__________________!____!_____!________________________________________________!
-! idbia0           ! i  ! <-- ! number of first free position in ia            !
-! idbra0           ! i  ! <-- ! number of first free position in ra            !
 ! ndim             ! i  ! <-- ! spatial dimension                              !
 ! ncelet           ! i  ! <-- ! number of extended (real + ghost) cells        !
 ! ncel             ! i  ! <-- ! number of cells                                !
@@ -77,7 +69,6 @@ subroutine laglec &
 ! nvisbr           ! e  ! <-- ! nombre de statistiques aux frontieres          !
 ! itepa            ! te ! <-- ! info particulaires (entiers)                   !
 ! (nbpmax,nivep    !    !     !   (cellule de la particule,...)                !
-! ia(*)            ! ia ! --- ! main integer work array                        !
 ! rtpa             ! tr ! <-- ! variables de calcul au centre des              !
 ! (ncelet,*)       !    !     !    cellules instant precedent                  !
 ! propce(ncelet, *)! ra ! <-- ! physical properties at cell centers            !
@@ -94,47 +85,44 @@ subroutine laglec &
 !(nfabor,nvisbr    !    !     !   aux faces de bord                            !
 ! tslagr           ! tr ! <-- ! terme de couplage retour du                    !
 !(ncelet,ntersl    !    !     !   lagrangien sur la phase porteuse             !
-! ra(*)            ! ra ! --- ! main real work array                           !
 !__________________!____!_____!________________________________________________!
 
 !     TYPE : E (ENTIER), R (REEL), A (ALPHANUMERIQUE), T (TABLEAU)
 !            L (LOGIQUE)   .. ET TYPES COMPOSES (EX : TR TABLEAU REEL)
 !     MODE : <-- donnee, --> resultat, <-> Donnee modifiee
 !            --- tableau de travail
+!===============================================================================
+
+!===============================================================================
+! Module files
+!===============================================================================
+
+use paramx
+use cstnum
+use cstphy
+use numvar
+use optcal
+use entsor
+use parall
+use period
+use lagpar
+use lagran
+use ppppar
+use ppthch
+use ppincl
+use cpincl
+use radiat
 
 !===============================================================================
 
 implicit none
 
-!===============================================================================
-! Common blocks
-!===============================================================================
-
-include "paramx.h"
-include "cstnum.h"
-include "cstphy.h"
-include "numvar.h"
-include "optcal.h"
-include "entsor.h"
-include "period.h"
-include "parall.h"
-include "lagpar.h"
-include "lagran.h"
-include "ppppar.h"
-include "ppthch.h"
-include "ppincl.h"
-include "cpincl.h"
-include "radiat.h"
-
-!===============================================================================
-
 ! Arguments
 
-integer          idbia0 , idbra0
 integer          ndim   , ncelet , ncel   , nfac   , nfabor
 integer          nbpmax , nvp    , nvp1   , nvep  , nivep
 integer          ntersl , nvlsta , nvisbr
-integer          itepa(nbpmax,nivep)  , ia(*)
+integer          itepa(nbpmax,nivep)
 
 double precision rtpa(ncelet,*) , propce(ncelet,*)
 double precision ettp(nbpmax,nvp) , tepa(nbpmax,nvep)
@@ -142,19 +130,18 @@ double precision statis(ncelet,nvlsta)
 double precision stativ(ncelet,nvlsta-1)
 double precision tslagr(ncelet,ntersl)
 double precision parbor(nfabor,nvisbr)
-double precision ra(*)
 
 ! Local variables
 
 character        rubriq*64 , car4*4, car8*8, kar8*8
 character        nomnvl(nvplmx)*60 , nomtsl(nvplmx)*60
 character        nomite(nvplmx)*64 , nomrte(nvplmx)*64
-integer          idebia , idebra
+character        ficsui*32
 integer          ncelok , nfaiok , nfabok , nsomok
 integer          ierror , irtyp  , itysup , nbval
 integer          ilecec , nberro , ivers
 integer          mvls   , ivar   , ip     , icha
-integer          ifac   , iel    , iok    , iphas
+integer          ifac   , iel    , iok
 integer          jphyla , jtpvar , jdpvar , jmpvar
 integer          jsttio , jdstnt , mstist , mvlsts
 integer          mstbor , musbor , mstits , jturb, jtytur
@@ -166,8 +153,6 @@ integer          impaml , impmls
 ! 0. Gestion memoire
 !===============================================================================
 
-idebia = idbia0
-idebra = idbra0
 
 !===============================================================================
 ! 1. Initialisations par defaut
@@ -177,8 +162,6 @@ idebra = idbra0
 !     tableaux lagrangiens ouverts dans la routine MEMLA1
 !     (sauf ITYCEL et ICOCEL qui sont initialises dans LAGDEB),
 
-iphas = ilphas
-
 do ivar = 1,nvp
   do ip = 1,nbpmax
     ettp(ip,ivar) = 0.d0
@@ -244,10 +227,11 @@ write(nfecra,6000)
 
 !     (ILECEC=1:lecture)
 ilecec = 1
-call opnsui(ficaml,len(ficaml),ilecec,impaml,ierror)
+ficsui = 'lagrangian'
+call opnsui(ficsui,len(ficsui),ilecec,impaml,ierror)
 !==========
 if(ierror.ne.0) then
-  write(nfecra,9010) ficaml, ficaml
+  write(nfecra,9010) ficsui, ficsui
   call csexit (1)
 endif
 
@@ -468,6 +452,16 @@ endif
 if (iphyla.eq.2) then
   NOMITE(JINCH) = 'numero_charbon'
 endif
+! deposition submodel
+if (idepst.eq.1) then
+  NOMITE(jimark) = 'indicateur_de_saut'
+  NOMITE(JDIEL) = 'diel_particules'
+  NOMITE(JDFAC) = 'dfac_particules'
+  NOMITE(JDIFEL) = 'difel_particules'
+  NOMITE(JTRAJ) = 'traj_particules'
+  NOMITE(JPTDET) = 'ptdet_particules'
+  NOMITE(jinjst) = 'indic_stat'
+endif
 
 nbval  = nbpart
 irtyp  = 1
@@ -492,6 +486,12 @@ if (iphyla.eq.2) then
   NOMRTE(JRR0P) = 'masse_volumique_initial_charbon'
 endif
 
+! Deposition submodel
+if (idepst.eq.1) then
+   NOMRTE(jryplu) = 'yplus_particules'
+   NOMRTE(jrinpf) = 'dx_particules'
+endif
+
 nbval  = nbpart
 irtyp  = 2
 
@@ -565,13 +565,13 @@ if (iphyla.eq.1 .and. itpvar.eq.1) then
                 ippmod(ielarc).ge.0 .or.                          &
                 ippmod(ieljou).ge.0      ) then
          ettp(ip,jtf) = propce(iel,ipproc(itemp)) -tkelvi
-      else if ( iscsth(iscalt(iphas)).eq.1 ) then
-         ettp(ip,jtf) = rtpa(iel,isca(iscalt(iphas))) -tkelvi
-      else if ( iscsth(iscalt(iphas)).eq.-1 ) then
-         ettp(ip,jtf) = rtpa(iel,isca(iscalt(iphas)))
-      else if ( iscsth(iscalt(iphas)).eq.2 ) then
+      else if ( iscsth(iscalt).eq.1 ) then
+         ettp(ip,jtf) = rtpa(iel,isca(iscalt)) -tkelvi
+      else if ( iscsth(iscalt).eq.-1 ) then
+         ettp(ip,jtf) = rtpa(iel,isca(iscalt))
+      else if ( iscsth(iscalt).eq.2 ) then
          mode = 1
-         call usthht(mode, rtpa(iel,isca(iscalt(iphas))),         &
+         call usthht(mode, rtpa(iel,isca(iscalt)),         &
                      ettp(ip,jtf))
       endif
     enddo
@@ -637,10 +637,11 @@ if (isuist.eq.1) then
 
 !     (ILECEC=1:lecture)
   ilecec = 1
-  call opnsui(ficmls,len(ficmls),ilecec,impmls,ierror)
+  ficsui = 'lagrangian_stats'
+  call opnsui(ficsui,len(ficsui),ilecec,impmls,ierror)
   !==========
   if(ierror.ne.0) then
-    write(nfecra,9010) ficmls, ficmls
+    write(nfecra,9010) ficsui, ficsui
     call csexit (1)
   endif
 
@@ -1021,10 +1022,10 @@ if (isuist.eq.1) then
       IF (JTYTUR.EQ.3) CAR8 = 'Rij-eps'
       IF (JTURB.EQ.50) CAR8 = 'v2f'
       IF (JTURB.EQ.60) CAR8 = 'k-omega'
-      IF (ITYTUR(IPHAS).EQ.2) KAR8 = 'k-eps'
-      IF (ITYTUR(IPHAS).EQ.3) KAR8 = 'Rij-eps'
-      IF (ITURB(IPHAS).EQ.50) KAR8 = 'v2f'
-      IF (ITURB(IPHAS).EQ.60) KAR8 = 'k-omega'
+      IF (ITYTUR.EQ.2) KAR8 = 'k-eps'
+      IF (ITYTUR.EQ.3) KAR8 = 'Rij-eps'
+      IF (ITURB.EQ.50) KAR8 = 'v2f'
+      IF (ITURB.EQ.60) KAR8 = 'k-omega'
       write (nfecra,9330) ficmls,                                 &
                           jsttio, mstits, car8,                   &
                           isttio, nstits, kar8
@@ -1072,10 +1073,10 @@ if (isuist.eq.1) then
       NOMTSL(ITSVY) = 'terme_source_vitesseY'
       NOMTSL(ITSVZ) = 'terme_source_vitesseZ'
       NOMTSL(ITSLI) = 'terme_source_vitesse_implicite'
-      if (itytur(iphas).eq.2 .or. iturb(iphas).eq.50              &
-           .or. iturb(iphas).eq.60) then
+      if (itytur.eq.2 .or. iturb.eq.50              &
+           .or. iturb.eq.60) then
         NOMTSL(ITSKE) = 'terme_source_turbulence_keps'
-      else if (itytur(iphas).eq.3) then
+      else if (itytur.eq.3) then
         NOMTSL(ITSR11) = 'terme_source_turbulence_R11'
         NOMTSL(ITSR12) = 'terme_source_turbulence_R12'
         NOMTSL(ITSR13) = 'terme_source_turbulence_R13'
