@@ -2,48 +2,33 @@
 
 !VERS
 
-
-!     This file is part of the Code_Saturne Kernel, element of the
-!     Code_Saturne CFD tool.
-
-!     Copyright (C) 1998-2009 EDF S.A., France
-
-!     contact: saturne-support@edf.fr
-
-!     The Code_Saturne Kernel is free software; you can redistribute it
-!     and/or modify it under the terms of the GNU General Public License
-!     as published by the Free Software Foundation; either version 2 of
-!     the License, or (at your option) any later version.
-
-!     The Code_Saturne Kernel is distributed in the hope that it will be
-!     useful, but WITHOUT ANY WARRANTY; without even the implied warranty
-!     of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-!     GNU General Public License for more details.
-
-!     You should have received a copy of the GNU General Public License
-!     along with the Code_Saturne Kernel; if not, write to the
-!     Free Software Foundation, Inc.,
-!     51 Franklin St, Fifth Floor,
-!     Boston, MA  02110-1301  USA
+! This file is part of Code_Saturne, a general-purpose CFD tool.
+!
+! Copyright (C) 1998-2011 EDF S.A.
+!
+! This program is free software; you can redistribute it and/or modify it under
+! the terms of the GNU General Public License as published by the Free Software
+! Foundation; either version 2 of the License, or (at your option) any later
+! version.
+!
+! This program is distributed in the hope that it will be useful, but WITHOUT
+! ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+! FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+! details.
+!
+! You should have received a copy of the GNU General Public License along with
+! this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
+! Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 !-------------------------------------------------------------------------------
 
 subroutine usvort &
 !================
 
- ( idbia0 , idbra0 ,                                              &
-   ndim   , ncelet , ncel   , nfac   , nfabor , nfml   , nprfml , &
-   nnod   , lndfac , lndfbr , ncelbr ,                            &
-   nvar   , nscal  , nphas  ,                                     &
-   nideve , nrdeve , nituse , nrtuse ,                            &
-   iphas  , iappel ,                                              &
-   ifacel , ifabor , ifmfbr , ifmcel , iprfml , maxelt , lstelt , &
-   ipnfac , nodfac , ipnfbr , nodfbr , irepvo ,                   &
-   idevel , ituser , ia     ,                                     &
-   xyzcen , surfac , surfbo , cdgfac , cdgfbo , xyznod , volume , &
+ ( nvar   , nscal  ,                                              &
+   iappel ,                                                       &
    dt     , rtpa   , propce , propfa , propfb ,                   &
-   coefa  , coefb  ,                                              &
-   rdevel , rtuser , ra     )
+   coefa  , coefb  )
 
 !===============================================================================
 ! FONCTION :
@@ -68,56 +53,9 @@ subroutine usvort &
 !__________________.____._____.________________________________________________.
 ! name             !type!mode ! role                                           !
 !__________________!____!_____!________________________________________________!
-! idbia0           ! i  ! <-- ! number of first free position in ia            !
-! idbra0           ! i  ! <-- ! number of first free position in ra            !
-! ndim             ! i  ! <-- ! spatial dimension                              !
-! ncelet           ! i  ! <-- ! number of extended (real + ghost) cells        !
-! ncel             ! i  ! <-- ! number of cells                                !
-! nfac             ! i  ! <-- ! number of interior faces                       !
-! nfabor           ! i  ! <-- ! number of boundary faces                       !
-! nfml             ! i  ! <-- ! number of families (group classes)             !
-! nprfml           ! i  ! <-- ! number of properties per family (group class)  !
-! nnod             ! i  ! <-- ! number of vertices                             !
-! lndfac           ! i  ! <-- ! size of nodfac indexed array                   !
-! lndfbr           ! i  ! <-- ! size of nodfbr indexed array                   !
-! ncelbr           ! i  ! <-- ! number of cells with faces on boundary         !
 ! nvar             ! i  ! <-- ! total number of variables                      !
 ! nscal            ! i  ! <-- ! total number of scalars                        !
-! nphas            ! i  ! <-- ! number of phases                               !
-! nideve, nrdeve   ! i  ! <-- ! sizes of idevel and rdevel arrays              !
-! nituse, nrtuse   ! i  ! <-- ! sizes of ituser and rtuser arrays              !
-! iphas            ! i  ! <-- ! phase number                                   !
 ! iappel           ! e  ! <-- ! indique les donnes a renvoyer                  !
-! ifacel(2, nfac)  ! ia ! <-- ! interior faces -> cells connectivity           !
-! ifabor(nfabor)   ! ia ! <-- ! boundary faces -> cells connectivity           !
-! ifmfbr(nfabor)   ! ia ! <-- ! boundary face family numbers                   !
-! ifmcel(ncelet)   ! ia ! <-- ! cell family numbers                            !
-! iprfml           ! ia ! <-- ! property numbers per family                    !
-!  (nfml, nprfml)  !    !     !                                                !
-! maxelt           ! i  ! <-- ! max number of cells and faces (int/boundary)   !
-! lstelt(maxelt)   ! ia ! --- ! work array                                     !
-! ipnfac(nfac+1)   ! ia ! <-- ! interior faces -> vertices index (optional)    !
-! nodfac(lndfac)   ! ia ! <-- ! interior faces -> vertices list (optional)     !
-! ipnfbr(nfabor+1) ! ia ! <-- ! boundary faces -> vertices index (optional)    !
-! nodfbr(lndfbr)   ! ia ! <-- ! boundary faces -> vertices list (optional)     !
-! irepvo           ! te ! <-- ! numero de l'entree associe a chaque            !
-!     (nfabor)     !    !     ! face de bord (=0 si pas de vortex)             !
-! idevel(nideve)   ! ia ! <-> ! integer work array for temporary development   !
-! ituser(nituse)   ! ia ! <-> ! user-reserved integer work array               !
-! ia(*)            ! ia ! --- ! main integer work array                        !
-! xyzcen           ! ra ! <-- ! cell centers                                   !
-!  (ndim, ncelet)  !    !     !                                                !
-! surfac           ! ra ! <-- ! interior faces surface vectors                 !
-!  (ndim, nfac)    !    !     !                                                !
-! surfbo           ! ra ! <-- ! boundary faces surface vectors                 !
-!  (ndim, nfabor)  !    !     !                                                !
-! cdgfac           ! ra ! <-- ! interior faces centers of gravity              !
-!  (ndim, nfac)    !    !     !                                                !
-! cdgfbo           ! ra ! <-- ! boundary faces centers of gravity              !
-!  (ndim, nfabor)  !    !     !                                                !
-! xyznod           ! ra ! <-- ! vertex coordinates (optional)                  !
-!  (ndim, nnod)    !    !     !                                                !
-! volume(ncelet)   ! ra ! <-- ! cell volumes                                   !
 ! dt(ncelet)       ! ra ! <-- ! time step (per cell)                           !
 ! rtp, rtpa        ! ra ! <-- ! calculated variables at cell centers           !
 !  (ncelet, *)     !    !     !  (at current and previous time steps)          !
@@ -126,9 +64,6 @@ subroutine usvort &
 ! propfb(nfabor, *)! ra ! <-- ! physical properties at boundary face centers   !
 ! coefa, coefb     ! ra ! <-- ! boundary conditions                            !
 !  (nfabor, *)     !    !     !                                                !
-! rdevel(nrdeve)   ! ra ! <-> ! real work array for temporary development      !
-! rtuser(nrtuse)   ! ra ! <-> ! user-reserved real work array                  !
-! ra(*)            ! ra ! --- ! main real work array                           !
 !__________________!____!_____!________________________________________________!
 
 !     Type: i (integer), r (real), s (string), a (array), l (logical),
@@ -136,53 +71,37 @@ subroutine usvort &
 !     mode: <-- input, --> output, <-> modifies data, --- work array
 !===============================================================================
 
+!===============================================================================
+! Module files
+!===============================================================================
+
+use paramx
+use optcal
+use entsor
+use vorinc
+use mesh
+
+!===============================================================================
+
 implicit none
 
-!===============================================================================
-! Common blocks
-!===============================================================================
-
-include "paramx.h"
-include "optcal.h"
-include "entsor.h"
-include "vortex.h"
-
-!===============================================================================
-
 ! Arguments
 
-integer          idbia0 , idbra0
-integer          ndim   , ncelet , ncel   , nfac   , nfabor
-integer          nfml   , nprfml
-integer          nnod   , lndfac , lndfbr , ncelbr
-integer          nvar   , nscal  , nphas
-integer          nideve , nrdeve , nituse , nrtuse
-integer          iphas  , iappel
+integer          nvar   , nscal
+integer          iappel
 
-integer          ifacel(2,nfac) , ifabor(nfabor)
-integer          ifmfbr(nfabor) , ifmcel(ncelet)
-integer          iprfml(nfml,nprfml)
-integer          maxelt, lstelt(maxelt)
-integer          ipnfac(nfac+1), nodfac(lndfac)
-integer          ipnfbr(nfabor+1), nodfbr(lndfbr)
-integer          irepvo(nfabor)
-integer          idevel(nideve), ituser(nituse), ia(*)
-
-double precision xyzcen(ndim,ncelet)
-double precision surfac(ndim,nfac), surfbo(ndim,nfabor)
-double precision cdgfac(ndim,nfac), cdgfbo(ndim,nfabor)
-double precision xyznod(ndim,nnod), volume(ncelet)
 double precision dt(ncelet), rtpa(ncelet,*)
 double precision propce(ncelet,*)
 double precision propfa(nfac,*), propfb(nfabor,*)
 double precision coefa(nfabor,*), coefb(nfabor,*)
-double precision rdevel(nrdeve), rtuser(nrtuse), ra(*)
 
 ! Local variables
 
 integer          ifac, ient
 integer          ilelt, nlelt
 
+integer, allocatable, dimension(:) :: lstelt
+
 !===============================================================================
 
 ! TEST_TO_REMOVE_FOR_USE_OF_SUBROUTINE_START
@@ -193,6 +112,8 @@ if(1.eq.1) return
 !===============================================================================
 ! TEST_TO_REMOVE_FOR_USE_OF_SUBROUTINE_END
 
+! Allocate a temporary array for boundary faces selection
+allocate(lstelt(nfabor))
 
 !===============================================================================
 ! 1. PARAMETRES GLOBAUX
@@ -255,7 +176,7 @@ elseif (iappel.eq.2) then
 ! 3. PARAMETRES GEOMETRIQUES ET CONDITIONS LIMITES
 !===============================================================================
 
-! --- Cas trait
+! --- Cas traite
 
 ! ICAS = 1...Conduite rectangulaire
 !        2...Conduite circulaire
@@ -275,7 +196,7 @@ elseif (iappel.eq.2) then
 
 !     Si ICAS = 4, le code se charge de ces donnees
 !     Sinon il faut preciser les vecteurs DIR1 et DIR2 definissant
-!     un repre directe tel que DIR3 soit un vecteur entrant normal
+!     un repere directe tel que DIR3 soit un vecteur entrant normal
 !     a la face d'entree.
 
   ient = 1
@@ -439,7 +360,7 @@ elseif (iappel.eq.2) then
 
 !         Grad[u.DIR3].n est le gradient dans la direction normale
 !         a la paroi, de la vitesse principale dans le plan d'entree.
-!         Cette donnes n'est utilise qu'avec ICAS=2
+!         Cette donnees n'est utilisee qu'avec ICAS=2
 
 ! FICVOR...Nom du fichier de donnees utilisateur
 
@@ -449,8 +370,7 @@ elseif (iappel.eq.2) then
   ient = 2
   ndat(ient) = 2080
 
-! Par les defaut les fichiers sont nommes "vordat" affect de l'indice
-! d'entre
+! Par les defaut les fichiers sont nommes "vordat" affecte de l'indice d'entree
 
   ient = 1
   FICVOR(IENT) = 'entree_1.dat'
@@ -478,6 +398,9 @@ elseif (iappel.eq.2) then
 endif
 
 
+! Deallocate the temporary array
+deallocate(lstelt)
+
 return
 end subroutine
 
@@ -533,10 +456,13 @@ double precision vardat(ndat)
 integer          ii
 double precision phidat, dist1
 
+! Initialize variables to avoid compiler warnings
+
+phidat = 0.d0
 
 ! Dans l'exemple suivant, on se contente de retourne la valeur situee
 ! dans le fichier de donnee a l'abscisse la plus proche du point de
-! coordonne (Y,Z) ou l'on cherche a connaitre la valeur de la
+! coordonnee (Y,Z) ou l'on cherche a connaitre la valeur de la
 ! variable numero VARDAT.
 
 
@@ -559,5 +485,6 @@ elseif(icas.eq.4) then
   phidat = vardat(1)
 endif
 
+
 return
 end function
